All Classes and Interfaces

Class
Description
Callback for native IM_ASSERT calls.
 
Helper class to get ABGR packed color used by Dear ImGui.
 
All draw data to render Dear ImGui frame (NB: the style and the naming convention here is a little inconsistent, we currently preserve them for backward compatibility purpose, as this is one of the oldest structure exposed by the library! Basically, ImDrawList == CmdList)
Flags for ImDrawList functions
Draw command list This is the low-level list of polygons that ImGui:: functions are filling.
Flags for ImDrawList.
 
Font runtime data.
Load and rasterize multiple TTF/OTF fonts into a same texture.
Flags for ImFontAtlas build
 
Hold rendering data for one glyph.
Helper to build glyph ranges from text/string data.
 
 
 
Backend capabilities flags stored in io.BackendFlags.
 
 
Flags for ImGui::BeginChild() (Legacy: bit 0 must always correspond to ImGuiChildFlags_Border to be backward compatible with old API using 'bool border = false'.
Enumeration for PushStyleColor() / PopStyleColor()
Flags for ColorEdit3() / ColorEdit4() / ColorPicker3() / ColorPicker4() / ColorButton()
Flags for ImGui::BeginCombo()
Enumeration for ImGui::SetWindow***(), SetNextWindow***(), SetNextItem***() functions Represent a condition.
Configuration flags stored in io.ConfigFlags.
 
Store the source authority (dock node vs window) of a field
A primary data type
A cardinal direction
 
Flags for ImGui::DockSpace(), shared/inherited by child nodes.
Extend ImGuiDockNodeFlags
 
Flags for ImGui::BeginDragDropSource(), ImGui::AcceptDragDropPayload()
Flags for ImGui::IsWindowFocused()
 
Renamed from ImGuiFreeTypeBuilderFlags in imgui 1.92.
Flags for ImGui::IsItemHovered(), ImGui::IsWindowHovered() Note:if you are trying to check whether your mouse should be dispatched to Dear ImGui or to your app, you should use'io.WantCaptureMouse'instead!Please read the FAQ!Note: windows with the ImGuiWindowFlags_NoInputs flag are ignored by IsWindowHovered() calls.
 
Shared state of InputText(), passed as an argument to your callback when a ImGuiInputTextFlags_Callback* flag is used.
Flags for ImGui::InputText()
Communicate most settings and inputs/outputs to Dear ImGui using this structure.
Transient per-window flags, reset at the beginning of the frame.
 
A key identifier (ImGuiKey_XXX or ImGuiMod_XXX value): can represent Keyboard, Mouse and Gamepad values.
[Internal] Storage used by IsKeyDown(), IsKeyPressed() etc functions.
 
ImGuiKnobs extension for ImGui Repo: https://github.com/altschuler/imgui-knobs
 
Helper: Manually clip large list of items.
Identify a mouse button.
Enumeration for GetMouseCursor() User code may request binding to display given cursor by calling SetMouseCursor(), which is why we have some cursors that are marked unused here
Enumeration for AddMouseSourceEvent() actual source of Mouse Input data.
Helper: Execute a block of code at maximum once a frame.
----------------------------------------------------------------------------- [BETA] Platform interface for multi-viewport support ----------------------------------------------------------------------------- (Optional) This is completely optional, for advanced users! If you are new to Dear ImGui and trying to integrate it into your engine, you can probably ignore this for now.
(Optional) This is required when enabling multi-viewport.
Flags for OpenPopup*(), BeginPopupContext*(), IsPopupOpen() functions.
Flags for ImGui::Selectable()
 
 
A sorting direction
Helper: Key-Value storage Typically you don't have to worry about this since a storage is held within each Window.
Class provides a communication layer between binding and Dear ImGui library through the "pointer" field.
Class extends ImGuiStruct and provides additional API to allocated and de-allocate native objects.
You may modify the ImGui::GetStyle() main instance during initialization and before NewFrame().
Enumeration for PushStyleVar() / PopStyleVar() to temporarily modify the ImGuiStyle structure.
Flags for ImGui::BeginTabBar()
Flags for ImGui::BeginTabItem()
Enum for ImGui::TableSetBgColor() Background colors are rendering in 3 layers: - Layer 0: draw with RowBg0 color if set, otherwise draw with ColumnBg0 if set.
Sorting specification for one column of a table.
Flags for ImGui::BeginTable() [BETA API] API may evolve slightly! If you use this, please update to the next version when it comes out! - Important! Sizing policies have complex and subtle side effects, more so than you would expect.
Sorting specifications for a table (often handling sort specs for a single column, occasionally more) Obtained by calling TableGetSortSpecs().
Helper: Parse and apply text filters.
 
Flags for ImGui::TreeNodeEx(), ImGui::CollapsingHeader*()
The viewports created and managed by Dear ImGui.
Flags stored in ImGuiViewport::Flags, giving indications to the platform backends.
 
[ALPHA] Rarely used / very advanced uses only.
Flags for ImGui::Begin()
 
 
Callback for ImGuiListClipper class.
 
Bindings for Imnodes (https://github.com/Nelarius/imnodes/) Original library author - Johann Muszynski (https://github.com/Nelarius)
This enum controls the way the attribute pins behave.
 
 
 
 
This enum controls the minimap's location.
This enum controls the way attribute pins look.
 
 
 
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*)
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*, String)
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*, ImVec2)
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*, String)
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*) - Boolean
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*) - Boolean
Callback to represent ImGuiPlatformIO function with args: (ImGuiViewport*) - ImVec2
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Helper: ImRect (2D axis aligned bounding-box) NB: we can't rely on ImVec2 math operators being available here!
 
Callback to supply Java string form native code.
Wrapper for String to use inside th Dear ImGui input widgets.
Use this class to customize your ImGui input.
Callback to get Java string from native code.
2D vector (often used to store positions or sizes).
4D vector (often used to store floating-point colors).
ImGui Club Memory Editor extension for ImGui Repo: https://github.com/ocornut/imgui_club
 
 
Bindings for Imgui Node Editor (https://github.com/thedmd/imgui-node-editor) Original library author - Michał Cichoń (https://github.com/thedmd)
 
 
 
 
 
 
 
 
Needs view and projection matrices.