Package imgui
Class ImGuiKeyData
java.lang.Object
imgui.binding.ImGuiStruct
imgui.binding.ImGuiStructDestroyable
imgui.ImGuiKeyData
[Internal] Storage used by IsKeyDown(), IsKeyPressed() etc functions.
If prior to 1.87 you used io.KeysDownDuration[] (which was marked as internal), you should use GetKeyData(key).DownDuration and not io.KeysData[key].DownDuration.
-
Field Summary
Fields inherited from class imgui.binding.ImGuiStruct
ptr -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected longcreate()float0.0f..1.0f for gamepad valuesbooleangetDown()True for if key is downfloatDuration the key has been down (<0.0f: not pressed, 0.0f: just pressed,>0.0f: time held)floatLast frame duration the key has been downvoidsetAnalogValue(float value) 0.0f..1.0f for gamepad valuesvoidsetDown(boolean value) True for if key is downvoidsetDownDuration(float value) Duration the key has been down (<0.0f: not pressed, 0.0f: just pressed,>0.0f: time held)voidsetDownDurationPrev(float value) Last frame duration the key has been downMethods inherited from class imgui.binding.ImGuiStructDestroyable
destroyMethods inherited from class imgui.binding.ImGuiStruct
isNotValidPtr, isValidPtr
-
Constructor Details
-
ImGuiKeyData
public ImGuiKeyData() -
ImGuiKeyData
public ImGuiKeyData(long ptr)
-
-
Method Details
-
create
protected long create()- Specified by:
createin classImGuiStructDestroyable
-
getDown
public boolean getDown()True for if key is down -
setDown
public void setDown(boolean value) True for if key is down -
getDownDuration
public float getDownDuration()Duration the key has been down (<0.0f: not pressed, 0.0f: just pressed,>0.0f: time held) -
setDownDuration
public void setDownDuration(float value) Duration the key has been down (<0.0f: not pressed, 0.0f: just pressed,>0.0f: time held) -
getDownDurationPrev
public float getDownDurationPrev()Last frame duration the key has been down -
setDownDurationPrev
public void setDownDurationPrev(float value) Last frame duration the key has been down -
getAnalogValue
public float getAnalogValue()0.0f..1.0f for gamepad values -
setAnalogValue
public void setAnalogValue(float value) 0.0f..1.0f for gamepad values
-