Package imgui

Class ImGuiOnceUponAFrame

java.lang.Object
imgui.ImGuiOnceUponAFrame

public final class ImGuiOnceUponAFrame extends Object
Helper: Execute a block of code at maximum once a frame. Convenient if you want to quickly create an UI within deep-nested code that runs multiple times every frame. Usage: static ImGuiOnceUponAFrame oaf; if (oaf) ImGui::Text("This will be called only once per frame");

BINDING NOTICE: Java example: if (ImGuiOnceUponAFrame.get()) ImGui.text("This will be called only once per frame");

  • Method Details

    • get

      public static boolean get()