Package imgui

Class ImGuiPlatformMonitor

java.lang.Object
imgui.binding.ImGuiStruct
imgui.ImGuiPlatformMonitor

public final class ImGuiPlatformMonitor extends ImGuiStruct
(Optional) This is required when enabling multi-viewport. Represent the bounds of each connected monitor/display and their DPI. We use this information for multiple DPI support + clamping the position of popups and tooltips so they don't straddle multiple monitors.
  • Field Summary

    Fields inherited from class imgui.binding.ImGuiStruct

    ptr
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Modifier and Type
    Method
    Description
    float
    1.0f = 96 DPI
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    float
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    float
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    float
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    float
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    long
    Backend dependant data (e.g.
    Coordinates without task bars / side bars / menu bars.
    void
    Coordinates without task bars / side bars / menu bars.
    float
    Coordinates without task bars / side bars / menu bars.
    float
    Coordinates without task bars / side bars / menu bars.
    Coordinates without task bars / side bars / menu bars.
    void
    Coordinates without task bars / side bars / menu bars.
    float
    Coordinates without task bars / side bars / menu bars.
    float
    Coordinates without task bars / side bars / menu bars.
    void
    setDpiScale(float value)
    1.0f = 96 DPI
    void
    setMainPos(float valueX, float valueY)
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    setMainSize(float valueX, float valueY)
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    void
    setPlatformHandle(long platformHandle)
    Backend dependant data (e.g.
    void
    setWorkPos(float valueX, float valueY)
    Coordinates without task bars / side bars / menu bars.
    void
    Coordinates without task bars / side bars / menu bars.
    void
    setWorkSize(float valueX, float valueY)
    Coordinates without task bars / side bars / menu bars.
    void
    Coordinates without task bars / side bars / menu bars.

    Methods inherited from class imgui.binding.ImGuiStruct

    isNotValidPtr, isValidPtr

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • ImGuiPlatformMonitor

      public ImGuiPlatformMonitor(long ptr)
  • Method Details

    • getMainPos

      public ImVec2 getMainPos()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainPosX

      public float getMainPosX()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainPosY

      public float getMainPosY()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainPos

      public void getMainPos(ImVec2 dst)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • setMainPos

      public void setMainPos(ImVec2 value)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • setMainPos

      public void setMainPos(float valueX, float valueY)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainSize

      public ImVec2 getMainSize()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainSizeX

      public float getMainSizeX()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainSizeY

      public float getMainSizeY()
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getMainSize

      public void getMainSize(ImVec2 dst)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • setMainSize

      public void setMainSize(ImVec2 value)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • setMainSize

      public void setMainSize(float valueX, float valueY)
      Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)
    • getWorkPos

      public ImVec2 getWorkPos()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkPosX

      public float getWorkPosX()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkPosY

      public float getWorkPosY()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkPos

      public void getWorkPos(ImVec2 dst)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • setWorkPos

      public void setWorkPos(ImVec2 value)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • setWorkPos

      public void setWorkPos(float valueX, float valueY)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkSize

      public ImVec2 getWorkSize()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkSizeX

      public float getWorkSizeX()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkSizeY

      public float getWorkSizeY()
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getWorkSize

      public void getWorkSize(ImVec2 dst)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • setWorkSize

      public void setWorkSize(ImVec2 value)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • setWorkSize

      public void setWorkSize(float valueX, float valueY)
      Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize.
    • getDpiScale

      public float getDpiScale()
      1.0f = 96 DPI
    • setDpiScale

      public void setDpiScale(float value)
      1.0f = 96 DPI
    • setPlatformHandle

      public void setPlatformHandle(long platformHandle)
      Backend dependant data (e.g. HMONITOR, GLFWmonitor*, SDL Display Index, NSScreen*)
    • getPlatformHandle

      public long getPlatformHandle()
      Backend dependant data (e.g. HMONITOR, GLFWmonitor*, SDL Display Index, NSScreen*)