Package imgui

Class ImGuiStyle


public final class ImGuiStyle extends ImGuiStructDestroyable
You may modify the ImGui::GetStyle() main instance during initialization and before NewFrame(). During the frame, use ImGui::PushStyleVar(ImGuiStyleVar_XXXX)/PopStyleVar() to alter the main style values, and ImGui::PushStyleColor(ImGuiCol_XXX)/PopStyleColor() for colors.
  • Constructor Details

    • ImGuiStyle

      public ImGuiStyle()
    • ImGuiStyle

      public ImGuiStyle(long ptr)
  • Method Details

    • create

      protected long create()
      Specified by:
      create in class ImGuiStructDestroyable
    • getAlpha

      public float getAlpha()
      Global alpha applies to everything in Dear ImGui.
    • setAlpha

      public void setAlpha(float value)
      Global alpha applies to everything in Dear ImGui.
    • getDisabledAlpha

      public float getDisabledAlpha()
      Additional alpha multiplier applied by BeginDisabled(). Multiply over current value of Alpha.
    • setDisabledAlpha

      public void setDisabledAlpha(float value)
      Additional alpha multiplier applied by BeginDisabled(). Multiply over current value of Alpha.
    • getFontScaleMain

      public float getFontScaleMain()
      Main global scale factor applied on top of font size. Replaces io.FontGlobalScale (moved from io to style in imgui 1.92). May be set by application once or exposed to end-users.
    • setFontScaleMain

      public void setFontScaleMain(float value)
      Main global scale factor applied on top of font size. Replaces io.FontGlobalScale (moved from io to style in imgui 1.92). May be set by application once or exposed to end-users.
    • getFontScaleDpi

      public float getFontScaleDpi()
      Additional global scale factor from viewport/monitor contents scale (since imgui 1.92). In the docking branch: when io.ConfigDpiScaleFonts is enabled, this is automatically overwritten when changing monitor DPI.
    • setFontScaleDpi

      public void setFontScaleDpi(float value)
      Additional global scale factor from viewport/monitor contents scale (since imgui 1.92). In the docking branch: when io.ConfigDpiScaleFonts is enabled, this is automatically overwritten when changing monitor DPI.
    • getWindowPadding

      public ImVec2 getWindowPadding()
      Padding within a window.
    • getWindowPaddingX

      public float getWindowPaddingX()
      Padding within a window.
    • getWindowPaddingY

      public float getWindowPaddingY()
      Padding within a window.
    • getWindowPadding

      public void getWindowPadding(ImVec2 dst)
      Padding within a window.
    • setWindowPadding

      public void setWindowPadding(ImVec2 value)
      Padding within a window.
    • setWindowPadding

      public void setWindowPadding(float valueX, float valueY)
      Padding within a window.
    • getWindowRounding

      public float getWindowRounding()
      Radius of window corners rounding. Set to 0.0f to have rectangular windows. Large values tend to lead to variety of artifacts and are not recommended.
    • setWindowRounding

      public void setWindowRounding(float value)
      Radius of window corners rounding. Set to 0.0f to have rectangular windows. Large values tend to lead to variety of artifacts and are not recommended.
    • getWindowBorderSize

      public float getWindowBorderSize()
      Thickness of border around windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • setWindowBorderSize

      public void setWindowBorderSize(float value)
      Thickness of border around windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • getWindowMinSize

      public ImVec2 getWindowMinSize()
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • getWindowMinSizeX

      public float getWindowMinSizeX()
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • getWindowMinSizeY

      public float getWindowMinSizeY()
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • getWindowMinSize

      public void getWindowMinSize(ImVec2 dst)
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • setWindowMinSize

      public void setWindowMinSize(ImVec2 value)
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • setWindowMinSize

      public void setWindowMinSize(float valueX, float valueY)
      Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints().
    • getWindowTitleAlign

      public ImVec2 getWindowTitleAlign()
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • getWindowTitleAlignX

      public float getWindowTitleAlignX()
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • getWindowTitleAlignY

      public float getWindowTitleAlignY()
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • getWindowTitleAlign

      public void getWindowTitleAlign(ImVec2 dst)
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • setWindowTitleAlign

      public void setWindowTitleAlign(ImVec2 value)
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • setWindowTitleAlign

      public void setWindowTitleAlign(float valueX, float valueY)
      Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered.
    • getWindowMenuButtonPosition

      public int getWindowMenuButtonPosition()
      Side of the collapsing/docking button in the title bar (None/Left/Right). Defaults to ImGuiDir_Left.
    • setWindowMenuButtonPosition

      public void setWindowMenuButtonPosition(int value)
      Side of the collapsing/docking button in the title bar (None/Left/Right). Defaults to ImGuiDir_Left.
    • getChildRounding

      public float getChildRounding()
      Radius of child window corners rounding. Set to 0.0f to have rectangular windows.
    • setChildRounding

      public void setChildRounding(float value)
      Radius of child window corners rounding. Set to 0.0f to have rectangular windows.
    • getChildBorderSize

      public float getChildBorderSize()
      Thickness of border around child windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • setChildBorderSize

      public void setChildBorderSize(float value)
      Thickness of border around child windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • getPopupRounding

      public float getPopupRounding()
      Radius of popup window corners rounding. (Note that tooltip windows use WindowRounding)
    • setPopupRounding

      public void setPopupRounding(float value)
      Radius of popup window corners rounding. (Note that tooltip windows use WindowRounding)
    • getPopupBorderSize

      public float getPopupBorderSize()
      Thickness of border around popup/tooltip windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • setPopupBorderSize

      public void setPopupBorderSize(float value)
      Thickness of border around popup/tooltip windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • getFramePadding

      public ImVec2 getFramePadding()
      Padding within a framed rectangle (used by most widgets).
    • getFramePaddingX

      public float getFramePaddingX()
      Padding within a framed rectangle (used by most widgets).
    • getFramePaddingY

      public float getFramePaddingY()
      Padding within a framed rectangle (used by most widgets).
    • getFramePadding

      public void getFramePadding(ImVec2 dst)
      Padding within a framed rectangle (used by most widgets).
    • setFramePadding

      public void setFramePadding(ImVec2 value)
      Padding within a framed rectangle (used by most widgets).
    • setFramePadding

      public void setFramePadding(float valueX, float valueY)
      Padding within a framed rectangle (used by most widgets).
    • getFrameRounding

      public float getFrameRounding()
      Radius of frame corners rounding. Set to 0.0f to have rectangular frame (used by most widgets).
    • setFrameRounding

      public void setFrameRounding(float value)
      Radius of frame corners rounding. Set to 0.0f to have rectangular frame (used by most widgets).
    • getFrameBorderSize

      public float getFrameBorderSize()
      Thickness of border around frames. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • setFrameBorderSize

      public void setFrameBorderSize(float value)
      Thickness of border around frames. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly).
    • getItemSpacing

      public ImVec2 getItemSpacing()
      Horizontal and vertical spacing between widgets/lines.
    • getItemSpacingX

      public float getItemSpacingX()
      Horizontal and vertical spacing between widgets/lines.
    • getItemSpacingY

      public float getItemSpacingY()
      Horizontal and vertical spacing between widgets/lines.
    • getItemSpacing

      public void getItemSpacing(ImVec2 dst)
      Horizontal and vertical spacing between widgets/lines.
    • setItemSpacing

      public void setItemSpacing(ImVec2 value)
      Horizontal and vertical spacing between widgets/lines.
    • setItemSpacing

      public void setItemSpacing(float valueX, float valueY)
      Horizontal and vertical spacing between widgets/lines.
    • getItemInnerSpacing

      public ImVec2 getItemInnerSpacing()
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • getItemInnerSpacingX

      public float getItemInnerSpacingX()
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • getItemInnerSpacingY

      public float getItemInnerSpacingY()
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • getItemInnerSpacing

      public void getItemInnerSpacing(ImVec2 dst)
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • setItemInnerSpacing

      public void setItemInnerSpacing(ImVec2 value)
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • setItemInnerSpacing

      public void setItemInnerSpacing(float valueX, float valueY)
      Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label).
    • getCellPadding

      public ImVec2 getCellPadding()
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • getCellPaddingX

      public float getCellPaddingX()
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • getCellPaddingY

      public float getCellPaddingY()
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • getCellPadding

      public void getCellPadding(ImVec2 dst)
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • setCellPadding

      public void setCellPadding(ImVec2 value)
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • setCellPadding

      public void setCellPadding(float valueX, float valueY)
      Padding within a table cell. CellPadding.y may be altered between different rows.
    • getTouchExtraPadding

      public ImVec2 getTouchExtraPadding()
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • getTouchExtraPaddingX

      public float getTouchExtraPaddingX()
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • getTouchExtraPaddingY

      public float getTouchExtraPaddingY()
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • getTouchExtraPadding

      public void getTouchExtraPadding(ImVec2 dst)
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • setTouchExtraPadding

      public void setTouchExtraPadding(ImVec2 value)
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • setTouchExtraPadding

      public void setTouchExtraPadding(float valueX, float valueY)
      Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much!
    • getIndentSpacing

      public float getIndentSpacing()
      Horizontal indentation when e.g. entering a tree node. Generally == (FontSize + FramePadding.x*2).
    • setIndentSpacing

      public void setIndentSpacing(float value)
      Horizontal indentation when e.g. entering a tree node. Generally == (FontSize + FramePadding.x*2).
    • getColumnsMinSpacing

      public float getColumnsMinSpacing()
      Minimum horizontal spacing between two columns. Preferably > (FramePadding.x + 1).
    • setColumnsMinSpacing

      public void setColumnsMinSpacing(float value)
      Minimum horizontal spacing between two columns. Preferably > (FramePadding.x + 1).
    • getScrollbarSize

      public float getScrollbarSize()
      Width of the vertical scrollbar, Height of the horizontal scrollbar.
    • setScrollbarSize

      public void setScrollbarSize(float value)
      Width of the vertical scrollbar, Height of the horizontal scrollbar.
    • getScrollbarRounding

      public float getScrollbarRounding()
      Radius of grab corners for scrollbar.
    • setScrollbarRounding

      public void setScrollbarRounding(float value)
      Radius of grab corners for scrollbar.
    • getGrabMinSize

      public float getGrabMinSize()
      Minimum width/height of a grab box for slider/scrollbar.
    • setGrabMinSize

      public void setGrabMinSize(float value)
      Minimum width/height of a grab box for slider/scrollbar.
    • getGrabRounding

      public float getGrabRounding()
      Radius of grabs corners rounding. Set to 0.0f to have rectangular slider grabs.
    • setGrabRounding

      public void setGrabRounding(float value)
      Radius of grabs corners rounding. Set to 0.0f to have rectangular slider grabs.
    • getLogSliderDeadzone

      public float getLogSliderDeadzone()
      The size in pixels of the dead-zone around zero on logarithmic sliders that cross zero.
    • setLogSliderDeadzone

      public void setLogSliderDeadzone(float value)
      The size in pixels of the dead-zone around zero on logarithmic sliders that cross zero.
    • getTabRounding

      public float getTabRounding()
      Radius of upper corners of a tab. Set to 0.0f to have rectangular tabs.
    • setTabRounding

      public void setTabRounding(float value)
      Radius of upper corners of a tab. Set to 0.0f to have rectangular tabs.
    • getTabBorderSize

      public float getTabBorderSize()
      Thickness of border around tabs.
    • setTabBorderSize

      public void setTabBorderSize(float value)
      Thickness of border around tabs.
    • getTabCloseButtonMinWidthSelected

      public float getTabCloseButtonMinWidthSelected()
      Minimum width for close button to appear on a selected tab when hovered. -1: always visible; 0: visible when hovered; >0: visible when hovered if tab width is at least this wide. (Since imgui 1.91.9 this field split into TabCloseButtonMinWidthSelected and TabCloseButtonMinWidthUnselected.)
    • setTabCloseButtonMinWidthSelected

      public void setTabCloseButtonMinWidthSelected(float value)
      Minimum width for close button to appear on a selected tab when hovered. -1: always visible; 0: visible when hovered; >0: visible when hovered if tab width is at least this wide. (Since imgui 1.91.9 this field split into TabCloseButtonMinWidthSelected and TabCloseButtonMinWidthUnselected.)
    • getTabCloseButtonMinWidthUnselected

      public float getTabCloseButtonMinWidthUnselected()
      Minimum width for close button to appear on an unselected tab when hovered. -1: always visible; 0: visible when hovered; >0: visible when hovered if tab width is at least this wide; FLT_MAX: never show close button when unselected. (Since imgui 1.91.9; renamed from TabMinWidthForCloseButton.)
    • setTabCloseButtonMinWidthUnselected

      public void setTabCloseButtonMinWidthUnselected(float value)
      Minimum width for close button to appear on an unselected tab when hovered. -1: always visible; 0: visible when hovered; >0: visible when hovered if tab width is at least this wide; FLT_MAX: never show close button when unselected. (Since imgui 1.91.9; renamed from TabMinWidthForCloseButton.)
    • getColorButtonPosition

      public int getColorButtonPosition()
      Side of the color button in the ColorEdit4 widget (left/right). Defaults to ImGuiDir_Right.
    • setColorButtonPosition

      public void setColorButtonPosition(int value)
      Side of the color button in the ColorEdit4 widget (left/right). Defaults to ImGuiDir_Right.
    • getButtonTextAlign

      public ImVec2 getButtonTextAlign()
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • getButtonTextAlignX

      public float getButtonTextAlignX()
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • getButtonTextAlignY

      public float getButtonTextAlignY()
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • getButtonTextAlign

      public void getButtonTextAlign(ImVec2 dst)
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • setButtonTextAlign

      public void setButtonTextAlign(ImVec2 value)
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • setButtonTextAlign

      public void setButtonTextAlign(float valueX, float valueY)
      Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered).
    • getSelectableTextAlign

      public ImVec2 getSelectableTextAlign()
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • getSelectableTextAlignX

      public float getSelectableTextAlignX()
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • getSelectableTextAlignY

      public float getSelectableTextAlignY()
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • getSelectableTextAlign

      public void getSelectableTextAlign(ImVec2 dst)
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • setSelectableTextAlign

      public void setSelectableTextAlign(ImVec2 value)
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • setSelectableTextAlign

      public void setSelectableTextAlign(float valueX, float valueY)
      Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line.
    • getImageRounding

      public float getImageRounding()
      Rounding of Image() calls (since imgui 1.92).
    • setImageRounding

      public void setImageRounding(float value)
      Rounding of Image() calls (since imgui 1.92).
    • getImageBorderSize

      public float getImageBorderSize()
      Thickness of border around Image() calls (since imgui 1.92).
    • setImageBorderSize

      public void setImageBorderSize(float value)
      Thickness of border around Image() calls (since imgui 1.92).
    • getTreeLinesFlags

      public int getTreeLinesFlags()
      Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One of ImGuiTreeNodeFlags_DrawLinesNone / DrawLinesFull / DrawLinesToNodes.
    • setTreeLinesFlags

      public void setTreeLinesFlags(int value)
      Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One of ImGuiTreeNodeFlags_DrawLinesNone / DrawLinesFull / DrawLinesToNodes.
    • addTreeLinesFlags

      public void addTreeLinesFlags(int flags)
      Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One of ImGuiTreeNodeFlags_DrawLinesNone / DrawLinesFull / DrawLinesToNodes.
    • removeTreeLinesFlags

      public void removeTreeLinesFlags(int flags)
      Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One of ImGuiTreeNodeFlags_DrawLinesNone / DrawLinesFull / DrawLinesToNodes.
    • hasTreeLinesFlags

      public boolean hasTreeLinesFlags(int flags)
      Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One of ImGuiTreeNodeFlags_DrawLinesNone / DrawLinesFull / DrawLinesToNodes.
    • getTreeLinesSize

      public float getTreeLinesSize()
      Thickness of outlines when using ImGuiTreeNodeFlags_DrawLines (since imgui 1.92).
    • setTreeLinesSize

      public void setTreeLinesSize(float value)
      Thickness of outlines when using ImGuiTreeNodeFlags_DrawLines (since imgui 1.92).
    • getTreeLinesRounding

      public float getTreeLinesRounding()
      Radius of lines connecting child nodes to the vertical line (since imgui 1.92).
    • setTreeLinesRounding

      public void setTreeLinesRounding(float value)
      Radius of lines connecting child nodes to the vertical line (since imgui 1.92).
    • getColorMarkerSize

      public float getColorMarkerSize()
      Size of R/G/B/A color markers for ColorEdit4() and for Drags/Sliders when using ImGuiSliderFlags_ColorMarkers (since imgui 1.92.7). Set to 0 to disable globally.
    • setColorMarkerSize

      public void setColorMarkerSize(float value)
      Size of R/G/B/A color markers for ColorEdit4() and for Drags/Sliders when using ImGuiSliderFlags_ColorMarkers (since imgui 1.92.7). Set to 0 to disable globally.
    • getSeparatorSize

      public float getSeparatorSize()
      Thickness of the separator line rendered by Separator() (new in imgui 1.92.7).
    • setSeparatorSize

      public void setSeparatorSize(float value)
      Thickness of the separator line rendered by Separator() (new in imgui 1.92.7).
    • getSeparatorTextBorderSize

      public float getSeparatorTextBorderSize()
      Thickkness of border in SeparatorText()
    • setSeparatorTextBorderSize

      public void setSeparatorTextBorderSize(float value)
      Thickkness of border in SeparatorText()
    • getSeparatorTextAlign

      public ImVec2 getSeparatorTextAlign()
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • getSeparatorTextAlignX

      public float getSeparatorTextAlignX()
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • getSeparatorTextAlignY

      public float getSeparatorTextAlignY()
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • getSeparatorTextAlign

      public void getSeparatorTextAlign(ImVec2 dst)
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • setSeparatorTextAlign

      public void setSeparatorTextAlign(ImVec2 value)
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • setSeparatorTextAlign

      public void setSeparatorTextAlign(float valueX, float valueY)
      Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center).
    • getSeparatorTextPadding

      public ImVec2 getSeparatorTextPadding()
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • getSeparatorTextPaddingX

      public float getSeparatorTextPaddingX()
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • getSeparatorTextPaddingY

      public float getSeparatorTextPaddingY()
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • getSeparatorTextPadding

      public void getSeparatorTextPadding(ImVec2 dst)
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • setSeparatorTextPadding

      public void setSeparatorTextPadding(ImVec2 value)
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • setSeparatorTextPadding

      public void setSeparatorTextPadding(float valueX, float valueY)
      Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y.
    • getDisplayWindowPadding

      public ImVec2 getDisplayWindowPadding()
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • getDisplayWindowPaddingX

      public float getDisplayWindowPaddingX()
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • getDisplayWindowPaddingY

      public float getDisplayWindowPaddingY()
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • getDisplayWindowPadding

      public void getDisplayWindowPadding(ImVec2 dst)
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • setDisplayWindowPadding

      public void setDisplayWindowPadding(ImVec2 value)
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • setDisplayWindowPadding

      public void setDisplayWindowPadding(float valueX, float valueY)
      Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows.
    • getDisplaySafeAreaPadding

      public ImVec2 getDisplaySafeAreaPadding()
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • getDisplaySafeAreaPaddingX

      public float getDisplaySafeAreaPaddingX()
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • getDisplaySafeAreaPaddingY

      public float getDisplaySafeAreaPaddingY()
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • getDisplaySafeAreaPadding

      public void getDisplaySafeAreaPadding(ImVec2 dst)
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • setDisplaySafeAreaPadding

      public void setDisplaySafeAreaPadding(ImVec2 value)
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • setDisplaySafeAreaPadding

      public void setDisplaySafeAreaPadding(float valueX, float valueY)
      If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly!
    • getDockingSeparatorSize

      public float getDockingSeparatorSize()
      Thickness of resizing border between docked windows
    • setDockingSeparatorSize

      public void setDockingSeparatorSize(float value)
      Thickness of resizing border between docked windows
    • getMouseCursorScale

      public float getMouseCursorScale()
      Scale software rendered mouse cursor (when io.MouseDrawCursor is enabled). May be removed later.
    • setMouseCursorScale

      public void setMouseCursorScale(float value)
      Scale software rendered mouse cursor (when io.MouseDrawCursor is enabled). May be removed later.
    • getAntiAliasedLines

      public boolean getAntiAliasedLines()
      Enable anti-aliased lines/borders. Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList).
    • setAntiAliasedLines

      public void setAntiAliasedLines(boolean value)
      Enable anti-aliased lines/borders. Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList).
    • getAntiAliasedLinesUseTex

      public boolean getAntiAliasedLinesUseTex()
      Enable anti-aliased lines/borders using textures where possible. Require backend to render with bilinear filtering (NOT point/nearest filtering). Latched at the beginning of the frame (copied to ImDrawList).
    • setAntiAliasedLinesUseTex

      public void setAntiAliasedLinesUseTex(boolean value)
      Enable anti-aliased lines/borders using textures where possible. Require backend to render with bilinear filtering (NOT point/nearest filtering). Latched at the beginning of the frame (copied to ImDrawList).
    • getAntiAliasedFill

      public boolean getAntiAliasedFill()
      Enable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.). Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList).
    • setAntiAliasedFill

      public void setAntiAliasedFill(boolean value)
      Enable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.). Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList).
    • getCurveTessellationTol

      public float getCurveTessellationTol()
      Tessellation tolerance when using PathBezierCurveTo() without a specific number of segments. Decrease for highly tessellated curves (higher quality, more polygons), increase to reduce quality.
    • setCurveTessellationTol

      public void setCurveTessellationTol(float value)
      Tessellation tolerance when using PathBezierCurveTo() without a specific number of segments. Decrease for highly tessellated curves (higher quality, more polygons), increase to reduce quality.
    • getCircleTessellationMaxError

      public float getCircleTessellationMaxError()
      Maximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified. Decrease for higher quality but more geometry.
    • setCircleTessellationMaxError

      public void setCircleTessellationMaxError(float value)
      Maximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified. Decrease for higher quality but more geometry.
    • getColors

      public ImVec4[] getColors()
    • setColors

      public void setColors(ImVec4[] value)
    • getColor

      public ImVec4 getColor(int col)
    • getColor

      public void getColor(int col, ImVec4 dst)
    • setColor

      public void setColor(int col, float r, float g, float b, float a)
    • setColor

      public void setColor(int col, int r, int g, int b, int a)
    • setColor

      public void setColor(int col, int value)
    • getHoverStationaryDelay

      public float getHoverStationaryDelay()
      Delay for IsItemHovered(ImGuiHoveredFlags_Stationary). Time required to consider mouse stationary.
    • setHoverStationaryDelay

      public void setHoverStationaryDelay(float value)
      Delay for IsItemHovered(ImGuiHoveredFlags_Stationary). Time required to consider mouse stationary.
    • getHoverDelayShort

      public float getHoverDelayShort()
      Delay for IsItemHovered(ImGuiHoveredFlags_DelayShort). Usually used along with HoverStationaryDelay.
    • setHoverDelayShort

      public void setHoverDelayShort(float value)
      Delay for IsItemHovered(ImGuiHoveredFlags_DelayShort). Usually used along with HoverStationaryDelay.
    • getHoverDelayNormal

      public float getHoverDelayNormal()
      Delay for IsItemHovered(ImGuiHoveredFlags_DelayNormal). "
    • setHoverDelayNormal

      public void setHoverDelayNormal(float value)
      Delay for IsItemHovered(ImGuiHoveredFlags_DelayNormal). "
    • getHoverFlagsForTooltipMouse

      public int getHoverFlagsForTooltipMouse()
      Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse.
    • setHoverFlagsForTooltipMouse

      public void setHoverFlagsForTooltipMouse(int value)
      Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse.
    • getHoverFlagsForTooltipNav

      public int getHoverFlagsForTooltipNav()
      Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using keyboard/gamepad.
    • setHoverFlagsForTooltipNav

      public void setHoverFlagsForTooltipNav(int value)
      Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using keyboard/gamepad.
    • scaleAllSizes

      public void scaleAllSizes(float scaleFactor)