Package imgui

Class ImGuiTableColumnSortSpecs

java.lang.Object
imgui.binding.ImGuiStruct
imgui.ImGuiTableColumnSortSpecs

public final class ImGuiTableColumnSortSpecs extends ImGuiStruct
Sorting specification for one column of a table.
  • Constructor Details

    • ImGuiTableColumnSortSpecs

      public ImGuiTableColumnSortSpecs(long ptr)
  • Method Details

    • getColumnUserID

      public int getColumnUserID()
      User id of the column (if specified by a TableSetupColumn() call)
    • getColumnIndex

      public int getColumnIndex()
      Index of the column
    • getSortOrder

      public int getSortOrder()
      Index within parent ImGuiTableSortSpecs (always stored in order starting from 0, tables sorted on a single criteria will always have a 0 here)
    • getSortDirection

      public int getSortDirection()
      ImGuiSortDirection_Ascending or ImGuiSortDirection_Descending (you can use this or SortSign, whichever is more convenient for your sort function)