Package imgui.binding

Class ImGuiStruct

java.lang.Object
imgui.binding.ImGuiStruct
Direct Known Subclasses:
ImDrawData, ImDrawList, ImGuiContext, ImGuiDockNode, ImGuiInputTextCallbackData, ImGuiIO, ImGuiPlatformIO, ImGuiPlatformMonitor, ImGuiStructDestroyable, ImGuiTableColumnSortSpecs, ImGuiTableSortSpecs, ImGuiViewport, ImGuiWindow, ImNodesContext, ImNodesEditorContext, ImNodesIO, ImNodesStyle, ImPlotContext, NodeEditorContext, NodeEditorStyle, TextEditorLanguage

public abstract class ImGuiStruct extends Object
Class provides a communication layer between binding and Dear ImGui library through the "pointer" field.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    long
    Pointer to the natively allocated object.
  • Constructor Summary

    Constructors
    Constructor
    Description
    ImGuiStruct(long ptr)
     
  • Method Summary

    Modifier and Type
    Method
    Description
    final boolean
    Shows if object pointer is valid and does it point to the existing object.
    final boolean
    Shows if object pointer is valid and does it point to the existing object.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • ptr

      public long ptr
      Pointer to the natively allocated object. Could be zero if JNI returned NULL instead of the real object. For such cases methods isValidPtr() and isNotValidPtr() could be used to verify that object points to the real object.
  • Constructor Details

    • ImGuiStruct

      public ImGuiStruct(long ptr)
  • Method Details

    • isValidPtr

      public final boolean isValidPtr()
      Shows if object pointer is valid and does it point to the existing object.
      Returns:
      true, if pointer is valid
    • isNotValidPtr

      public final boolean isNotValidPtr()
      Shows if object pointer is valid and does it point to the existing object.
      Returns:
      true, if pointer is invalid