Package imgui.callback
Class ImGuiInputTextCallback
java.lang.Object
imgui.callback.ImGuiInputTextCallback
- All Implemented Interfaces:
Consumer<ImGuiInputTextCallbackData>
public abstract class ImGuiInputTextCallback
extends Object
implements Consumer<ImGuiInputTextCallbackData>
Callback to use in
ImGui.inputText(String, imgui.type.ImString, int, ImGuiInputTextCallback).-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal voidaccept(long ptr) This function will be called by the native Callback and wrapped.
-
Constructor Details
-
ImGuiInputTextCallback
public ImGuiInputTextCallback()
-
-
Method Details
-
accept
public final void accept(long ptr) This function will be called by the native Callback and wrapped.
-