Class ImPlotInputMap


public final class ImPlotInputMap extends ImGuiStructDestroyable
  • Field Summary

    Fields inherited from class imgui.binding.ImGuiStruct

    ptr
  • Constructor Summary

    Constructors
    Constructor
    Description
     
    ImPlotInputMap(long ptr)
     
  • Method Summary

    Modifier and Type
    Method
    Description
    protected long
     
    int
    LMB initiates fit when double clicked
    int
    RMB opens context menus (if enabled) when clicked
    int
    Ctrl when held, all input is ignored; used to enable axis/plots as DND sources
    int
    LMB enables panning when held
    int
    Optional modifier that must be held for panning/fitting
    int
    RMB begins box selection when pressed and confirms selection when released
    int
    LMB cancels active box selection when pressed; cannot be the same as Select
    int
    Alt expands active box selection horizontally to plot edge when held
    int
    Optional modifier that must be held for box selection
    int
    Shift expands active box selection vertically to plot edge when held
    int
    Optional modifier that must be held for scroll wheel zooming
    float
    Zoom rate for scroll (e.g.
    void
    setFit(int value)
    LMB initiates fit when double clicked
    void
    setMenu(int value)
    RMB opens context menus (if enabled) when clicked
    void
    setOverrideMod(int value)
    Ctrl when held, all input is ignored; used to enable axis/plots as DND sources
    void
    setPan(int value)
    LMB enables panning when held
    void
    setPanMod(int value)
    Optional modifier that must be held for panning/fitting
    void
    setSelect(int value)
    RMB begins box selection when pressed and confirms selection when released
    void
    setSelectCancel(int value)
    LMB cancels active box selection when pressed; cannot be the same as Select
    void
    setSelectHorzMod(int value)
    Alt expands active box selection horizontally to plot edge when held
    void
    setSelectMod(int value)
    Optional modifier that must be held for box selection
    void
    setSelectVertMod(int value)
    Shift expands active box selection vertically to plot edge when held
    void
    setZoomMod(int value)
    Optional modifier that must be held for scroll wheel zooming
    void
    setZoomRate(float value)
    Zoom rate for scroll (e.g.

    Methods inherited from class imgui.binding.ImGuiStructDestroyable

    destroy

    Methods inherited from class imgui.binding.ImGuiStruct

    isNotValidPtr, isValidPtr

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • ImPlotInputMap

      public ImPlotInputMap()
    • ImPlotInputMap

      public ImPlotInputMap(long ptr)
  • Method Details

    • create

      protected long create()
      Specified by:
      create in class ImGuiStructDestroyable
    • getPan

      public int getPan()
      LMB enables panning when held
    • setPan

      public void setPan(int value)
      LMB enables panning when held
    • getPanMod

      public int getPanMod()
      Optional modifier that must be held for panning/fitting
    • setPanMod

      public void setPanMod(int value)
      Optional modifier that must be held for panning/fitting
    • getFit

      public int getFit()
      LMB initiates fit when double clicked
    • setFit

      public void setFit(int value)
      LMB initiates fit when double clicked
    • getSelect

      public int getSelect()
      RMB begins box selection when pressed and confirms selection when released
    • setSelect

      public void setSelect(int value)
      RMB begins box selection when pressed and confirms selection when released
    • getSelectCancel

      public int getSelectCancel()
      LMB cancels active box selection when pressed; cannot be the same as Select
    • setSelectCancel

      public void setSelectCancel(int value)
      LMB cancels active box selection when pressed; cannot be the same as Select
    • getSelectMod

      public int getSelectMod()
      Optional modifier that must be held for box selection
    • setSelectMod

      public void setSelectMod(int value)
      Optional modifier that must be held for box selection
    • getSelectHorzMod

      public int getSelectHorzMod()
      Alt expands active box selection horizontally to plot edge when held
    • setSelectHorzMod

      public void setSelectHorzMod(int value)
      Alt expands active box selection horizontally to plot edge when held
    • getSelectVertMod

      public int getSelectVertMod()
      Shift expands active box selection vertically to plot edge when held
    • setSelectVertMod

      public void setSelectVertMod(int value)
      Shift expands active box selection vertically to plot edge when held
    • getMenu

      public int getMenu()
      RMB opens context menus (if enabled) when clicked
    • setMenu

      public void setMenu(int value)
      RMB opens context menus (if enabled) when clicked
    • getOverrideMod

      public int getOverrideMod()
      Ctrl when held, all input is ignored; used to enable axis/plots as DND sources
    • setOverrideMod

      public void setOverrideMod(int value)
      Ctrl when held, all input is ignored; used to enable axis/plots as DND sources
    • getZoomMod

      public int getZoomMod()
      Optional modifier that must be held for scroll wheel zooming
    • setZoomMod

      public void setZoomMod(int value)
      Optional modifier that must be held for scroll wheel zooming
    • getZoomRate

      public float getZoomRate()
      Zoom rate for scroll (e.g. 0.1f = 10% plot range every scroll click); make negative to invert
    • setZoomRate

      public void setZoomRate(float value)
      Zoom rate for scroll (e.g. 0.1f = 10% plot range every scroll click); make negative to invert