Package imgui.extension.implot.flag
Class ImPlotCol
java.lang.Object
imgui.extension.implot.flag.ImPlotCol
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intbackground color of axis hover region (defaults to transparent)static final intaxis active color (defaults to ImGuiCol_ButtonActive)static final intaxis hover color (defaults to ImGuiCol_ButtonHovered)static final intaxis grid color (defaults to 25% ImPlotCol_AxisText)static final intaxis label and tick labels color (defaults to ImGuiCol_Text)static final intaxis tick color (defaults to AxisGrid)static final intstatic final intcrosshairs color (defaults to ImPlotCol_PlotBorder)static final intplot frame background color (defaults to ImGuiCol_FrameBg)static final intcolor of text appearing inside of plots (defaults to ImGuiCol_Text)static final intlegend background color (defaults to ImGuiCol_PopupBg)static final intlegend border color (defaults to ImPlotCol_PlotBorder)static final intlegend text color (defaults to ImPlotCol_InlayText)static final intplot area background color (defaults to ImGuiCol_WindowBg)static final intplot area border color (defaults to ImGuiCol_Border)static final intbox-selection color (defaults to yellow)static final intplot title text color (defaults to ImGuiCol_Text) -
Method Summary
-
Field Details
-
FrameBg
public static final int FrameBgplot frame background color (defaults to ImGuiCol_FrameBg)- See Also:
-
PlotBg
public static final int PlotBgplot area background color (defaults to ImGuiCol_WindowBg)- See Also:
-
PlotBorder
public static final int PlotBorderplot area border color (defaults to ImGuiCol_Border)- See Also:
-
LegendBg
public static final int LegendBglegend background color (defaults to ImGuiCol_PopupBg)- See Also:
-
LegendBorder
public static final int LegendBorderlegend border color (defaults to ImPlotCol_PlotBorder)- See Also:
-
LegendText
public static final int LegendTextlegend text color (defaults to ImPlotCol_InlayText)- See Also:
-
TitleText
public static final int TitleTextplot title text color (defaults to ImGuiCol_Text)- See Also:
-
InlayText
public static final int InlayTextcolor of text appearing inside of plots (defaults to ImGuiCol_Text)- See Also:
-
AxisText
public static final int AxisTextaxis label and tick labels color (defaults to ImGuiCol_Text)- See Also:
-
AxisGrid
public static final int AxisGridaxis grid color (defaults to 25% ImPlotCol_AxisText)- See Also:
-
AxisTick
public static final int AxisTickaxis tick color (defaults to AxisGrid)- See Also:
-
AxisBg
public static final int AxisBgbackground color of axis hover region (defaults to transparent)- See Also:
-
AxisBgHovered
public static final int AxisBgHoveredaxis hover color (defaults to ImGuiCol_ButtonHovered)- See Also:
-
AxisBgActive
public static final int AxisBgActiveaxis active color (defaults to ImGuiCol_ButtonActive)- See Also:
-
Selection
public static final int Selectionbox-selection color (defaults to yellow)- See Also:
-
Crosshairs
public static final int Crosshairscrosshairs color (defaults to ImPlotCol_PlotBorder)- See Also:
-
COUNT
public static final int COUNT- See Also:
-