Class ImPlotFlags

java.lang.Object
imgui.extension.implot.flag.ImPlotFlags

public final class ImPlotFlags extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Definition: ImPlotFlags_NoTitle | ImPlotFlags_NoLegend | ImPlotFlags_NoMenus | ImPlotFlags_NoBoxSelect | ImPlotFlags_NoMouseText
    static final int
    the default mouse cursor will be replaced with a crosshair when hovered
    static final int
    x and y axes pairs will be constrained to have the same units/pixel
    static final int
    the user will not be able to box-select
    static final int
    the ImGui frame will not be rendered
    static final int
    the user will not be able to interact with the plot
    static final int
    the legend will not be displayed
    static final int
    the user will not be able to open context menus
    static final int
    the mouse position, in plot coordinates, will not be displayed inside of the plot
    static final int
    default
    static final int
    the plot title will not be displayed (titles are also hidden if preceded by double hashes, e.g.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      default

      Definition: 0

      See Also:
    • NoTitle

      public static final int NoTitle
      the plot title will not be displayed (titles are also hidden if preceded by double hashes, e.g. "##MyPlot")

      Definition: 1 << 0

      See Also:
    • NoLegend

      public static final int NoLegend
      the legend will not be displayed

      Definition: 1 << 1

      See Also:
    • NoMouseText

      public static final int NoMouseText
      the mouse position, in plot coordinates, will not be displayed inside of the plot

      Definition: 1 << 2

      See Also:
    • NoInputs

      public static final int NoInputs
      the user will not be able to interact with the plot

      Definition: 1 << 3

      See Also:
    • NoMenus

      public static final int NoMenus
      the user will not be able to open context menus

      Definition: 1 << 4

      See Also:
    • NoBoxSelect

      public static final int NoBoxSelect
      the user will not be able to box-select

      Definition: 1 << 5

      See Also:
    • NoFrame

      public static final int NoFrame
      the ImGui frame will not be rendered

      Definition: 1 << 6

      See Also:
    • Equal

      public static final int Equal
      x and y axes pairs will be constrained to have the same units/pixel

      Definition: 1 << 7

      See Also:
    • Crosshairs

      public static final int Crosshairs
      the default mouse cursor will be replaced with a crosshair when hovered

      Definition: 1 << 8

      See Also:
    • CanvasOnly

      public static final int CanvasOnly
      Definition: ImPlotFlags_NoTitle | ImPlotFlags_NoLegend | ImPlotFlags_NoMenus | ImPlotFlags_NoBoxSelect | ImPlotFlags_NoMouseText
      See Also: