Class ImPlotHistogramFlags

java.lang.Object
imgui.extension.implot.flag.ImPlotHistogramFlags

public final class ImPlotHistogramFlags extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    data will be read in column major order (not supported by PlotHistogram)
    static final int
    each bin will contain its count plus the counts of all previous bins (not supported by PlotHistogram2D)
    static final int
    counts will be normalized, i.e.
    static final int
    histogram bars will be rendered horizontally (not supported by PlotHistogram2D)
    static final int
    default
    static final int
    exclude values outside the specified histogram range from the count toward normalizing and cumulative counts
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      default

      Definition: 0

      See Also:
    • Horizontal

      public static final int Horizontal
      histogram bars will be rendered horizontally (not supported by PlotHistogram2D)

      Definition: 1 << 10

      See Also:
    • Cumulative

      public static final int Cumulative
      each bin will contain its count plus the counts of all previous bins (not supported by PlotHistogram2D)

      Definition: 1 << 11

      See Also:
    • Density

      public static final int Density
      counts will be normalized, i.e. the PDF will be visualized, or the CDF will be visualized if Cumulative is also set

      Definition: 1 << 12

      See Also:
    • NoOutliers

      public static final int NoOutliers
      exclude values outside the specified histogram range from the count toward normalizing and cumulative counts

      Definition: 1 << 13

      See Also:
    • ColMajor

      public static final int ColMajor
      data will be read in column major order (not supported by PlotHistogram)

      Definition: 1 << 14

      See Also: