Class ImPlotLineFlags

java.lang.Object
imgui.extension.implot.flag.ImPlotLineFlags

public final class ImPlotLineFlags extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    the last and first point will be connected to form a closed loop
    static final int
    markers (if displayed) on the edge of a plot will not be clipped
    static final int
    default
    static final int
    a line segment will be rendered from every two consecutive points
    static final int
    a filled region between the line and horizontal origin will be rendered; use PlotShaded for more advanced cases
    static final int
    NaNs values will be skipped instead of rendered as missing data
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      default

      Definition: 0

      See Also:
    • Segments

      public static final int Segments
      a line segment will be rendered from every two consecutive points

      Definition: 1 << 10

      See Also:
    • Loop

      public static final int Loop
      the last and first point will be connected to form a closed loop

      Definition: 1 << 11

      See Also:
    • SkipNaN

      public static final int SkipNaN
      NaNs values will be skipped instead of rendered as missing data

      Definition: 1 << 12

      See Also:
    • NoClip

      public static final int NoClip
      markers (if displayed) on the edge of a plot will not be clipped

      Definition: 1 << 13

      See Also:
    • Shaded

      public static final int Shaded
      a filled region between the line and horizontal origin will be rendered; use PlotShaded for more advanced cases

      Definition: 1 << 14

      See Also: