Class ImPlotStyleVar

java.lang.Object
imgui.extension.implot.flag.ImPlotStyleVar

public final class ImPlotStyleVar extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    ImVec2, text padding around annotation labels
    static final int
     
    static final int
    float, digital plot padding from bottom in pixels
    static final int
    float, digital plot spacing gap in pixels
    static final int
    ImVec2, additional fit padding as a percentage of the fit extents (e.g.
    static final int
    ImVec2, padding between axes labels, tick labels, and plot edge
    static final int
    ImVec2, legend inner padding from legend edges
    static final int
    ImVec2, legend padding from plot edges
    static final int
    ImVec2, spacing between legend entries
    static final int
    ImVec2, line thickness of major grid lines
    static final int
    ImVec2, major tick lengths for X and Y axes
    static final int
    ImVec2, line thickness of major ticks
    static final int
    float, alpha multiplier applied to minor axis grid lines
    static final int
    ImVec2, line thickness of minor grid lines
    static final int
    ImVec2, minor tick lengths for X and Y axes
    static final int
    ImVec2, line thickness of minor ticks
    static final int
    ImVec2, padding between plot edge and interior info text
    static final int
    float, thickness of border around plot area
    static final int
    ImVec2, default size used when ImVec2(0,0) is passed to BeginPlot
    static final int
    ImVec2, minimum size plot frame can be when shrunk
    static final int
    ImVec2, padding between widget frame and plot area, labels, or outside legends (i.e.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • PlotDefaultSize

      public static final int PlotDefaultSize
      ImVec2, default size used when ImVec2(0,0) is passed to BeginPlot
      See Also:
    • PlotMinSize

      public static final int PlotMinSize
      ImVec2, minimum size plot frame can be when shrunk
      See Also:
    • PlotBorderSize

      public static final int PlotBorderSize
      float, thickness of border around plot area
      See Also:
    • MinorAlpha

      public static final int MinorAlpha
      float, alpha multiplier applied to minor axis grid lines
      See Also:
    • MajorTickLen

      public static final int MajorTickLen
      ImVec2, major tick lengths for X and Y axes
      See Also:
    • MinorTickLen

      public static final int MinorTickLen
      ImVec2, minor tick lengths for X and Y axes
      See Also:
    • MajorTickSize

      public static final int MajorTickSize
      ImVec2, line thickness of major ticks
      See Also:
    • MinorTickSize

      public static final int MinorTickSize
      ImVec2, line thickness of minor ticks
      See Also:
    • MajorGridSize

      public static final int MajorGridSize
      ImVec2, line thickness of major grid lines
      See Also:
    • MinorGridSize

      public static final int MinorGridSize
      ImVec2, line thickness of minor grid lines
      See Also:
    • PlotPadding

      public static final int PlotPadding
      ImVec2, padding between widget frame and plot area, labels, or outside legends (i.e. main padding)
      See Also:
    • LabelPadding

      public static final int LabelPadding
      ImVec2, padding between axes labels, tick labels, and plot edge
      See Also:
    • LegendPadding

      public static final int LegendPadding
      ImVec2, legend padding from plot edges
      See Also:
    • LegendInnerPadding

      public static final int LegendInnerPadding
      ImVec2, legend inner padding from legend edges
      See Also:
    • LegendSpacing

      public static final int LegendSpacing
      ImVec2, spacing between legend entries
      See Also:
    • MousePosPadding

      public static final int MousePosPadding
      ImVec2, padding between plot edge and interior info text
      See Also:
    • AnnotationPadding

      public static final int AnnotationPadding
      ImVec2, text padding around annotation labels
      See Also:
    • FitPadding

      public static final int FitPadding
      ImVec2, additional fit padding as a percentage of the fit extents (e.g. ImVec2(0.1f,0.1f) adds 10% to the fit extents of X and Y)
      See Also:
    • DigitalPadding

      public static final int DigitalPadding
      float, digital plot padding from bottom in pixels
      See Also:
    • DigitalSpacing

      public static final int DigitalSpacing
      float, digital plot spacing gap in pixels
      See Also:
    • COUNT

      public static final int COUNT
      See Also: