Package imgui.flag

Class ImDrawListFlags

java.lang.Object
imgui.flag.ImDrawListFlags

public final class ImDrawListFlags extends Object
Flags for ImDrawList. Those are set automatically by ImGui:: functions from ImGuiIO settings, and generally not manipulated directly. It is however possible to temporarily alter flags between calls to ImDrawList:: functions.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Can emit 'VtxOffset>0' to allow large meshes.
    static final int
    Enable anti-aliased edge around filled shapes (rounded rectangles, circles).
    static final int
    Enable anti-aliased lines/borders (*2 the number of triangles for 1.0f wide line or lines thin enough to be drawn using textures, otherwise *3 the number of triangles)
    static final int
    Enable anti-aliased lines/borders using textures when possible.
    static final int
    Definition: 0
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • AntiAliasedLines

      public static final int AntiAliasedLines
      Enable anti-aliased lines/borders (*2 the number of triangles for 1.0f wide line or lines thin enough to be drawn using textures, otherwise *3 the number of triangles)

      Definition: 1 << 0

      See Also:
    • AntiAliasedLinesUseTex

      public static final int AntiAliasedLinesUseTex
      Enable anti-aliased lines/borders using textures when possible. Require backend to render with bilinear filtering (NOT point/nearest filtering).

      Definition: 1 << 1

      See Also:
    • AntiAliasedFill

      public static final int AntiAliasedFill
      Enable anti-aliased edge around filled shapes (rounded rectangles, circles).

      Definition: 1 << 2

      See Also:
    • AllowVtxOffset

      public static final int AllowVtxOffset
      Can emit 'VtxOffset>0' to allow large meshes. Set when 'ImGuiBackendFlags_RendererHasVtxOffset' is enabled.

      Definition: 1 << 3

      See Also: