Package imgui.flag

Class ImFontAtlasFlags

java.lang.Object
imgui.flag.ImFontAtlasFlags

public final class ImFontAtlasFlags extends Object
Flags for ImFontAtlas build
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • NoPowerOfTwoHeight

      public static final int NoPowerOfTwoHeight
      Don't round the height to next power of two

      Definition: 1 << 0

      See Also:
    • NoMouseCursors

      public static final int NoMouseCursors
      Don't build software mouse cursors into the atlas (save a little texture memory)

      Definition: 1 << 1

      See Also:
    • NoBakedLines

      public static final int NoBakedLines
      Don't build thick line textures into the atlas (save a little texture memory, allow support for point/nearest filtering). The AntiAliasedLinesUseTex features uses them, otherwise they will be rendered using polygons (more expensive for CPU/GPU).

      Definition: 1 << 2

      See Also: