Package imgui.flag

Class ImGuiBackendFlags

java.lang.Object
imgui.flag.ImGuiBackendFlags

public final class ImGuiBackendFlags extends Object
Backend capabilities flags stored in io.BackendFlags. Set by imgui_impl_xxx or custom backend.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Backend Platform supports gamepad and currently has one connected.
    static final int
    Backend Platform supports honoring GetMouseCursor() value to change the OS cursor shape.
    static final int
    Backend Platform supports calling io.AddMouseViewportEvent() with the viewport under the mouse.
    static final int
    Backend Platform supports honoring viewport->ParentViewport/ParentViewportId value, by applying the corresponding parent/child relation at the Platform level.
    static final int
    Backend Platform supports io.WantSetMousePos requests to reposition the OS mouse position (only used if io.ConfigNavMoveSetMousePos is set).
    static final int
    Definition: 0
    static final int
    Backend Platform supports multiple viewports.
    static final int
    Backend Renderer supports ImTextureData requests to create/update/destroy textures.
    static final int
    Backend Renderer supports multiple viewports.
    static final int
    Backend Renderer supports ImDrawCmd::VtxOffset.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • HasGamepad

      public static final int HasGamepad
      Backend Platform supports gamepad and currently has one connected.

      Definition: 1 << 0

      See Also:
    • HasMouseCursors

      public static final int HasMouseCursors
      Backend Platform supports honoring GetMouseCursor() value to change the OS cursor shape.

      Definition: 1 << 1

      See Also:
    • HasSetMousePos

      public static final int HasSetMousePos
      Backend Platform supports io.WantSetMousePos requests to reposition the OS mouse position (only used if io.ConfigNavMoveSetMousePos is set).

      Definition: 1 << 2

      See Also:
    • RendererHasVtxOffset

      public static final int RendererHasVtxOffset
      Backend Renderer supports ImDrawCmd::VtxOffset. This enables output of large meshes (64K+ vertices) while still using 16-bit indices.

      Definition: 1 << 3

      See Also:
    • RendererHasTextures

      public static final int RendererHasTextures
      Backend Renderer supports ImTextureData requests to create/update/destroy textures. This enables incremental texture updates and texture reloads. See https://github.com/ocornut/imgui/blob/master/docs/BACKENDS.md for instructions on how to upgrade your custom backend.

      Definition: 1 << 4

      See Also:
    • RendererHasViewports

      public static final int RendererHasViewports
      Backend Renderer supports multiple viewports.

      Definition: 1 << 10

      See Also:
    • PlatformHasViewports

      public static final int PlatformHasViewports
      Backend Platform supports multiple viewports.

      Definition: 1 << 11

      See Also:
    • HasMouseHoveredViewport

      public static final int HasMouseHoveredViewport
      Backend Platform supports calling io.AddMouseViewportEvent() with the viewport under the mouse. IF POSSIBLE, ignore viewports with the ImGuiViewportFlags_NoInputs flag (Win32 backend, GLFW 3.30+ backend can do this, SDL backend cannot). If this cannot be done, Dear ImGui needs to use a flawed heuristic to find the viewport under.

      Definition: 1 << 12

      See Also:
    • HasParentViewport

      public static final int HasParentViewport
      Backend Platform supports honoring viewport->ParentViewport/ParentViewportId value, by applying the corresponding parent/child relation at the Platform level.

      Definition: 1 << 13

      See Also: