Package imgui.flag

Class ImGuiColorEditFlags

java.lang.Object
imgui.flag.ImGuiColorEditFlags

public final class ImGuiColorEditFlags extends Object
Flags for ColorEdit3() / ColorEdit4() / ColorPicker3() / ColorPicker4() / ColorButton()
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    ColorEdit, ColorPicker: show vertical alpha bar/gradient in picker.
    static final int
    [Internal] Masks
    static final int
    ColorEdit, ColorPicker, ColorButton: disable rendering a checkerboard background behind transparent color.
    static final int
    ColorEdit, ColorPicker, ColorButton: disable alpha in the preview,.
    static final int
    Removed in 1.91.8.
    static final int
    ColorEdit, ColorPicker, ColorButton: display half opaque / half transparent preview.
    static final int
    [Internal] Masks
    static final int
    Defaults Options.
    static final int
    [Display] // "
    static final int
    [Display] // "
    static final int
    [Internal] Masks
    static final int
    [Display] // ColorEdit: override _display_ type among RGB/HSV/Hex.
    static final int
    [DataType] // ColorEdit, ColorPicker, ColorButton: _display_ values formatted as 0.0f..1.0f floats instead of 0..255 integers.
    static final int
    (WIP) ColorEdit: Currently only disable 0.0f..1.0f limits in RGBA edition (note: you probably want to use ImGuiColorEditFlags_Float flag as well).
    static final int
    [Input] // ColorEdit, ColorPicker: input and output data in HSV format.
    static final int
    [Internal] Masks
    static final int
    [Input] // ColorEdit, ColorPicker: input and output data in RGB format.
    static final int
    ColorEdit, ColorPicker, ColorButton: ignore Alpha component (will only read 3 components from the input pointer).
    static final int
    ColorButton: disable border (which is enforced by default)
    static final int
    ColorEdit: disable rendering R/G/B/A color marker.
    static final int
    ColorEdit: disable drag and drop target/source.
    static final int
    ColorEdit, ColorPicker: disable inputs sliders/text widgets (e.g.
    static final int
    ColorEdit, ColorPicker: disable display of inline text label (the label is still forwarded to the tooltip and picker).
    static final int
    Definition: 0
    static final int
    ColorEdit: disable toggling options menu when right-clicking on inputs/small preview.
    static final int
    ColorEdit: disable picker when clicking on color square.
    static final int
    ColorPicker: disable bigger color preview on right side of the picker, use small color square preview instead.
    static final int
    ColorEdit, ColorPicker: disable color square preview next to the inputs.
    static final int
    ColorEdit, ColorPicker, ColorButton: disable tooltip when hovering the preview.
    static final int
    [Picker] // ColorPicker: bar for Hue, rectangle for Sat/Value.
    static final int
    [Picker] // ColorPicker: wheel for Hue, triangle for Sat/Value.
    static final int
    [Internal] Masks
    static final int
    [DataType] // ColorEdit, ColorPicker, ColorButton: _display_ values formatted as 0..255.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • NoAlpha

      public static final int NoAlpha
      ColorEdit, ColorPicker, ColorButton: ignore Alpha component (will only read 3 components from the input pointer).

      Definition: 1 << 1

      See Also:
    • NoPicker

      public static final int NoPicker
      ColorEdit: disable picker when clicking on color square.

      Definition: 1 << 2

      See Also:
    • NoOptions

      public static final int NoOptions
      ColorEdit: disable toggling options menu when right-clicking on inputs/small preview.

      Definition: 1 << 3

      See Also:
    • NoSmallPreview

      public static final int NoSmallPreview
      ColorEdit, ColorPicker: disable color square preview next to the inputs. (e.g. to show only the inputs)

      Definition: 1 << 4

      See Also:
    • NoInputs

      public static final int NoInputs
      ColorEdit, ColorPicker: disable inputs sliders/text widgets (e.g. to show only the small preview color square).

      Definition: 1 << 5

      See Also:
    • NoTooltip

      public static final int NoTooltip
      ColorEdit, ColorPicker, ColorButton: disable tooltip when hovering the preview.

      Definition: 1 << 6

      See Also:
    • NoLabel

      public static final int NoLabel
      ColorEdit, ColorPicker: disable display of inline text label (the label is still forwarded to the tooltip and picker).

      Definition: 1 << 7

      See Also:
    • NoSidePreview

      public static final int NoSidePreview
      ColorPicker: disable bigger color preview on right side of the picker, use small color square preview instead.

      Definition: 1 << 8

      See Also:
    • NoDragDrop

      public static final int NoDragDrop
      ColorEdit: disable drag and drop target/source. ColorButton: disable drag and drop source.

      Definition: 1 << 9

      See Also:
    • NoBorder

      public static final int NoBorder
      ColorButton: disable border (which is enforced by default)

      Definition: 1 << 10

      See Also:
    • NoColorMarkers

      public static final int NoColorMarkers
      ColorEdit: disable rendering R/G/B/A color marker. May also be disabled globally by setting style.ColorMarkerSize = 0.

      Definition: 1 << 11

      See Also:
    • AlphaOpaque

      public static final int AlphaOpaque
      ColorEdit, ColorPicker, ColorButton: disable alpha in the preview,. Contrary to _NoAlpha it may still be edited when calling ColorEdit4()/ColorPicker4(). For ColorButton() this does the same as _NoAlpha.

      Definition: 1 << 12

      See Also:
    • AlphaNoBg

      public static final int AlphaNoBg
      ColorEdit, ColorPicker, ColorButton: disable rendering a checkerboard background behind transparent color.

      Definition: 1 << 13

      See Also:
    • AlphaPreviewHalf

      public static final int AlphaPreviewHalf
      ColorEdit, ColorPicker, ColorButton: display half opaque / half transparent preview.

      Definition: 1 << 14

      See Also:
    • AlphaBar

      public static final int AlphaBar
      ColorEdit, ColorPicker: show vertical alpha bar/gradient in picker.

      Definition: 1 << 18

      See Also:
    • HDR

      public static final int HDR
      (WIP) ColorEdit: Currently only disable 0.0f..1.0f limits in RGBA edition (note: you probably want to use ImGuiColorEditFlags_Float flag as well).

      Definition: 1 << 19

      See Also:
    • DisplayRGB

      public static final int DisplayRGB
      [Display] // ColorEdit: override _display_ type among RGB/HSV/Hex. ColorPicker: select any combination using one or more of RGB/HSV/Hex.

      Definition: 1 << 20

      See Also:
    • DisplayHSV

      public static final int DisplayHSV
      [Display] // "

      Definition: 1 << 21

      See Also:
    • DisplayHex

      public static final int DisplayHex
      [Display] // "

      Definition: 1 << 22

      See Also:
    • Uint8

      public static final int Uint8
      [DataType] // ColorEdit, ColorPicker, ColorButton: _display_ values formatted as 0..255.

      Definition: 1 << 23

      See Also:
    • Float

      public static final int Float
      [DataType] // ColorEdit, ColorPicker, ColorButton: _display_ values formatted as 0.0f..1.0f floats instead of 0..255 integers. No round-trip of value via integers.

      Definition: 1 << 24

      See Also:
    • PickerHueBar

      public static final int PickerHueBar
      [Picker] // ColorPicker: bar for Hue, rectangle for Sat/Value.

      Definition: 1 << 25

      See Also:
    • PickerHueWheel

      public static final int PickerHueWheel
      [Picker] // ColorPicker: wheel for Hue, triangle for Sat/Value.

      Definition: 1 << 26

      See Also:
    • InputRGB

      public static final int InputRGB
      [Input] // ColorEdit, ColorPicker: input and output data in RGB format.

      Definition: 1 << 27

      See Also:
    • InputHSV

      public static final int InputHSV
      [Input] // ColorEdit, ColorPicker: input and output data in HSV format.

      Definition: 1 << 28

      See Also:
    • DefaultOptions_

      public static final int DefaultOptions_
      Defaults Options. You can set application defaults using SetColorEditOptions(). The intent is that you probably don't want to override them in most of your calls. Let the user choose via the option menu and/or call SetColorEditOptions() once during startup.

      Definition: ImGuiColorEditFlags_Uint8 | ImGuiColorEditFlags_DisplayRGB | ImGuiColorEditFlags_InputRGB | ImGuiColorEditFlags_PickerHueBar

      See Also:
    • AlphaMask_

      public static final int AlphaMask_
      [Internal] Masks

      Definition: ImGuiColorEditFlags_NoAlpha | ImGuiColorEditFlags_AlphaOpaque | ImGuiColorEditFlags_AlphaNoBg | ImGuiColorEditFlags_AlphaPreviewHalf

      See Also:
    • DisplayMask_

      public static final int DisplayMask_
      [Internal] Masks

      Definition: ImGuiColorEditFlags_DisplayRGB | ImGuiColorEditFlags_DisplayHSV | ImGuiColorEditFlags_DisplayHex

      See Also:
    • DataTypeMask_

      public static final int DataTypeMask_
      [Internal] Masks

      Definition: ImGuiColorEditFlags_Uint8 | ImGuiColorEditFlags_Float

      See Also:
    • PickerMask_

      public static final int PickerMask_
      [Internal] Masks

      Definition: ImGuiColorEditFlags_PickerHueWheel | ImGuiColorEditFlags_PickerHueBar

      See Also:
    • InputMask_

      public static final int InputMask_
      [Internal] Masks

      Definition: ImGuiColorEditFlags_InputRGB | ImGuiColorEditFlags_InputHSV

      See Also:
    • AlphaPreview

      public static final int AlphaPreview
      Removed in 1.91.8. This is the default now. Will display a checkerboard unless ImGuiColorEditFlags_AlphaNoBg is set.

      Definition: 0

      See Also: