Package imgui.flag

Class ImGuiConfigFlags

java.lang.Object
imgui.flag.ImGuiConfigFlags

public final class ImGuiConfigFlags extends Object
Configuration flags stored in io.ConfigFlags. Set by user/application.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Docking enable flags.
    static final int
    [moved/renamed in 1.92.0] -> use bool io.ConfigDpiScaleFonts
    static final int
    [moved/renamed in 1.92.0] -> use bool io.ConfigDpiScaleViewports
    static final int
    Application is SRGB-aware.
    static final int
    Application is using a touch screen instead of a mouse.
    static final int
    Master gamepad navigation enable flag.
    static final int
    Master keyboard navigation enable flag.
    static final int
    [moved/renamed in 1.91.4] -> use bool io.ConfigNavMoveSetMousePos
    static final int
    [moved/renamed in 1.91.4] -> use bool io.ConfigNavCaptureKeyboard
    static final int
    Instruct dear imgui to disable keyboard inputs and interactions.
    static final int
    Instruct dear imgui to disable mouse inputs and interactions.
    static final int
    Instruct backend to not alter mouse cursor shape and visibility.
    static final int
    Definition: 0
    static final int
    Viewport enable flags (require both ImGuiBackendFlags_PlatformHasViewports + ImGuiBackendFlags_RendererHasViewports set by the respective backends)
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • NoMouse

      public static final int NoMouse
      Instruct dear imgui to disable mouse inputs and interactions.

      Definition: 1 << 4

      See Also:
    • NoMouseCursorChange

      public static final int NoMouseCursorChange
      Instruct backend to not alter mouse cursor shape and visibility. Use if the backend cursor changes are interfering with yours and you don't want to use SetMouseCursor() to change mouse cursor. You may want to honor requests from imgui by reading GetMouseCursor() yourself instead.

      Definition: 1 << 5

      See Also:
    • NoKeyboard

      public static final int NoKeyboard
      Instruct dear imgui to disable keyboard inputs and interactions. This is done by ignoring keyboard events and clearing existing states.

      Definition: 1 << 6

      See Also:
    • DockingEnable

      public static final int DockingEnable
      Docking enable flags.

      Definition: 1 << 7

      See Also:
    • ViewportsEnable

      public static final int ViewportsEnable
      Viewport enable flags (require both ImGuiBackendFlags_PlatformHasViewports + ImGuiBackendFlags_RendererHasViewports set by the respective backends)

      Definition: 1 << 10

      See Also:
    • IsSRGB

      public static final int IsSRGB
      Application is SRGB-aware.

      Definition: 1 << 20

      See Also:
    • IsTouchScreen

      public static final int IsTouchScreen
      Application is using a touch screen instead of a mouse.

      Definition: 1 << 21

      See Also:
    • DpiEnableScaleFonts

      public static final int DpiEnableScaleFonts
      [moved/renamed in 1.92.0] -> use bool io.ConfigDpiScaleFonts

      Definition: 1 << 14

      See Also:
    • DpiEnableScaleViewports

      public static final int DpiEnableScaleViewports
      [moved/renamed in 1.92.0] -> use bool io.ConfigDpiScaleViewports

      Definition: 1 << 15

      See Also: