Package imgui.flag

Class ImGuiDataType

java.lang.Object
imgui.flag.ImGuiDataType

public final class ImGuiDataType extends Object
A primary data type
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    bool (provided for user convenience, not supported by scalar widgets)
    static final int
     
    static final int
    double
    static final int
    float
    static final int
    short
    static final int
    int
    static final int
    long long / __int64
    static final int
    signed char / char (with sensible compilers)
    static final int
    char* (provided for user convenience, not supported by scalar widgets)
    static final int
    unsigned short
    static final int
    unsigned int
    static final int
    unsigned long long / unsigned __int64
    static final int
    unsigned char
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait