Package imgui.flag

Class ImGuiDockNodeFlags

java.lang.Object
imgui.flag.ImGuiDockNodeFlags

public final class ImGuiDockNodeFlags extends Object
Flags for ImGui::DockSpace(), shared/inherited by child nodes. (Some flags can be applied to individual nodes directly)
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Tab bar will automatically hide when there is a single window in the dock node.
    static final int
    Don't display the dockspace node but keep it alive.
    static final int
    Renamed in 1.90
    static final int
    Disable docking over the Central Node, which will be always kept empty.
    static final int
    Disable other windows/nodes from splitting this node.
    static final int
    Definition: 0
    static final int
    Saved // Disable resizing node using the splitter/separators.
    static final int
    Renamed in 1.90
    static final int
    Disable undocking this node.
    static final int
    Enable passthru dockspace: 1) DockSpace() will render a ImGuiCol_WindowBg background covering everything excepted the Central Node when empty.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • KeepAliveOnly

      public static final int KeepAliveOnly
      Don't display the dockspace node but keep it alive. Windows docked into this dockspace node won't be undocked.

      Definition: 1 << 0

      See Also:
    • NoDockingOverCentralNode

      public static final int NoDockingOverCentralNode
      Disable docking over the Central Node, which will be always kept empty.

      Definition: 1 << 2

      See Also:
    • PassthruCentralNode

      public static final int PassthruCentralNode
      Enable passthru dockspace: 1) DockSpace() will render a ImGuiCol_WindowBg background covering everything excepted the Central Node when empty. Meaning the host window should probably use SetNextWindowBgAlpha(0.0f) prior to Begin() when using this. 2) When Central Node is empty: let inputs pass-through + won't display a DockingEmptyBg background. See demo for details.

      Definition: 1 << 3

      See Also:
    • NoDockingSplit

      public static final int NoDockingSplit
      Disable other windows/nodes from splitting this node.

      Definition: 1 << 4

      See Also:
    • NoResize

      public static final int NoResize
      Saved // Disable resizing node using the splitter/separators. Useful with programmatically setup dockspaces.

      Definition: 1 << 5

      See Also:
    • AutoHideTabBar

      public static final int AutoHideTabBar
      Tab bar will automatically hide when there is a single window in the dock node.

      Definition: 1 << 6

      See Also:
    • NoUndocking

      public static final int NoUndocking
      Disable undocking this node.

      Definition: 1 << 7

      See Also:
    • NoSplit

      public static final int NoSplit
      Renamed in 1.90

      Definition: ImGuiDockNodeFlags_NoDockingSplit

      See Also:
    • NoDockingInCentralNode

      public static final int NoDockingInCentralNode
      Renamed in 1.90

      Definition: ImGuiDockNodeFlags_NoDockingOverCentralNode

      See Also: