Package imgui.flag

Class ImGuiInputTextFlags

java.lang.Object
imgui.flag.ImGuiInputTextFlags

public final class ImGuiInputTextFlags extends Object
Flags for ImGui::InputText()
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Pressing TAB input a ' ' character into the text field
    static final int
    Overwrite mode
    static final int
    Select entire text when first taking mouse focus
    static final int
    Callback on each iteration.
    static final int
    Callback on character inputs to replace or discard them.
    static final int
    Callback on pressing TAB (for completion handling)
    static final int
    Callback on any edit.
    static final int
    Callback on pressing Up/Down arrows (for history handling)
    static final int
    Callback on buffer capacity changes request (beyond 'buf_size' parameter value), allowing the string to grow.
    static final int
    Allow 0123456789.+-* /
    static final int
    Allow 0123456789ABCDEFabcdef
    static final int
    Filter out spaces, tabs
    static final int
    Allow 0123456789.+-* /eE (Scientific notation input)
    static final int
    Turn a..z into A..Z
    static final int
    In multi-line mode: validate with Enter, add new line with Ctrl+Enter (default is opposite: validate with Ctrl+Enter, add line with Enter).
    static final int
    InputFloat(), InputInt(), InputScalar() etc.
    static final int
    When text doesn't fit, elide left side to ensure right side stays visible.
    static final int
    Return 'true' when Enter is pressed (as opposed to every time the value was modified).
    static final int
    Escape key clears content if not empty, and deactivate otherwise (contrast to default behavior of Escape to revert)
    static final int
    Disable following the cursor horizontally
    static final int
    Basic filters (also see ImGuiInputTextFlags_CallbackCharFilter)
    static final int
    Disable undo/redo.
    static final int
    InputFloat(), InputInt(), InputScalar() etc.
    static final int
    Password mode, display all characters as '*', disable copy
    static final int
    Read-only mode
    static final int
    InputTextMultiline(): word-wrap lines that are too long.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Basic filters (also see ImGuiInputTextFlags_CallbackCharFilter)

      Definition: 0

      See Also:
    • CharsDecimal

      public static final int CharsDecimal
      Allow 0123456789.+-* /

      Definition: 1 << 0

      See Also:
    • CharsHexadecimal

      public static final int CharsHexadecimal
      Allow 0123456789ABCDEFabcdef

      Definition: 1 << 1

      See Also:
    • CharsScientific

      public static final int CharsScientific
      Allow 0123456789.+-* /eE (Scientific notation input)

      Definition: 1 << 2

      See Also:
    • CharsUppercase

      public static final int CharsUppercase
      Turn a..z into A..Z

      Definition: 1 << 3

      See Also:
    • CharsNoBlank

      public static final int CharsNoBlank
      Filter out spaces, tabs

      Definition: 1 << 4

      See Also:
    • AllowTabInput

      public static final int AllowTabInput
      Pressing TAB input a ' ' character into the text field

      Definition: 1 << 5

      See Also:
    • EnterReturnsTrue

      public static final int EnterReturnsTrue
      Return 'true' when Enter is pressed (as opposed to every time the value was modified). Consider using IsItemDeactivatedAfterEdit() instead!

      Definition: 1 << 6

      See Also:
    • EscapeClearsAll

      public static final int EscapeClearsAll
      Escape key clears content if not empty, and deactivate otherwise (contrast to default behavior of Escape to revert)

      Definition: 1 << 7

      See Also:
    • CtrlEnterForNewLine

      public static final int CtrlEnterForNewLine
      In multi-line mode: validate with Enter, add new line with Ctrl+Enter (default is opposite: validate with Ctrl+Enter, add line with Enter). Note that Shift+Enter always enter a new line either way.

      Definition: 1 << 8

      See Also:
    • ReadOnly

      public static final int ReadOnly
      Read-only mode

      Definition: 1 << 9

      See Also:
    • Password

      public static final int Password
      Password mode, display all characters as '*', disable copy

      Definition: 1 << 10

      See Also:
    • AlwaysOverwrite

      public static final int AlwaysOverwrite
      Overwrite mode

      Definition: 1 << 11

      See Also:
    • AutoSelectAll

      public static final int AutoSelectAll
      Select entire text when first taking mouse focus

      Definition: 1 << 12

      See Also:
    • ParseEmptyRefVal

      public static final int ParseEmptyRefVal
      InputFloat(), InputInt(), InputScalar() etc. only: parse empty string as zero value.

      Definition: 1 << 13

      See Also:
    • DisplayEmptyRefVal

      public static final int DisplayEmptyRefVal
      InputFloat(), InputInt(), InputScalar() etc. only: when value is zero, do not display it. Generally used with ImGuiInputTextFlags_ParseEmptyRefVal.

      Definition: 1 << 14

      See Also:
    • NoHorizontalScroll

      public static final int NoHorizontalScroll
      Disable following the cursor horizontally

      Definition: 1 << 15

      See Also:
    • NoUndoRedo

      public static final int NoUndoRedo
      Disable undo/redo. Note that input text owns the text data while active, if you want to provide your own undo/redo stack you need e.g. to call ClearActiveID().

      Definition: 1 << 16

      See Also:
    • ElideLeft

      public static final int ElideLeft
      When text doesn't fit, elide left side to ensure right side stays visible. Useful for path/filenames. Single-line only!

      Definition: 1 << 17

      See Also:
    • CallbackCompletion

      public static final int CallbackCompletion
      Callback on pressing TAB (for completion handling)

      Definition: 1 << 18

      See Also:
    • CallbackHistory

      public static final int CallbackHistory
      Callback on pressing Up/Down arrows (for history handling)

      Definition: 1 << 19

      See Also:
    • CallbackAlways

      public static final int CallbackAlways
      Callback on each iteration. User code may query cursor position, modify text buffer.

      Definition: 1 << 20

      See Also:
    • CallbackCharFilter

      public static final int CallbackCharFilter
      Callback on character inputs to replace or discard them. Modify 'EventChar' to replace or discard, or return 1 in callback to discard.

      Definition: 1 << 21

      See Also:
    • CallbackResize

      public static final int CallbackResize
      Callback on buffer capacity changes request (beyond 'buf_size' parameter value), allowing the string to grow. Notify when the string wants to be resized (for string types which hold a cache of their Size). You will be provided a new BufSize in the callback and NEED to honor it. (see misc/cpp/imgui_stdlib.h for an example of using this)

      Definition: 1 << 22

      See Also:
    • CallbackEdit

      public static final int CallbackEdit
      Callback on any edit. Note that InputText() already returns true on edit + you can always use IsItemEdited(). The callback is useful to manipulate the underlying buffer while focus is active.

      Definition: 1 << 23

      See Also:
    • WordWrap

      public static final int WordWrap
      InputTextMultiline(): word-wrap lines that are too long.

      Definition: 1 << 24

      See Also: