Package imgui.flag

Class ImGuiMouseSource

java.lang.Object
imgui.flag.ImGuiMouseSource

public final class ImGuiMouseSource extends Object
Enumeration for AddMouseSourceEvent() actual source of Mouse Input data. Historically we use "Mouse" terminology everywhere to indicate pointer data, e.g. MousePos, IsMousePressed(), io.AddMousePosEvent() But that "Mouse" data can come from different source which occasionally may be useful for application to know about. You can submit a change of pointer type using io.AddMouseSourceEvent().
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
     
    static final int
    Input is coming from an actual mouse.
    static final int
    Input is coming from a pressure/magnetic pen (often used in conjunction with high-sampling rates).
    static final int
    Input is coming from a touch screen (no hovering prior to initial press, less precise initial press aiming, dual-axis wheeling possible).
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • Mouse

      public static final int Mouse
      Input is coming from an actual mouse.

      Definition: 0

      See Also:
    • TouchScreen

      public static final int TouchScreen
      Input is coming from a touch screen (no hovering prior to initial press, less precise initial press aiming, dual-axis wheeling possible).
      See Also:
    • Pen

      public static final int Pen
      Input is coming from a pressure/magnetic pen (often used in conjunction with high-sampling rates).
      See Also:
    • COUNT

      public static final int COUNT
      See Also: