Package imgui.flag

Class ImGuiSelectableFlags

java.lang.Object
imgui.flag.ImGuiSelectableFlags

public final class ImGuiSelectableFlags extends Object
Flags for ImGui::Selectable()
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Generate press events on double clicks too
    static final int
    Hit testing will allow subsequent widgets to overlap this one.
    static final int
    Cannot be selected, display grayed out text
    static final int
    Renamed in 1.91.0
    static final int
    Make the item be displayed as if it is hovered
    static final int
    Clicking this doesn't close parent popup window (overrides ImGuiItemFlags_AutoClosePopups)
    static final int
    Definition: 0
    static final int
    Auto-select when moved into, unless Ctrl is held.
    static final int
    Frame will span all columns of its container table (text will still fit in current column)
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • NoAutoClosePopups

      public static final int NoAutoClosePopups
      Clicking this doesn't close parent popup window (overrides ImGuiItemFlags_AutoClosePopups)

      Definition: 1 << 0

      See Also:
    • SpanAllColumns

      public static final int SpanAllColumns
      Frame will span all columns of its container table (text will still fit in current column)

      Definition: 1 << 1

      See Also:
    • AllowDoubleClick

      public static final int AllowDoubleClick
      Generate press events on double clicks too

      Definition: 1 << 2

      See Also:
    • Disabled

      public static final int Disabled
      Cannot be selected, display grayed out text

      Definition: 1 << 3

      See Also:
    • AllowOverlap

      public static final int AllowOverlap
      Hit testing will allow subsequent widgets to overlap this one. Require previous frame HoveredId to match before being usable. Shortcut to calling SetNextItemAllowOverlap().

      Definition: 1 << 4

      See Also:
    • Highlight

      public static final int Highlight
      Make the item be displayed as if it is hovered

      Definition: 1 << 5

      See Also:
    • SelectOnNav

      public static final int SelectOnNav
      Auto-select when moved into, unless Ctrl is held. Automatic when in a BeginMultiSelect() block.

      Definition: 1 << 6

      See Also:
    • DontClosePopups

      public static final int DontClosePopups
      Renamed in 1.91.0

      Definition: ImGuiSelectableFlags_NoAutoClosePopups

      See Also: