Package imgui.flag

Class ImGuiTableColumnFlags

java.lang.Object
imgui.flag.ImGuiTableColumnFlags

public final class ImGuiTableColumnFlags extends Object
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    TableHeadersRow() will submit an angled header row for this column.
    static final int
    Default as a hidden/disabled column.
    static final int
    Default as a sorting column.
    static final int
    Overriding/master disable flag: hide column, won't show in context menu (unlike calling TableSetColumnEnabled() which manipulates the user accessible state)
    static final int
    Ignore current Indent value when entering cell (default for columns>0).
    static final int
    Use current Indent value when entering cell (default for column 0).
    static final int
    [Internal] Combinations and masks
    static final int
    Status: is enabled == not hidden by user/api (referred to as "Hide" in _DefaultHide and _NoHide) flags.
    static final int
    Status: is hovered by mouse
    static final int
    Status: is currently part of the sort specs
    static final int
    Status: is visible == is enabled AND not clipped by scrolling.
    static final int
    Disable clipping for this column (all NoClip columns will render in a same draw command).
    static final int
    [Internal] Disable user resizing this column directly (it may however we resized indirectly from its left edge)
    static final int
    TableHeadersRow() will submit an empty label for this column.
    static final int
    Disable header text width contribution to automatic column width.
    static final int
    Disable ability to hide/disable this column.
    static final int
    Input configuration flags
    static final int
    Disable manual reordering this column, this will also prevent other columns from crossing over this column.
    static final int
    Disable manual resizing.
    static final int
    Disable ability to sort on this field (even if ImGuiTableFlags_Sortable is set on the table).
    static final int
    Disable ability to sort in the ascending direction.
    static final int
    Disable ability to sort in the descending direction.
    static final int
    Make the initial sort direction Ascending when first sorting on this column (default).
    static final int
    Make the initial sort direction Descending when first sorting on this column.
    static final int
    [Internal] Combinations and masks
    static final int
    Column will not stretch.
    static final int
    [Internal] Combinations and masks
    static final int
    Column will stretch.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Input configuration flags

      Definition: 0

      See Also:
    • Disabled

      public static final int Disabled
      Overriding/master disable flag: hide column, won't show in context menu (unlike calling TableSetColumnEnabled() which manipulates the user accessible state)

      Definition: 1 << 0

      See Also:
    • DefaultHide

      public static final int DefaultHide
      Default as a hidden/disabled column.

      Definition: 1 << 1

      See Also:
    • DefaultSort

      public static final int DefaultSort
      Default as a sorting column.

      Definition: 1 << 2

      See Also:
    • WidthStretch

      public static final int WidthStretch
      Column will stretch. Preferable with horizontal scrolling disabled (default if table sizing policy is _SizingStretchSame or _SizingStretchProp).

      Definition: 1 << 3

      See Also:
    • WidthFixed

      public static final int WidthFixed
      Column will not stretch. Preferable with horizontal scrolling enabled (default if table sizing policy is _SizingFixedFit and table is resizable).

      Definition: 1 << 4

      See Also:
    • NoResize

      public static final int NoResize
      Disable manual resizing.

      Definition: 1 << 5

      See Also:
    • NoReorder

      public static final int NoReorder
      Disable manual reordering this column, this will also prevent other columns from crossing over this column.

      Definition: 1 << 6

      See Also:
    • NoHide

      public static final int NoHide
      Disable ability to hide/disable this column.

      Definition: 1 << 7

      See Also:
    • NoClip

      public static final int NoClip
      Disable clipping for this column (all NoClip columns will render in a same draw command).

      Definition: 1 << 8

      See Also:
    • NoSort

      public static final int NoSort
      Disable ability to sort on this field (even if ImGuiTableFlags_Sortable is set on the table).

      Definition: 1 << 9

      See Also:
    • NoSortAscending

      public static final int NoSortAscending
      Disable ability to sort in the ascending direction.

      Definition: 1 << 10

      See Also:
    • NoSortDescending

      public static final int NoSortDescending
      Disable ability to sort in the descending direction.

      Definition: 1 << 11

      See Also:
    • NoHeaderLabel

      public static final int NoHeaderLabel
      TableHeadersRow() will submit an empty label for this column. Convenient for some small columns. Name will still appear in context menu or in angled headers. You may append into this cell by calling TableSetColumnIndex() right after the TableHeadersRow() call.

      Definition: 1 << 12

      See Also:
    • NoHeaderWidth

      public static final int NoHeaderWidth
      Disable header text width contribution to automatic column width.

      Definition: 1 << 13

      See Also:
    • PreferSortAscending

      public static final int PreferSortAscending
      Make the initial sort direction Ascending when first sorting on this column (default).

      Definition: 1 << 14

      See Also:
    • PreferSortDescending

      public static final int PreferSortDescending
      Make the initial sort direction Descending when first sorting on this column.

      Definition: 1 << 15

      See Also:
    • IndentEnable

      public static final int IndentEnable
      Use current Indent value when entering cell (default for column 0).

      Definition: 1 << 16

      See Also:
    • IndentDisable

      public static final int IndentDisable
      Ignore current Indent value when entering cell (default for columns>0). Indentation changes _within_ the cell will still be honored.

      Definition: 1 << 17

      See Also:
    • AngledHeader

      public static final int AngledHeader
      TableHeadersRow() will submit an angled header row for this column. Note this will add an extra row.

      Definition: 1 << 18

      See Also:
    • IsEnabled

      public static final int IsEnabled
      Status: is enabled == not hidden by user/api (referred to as "Hide" in _DefaultHide and _NoHide) flags.

      Definition: 1 << 24

      See Also:
    • IsVisible

      public static final int IsVisible
      Status: is visible == is enabled AND not clipped by scrolling.

      Definition: 1 << 25

      See Also:
    • IsSorted

      public static final int IsSorted
      Status: is currently part of the sort specs

      Definition: 1 << 26

      See Also:
    • IsHovered

      public static final int IsHovered
      Status: is hovered by mouse

      Definition: 1 << 27

      See Also:
    • WidthMask_

      public static final int WidthMask_
      [Internal] Combinations and masks

      Definition: ImGuiTableColumnFlags_WidthStretch | ImGuiTableColumnFlags_WidthFixed

      See Also:
    • IndentMask_

      public static final int IndentMask_
      [Internal] Combinations and masks

      Definition: ImGuiTableColumnFlags_IndentEnable | ImGuiTableColumnFlags_IndentDisable

      See Also:
    • StatusMask_

      public static final int StatusMask_
      [Internal] Combinations and masks

      Definition: ImGuiTableColumnFlags_IsEnabled | ImGuiTableColumnFlags_IsVisible | ImGuiTableColumnFlags_IsSorted | ImGuiTableColumnFlags_IsHovered

      See Also:
    • NoDirectResize_

      public static final int NoDirectResize_
      [Internal] Disable user resizing this column directly (it may however we resized indirectly from its left edge)

      Definition: 1 << 30

      See Also: