Package imgui.flag

Class ImGuiTreeNodeFlags

java.lang.Object
imgui.flag.ImGuiTreeNodeFlags

public final class ImGuiTreeNodeFlags extends Object
Flags for ImGui::TreeNodeEx(), ImGui::CollapsingHeader*()
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Hit testing will allow subsequent widgets to overlap this one.
    static final int
    Display a bullet instead of arrow.
    static final int
    Definition: ImGuiTreeNodeFlags_Framed | ImGuiTreeNodeFlags_NoTreePushOnOpen | ImGuiTreeNodeFlags_NoAutoOpenOnLog
    static final int
    Default node to be open
    static final int
    Horizontal lines to child nodes.
    static final int
    No lines drawn
    static final int
    Horizontal lines to child nodes.
    static final int
    Draw frame with background (e.g.
    static final int
    Use FramePadding (even for an unframed text node) to vertically align text baseline to regular widget height.
    static final int
    Label will span all columns of its container table
    static final int
    No collapsing, no arrow (use as a convenience for leaf nodes).
    static final int
    Renamed in 1.92.0
    static final int
    Nav: left arrow moves back to parent.
    static final int
    Don't automatically and temporarily open node when Logging is active (by default logging will automatically open tree nodes)
    static final int
    Definition: 0
    static final int
    Don't do a TreePush() when open (e.g.
    static final int
    Open when clicking on the arrow part (default for multi-select unless any _OpenOnXXX behavior is set explicitly).
    static final int
    Open on double-click instead of simple click (default for multi-select unless any _OpenOnXXX behavior is set explicitly).
    static final int
    Draw as selected
    static final int
    Frame will span all columns of its container table (label will still fit in current column)
    static final int
    Extend hit box to the right-most edge, even if not framed.
    static final int
    Extend hit box to the left-most and right-most edges (cover the indent area).
    static final int
    Narrow hit box + narrow hovering highlight, will only cover the label text.
    static final int
    Renamed in 1.90.7
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • Selected

      public static final int Selected
      Draw as selected

      Definition: 1 << 0

      See Also:
    • Framed

      public static final int Framed
      Draw frame with background (e.g. for CollapsingHeader)

      Definition: 1 << 1

      See Also:
    • AllowOverlap

      public static final int AllowOverlap
      Hit testing will allow subsequent widgets to overlap this one. Require previous frame HoveredId to match before being usable. Shortcut to calling SetNextItemAllowOverlap().

      Definition: 1 << 2

      See Also:
    • NoTreePushOnOpen

      public static final int NoTreePushOnOpen
      Don't do a TreePush() when open (e.g. for CollapsingHeader) = no extra indent nor pushing on ID stack

      Definition: 1 << 3

      See Also:
    • NoAutoOpenOnLog

      public static final int NoAutoOpenOnLog
      Don't automatically and temporarily open node when Logging is active (by default logging will automatically open tree nodes)

      Definition: 1 << 4

      See Also:
    • DefaultOpen

      public static final int DefaultOpen
      Default node to be open

      Definition: 1 << 5

      See Also:
    • OpenOnDoubleClick

      public static final int OpenOnDoubleClick
      Open on double-click instead of simple click (default for multi-select unless any _OpenOnXXX behavior is set explicitly). Both behaviors may be combined.

      Definition: 1 << 6

      See Also:
    • OpenOnArrow

      public static final int OpenOnArrow
      Open when clicking on the arrow part (default for multi-select unless any _OpenOnXXX behavior is set explicitly). Both behaviors may be combined.

      Definition: 1 << 7

      See Also:
    • Leaf

      public static final int Leaf
      No collapsing, no arrow (use as a convenience for leaf nodes). Note: will always open a tree/id scope and return true. If you never use that scope, add ImGuiTreeNodeFlags_NoTreePushOnOpen.

      Definition: 1 << 8

      See Also:
    • Bullet

      public static final int Bullet
      Display a bullet instead of arrow. IMPORTANT: node can still be marked open/close if you don't set the _Leaf flag!

      Definition: 1 << 9

      See Also:
    • FramePadding

      public static final int FramePadding
      Use FramePadding (even for an unframed text node) to vertically align text baseline to regular widget height. Equivalent to calling AlignTextToFramePadding() before the node.

      Definition: 1 << 10

      See Also:
    • SpanAvailWidth

      public static final int SpanAvailWidth
      Extend hit box to the right-most edge, even if not framed. This is not the default in order to allow adding other items on the same line without using AllowOverlap mode.

      Definition: 1 << 11

      See Also:
    • SpanFullWidth

      public static final int SpanFullWidth
      Extend hit box to the left-most and right-most edges (cover the indent area).

      Definition: 1 << 12

      See Also:
    • SpanLabelWidth

      public static final int SpanLabelWidth
      Narrow hit box + narrow hovering highlight, will only cover the label text.

      Definition: 1 << 13

      See Also:
    • SpanAllColumns

      public static final int SpanAllColumns
      Frame will span all columns of its container table (label will still fit in current column)

      Definition: 1 << 14

      See Also:
    • LabelSpanAllColumns

      public static final int LabelSpanAllColumns
      Label will span all columns of its container table

      Definition: 1 << 15

      See Also:
    • CollapsingHeader

      public static final int CollapsingHeader
      Definition: ImGuiTreeNodeFlags_Framed | ImGuiTreeNodeFlags_NoTreePushOnOpen | ImGuiTreeNodeFlags_NoAutoOpenOnLog
      See Also:
    • DrawLinesNone

      public static final int DrawLinesNone
      No lines drawn

      Definition: 1 << 18

      See Also:
    • DrawLinesFull

      public static final int DrawLinesFull
      Horizontal lines to child nodes. Vertical line drawn down to TreePop() position: cover full contents. Faster (for large trees).

      Definition: 1 << 19

      See Also:
    • DrawLinesToNodes

      public static final int DrawLinesToNodes
      Horizontal lines to child nodes. Vertical line drawn down to bottom-most child node. Slower (for large trees).

      Definition: 1 << 20

      See Also:
    • SpanTextWidth

      public static final int SpanTextWidth
      Renamed in 1.90.7

      Definition: ImGuiTreeNodeFlags_SpanLabelWidth

      See Also: