Package imgui.flag

Class ImGuiWindowFlags

java.lang.Object
imgui.flag.ImGuiWindowFlags

public final class ImGuiWindowFlags extends Object
Flags for ImGui::Begin()
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final int
    Resize every window to its content every frame
    static final int
    Always show horizontal scrollbar (even if ContentSize.x<Size.x)
    static final int
    Always show vertical scrollbar (even if ContentSize.y<Size.y)
    static final int
    Don't use! For internal use by BeginMenu()
    static final int
    Don't use! For internal use by BeginChild()
    static final int
    Don't use! For internal use by Begin()/NewFrame()
    static final int
    Allow horizontal scrollbar to appear (off by default).
    static final int
    Has a menu-bar
    static final int
    Don't use! For internal use by BeginPopupModal()
    static final int
    Disable drawing background color (WindowBg, etc.) and outside border.
    static final int
    Disable bringing window to front when taking focus (e.g.
    static final int
    Disable user collapsing window by double-clicking on it.
    static final int
    Definition: ImGuiWindowFlags_NoTitleBar | ImGuiWindowFlags_NoResize | ImGuiWindowFlags_NoScrollbar | ImGuiWindowFlags_NoCollapse
    static final int
    Disable docking of this window
    static final int
    Disable taking focus when transitioning from hidden to visible state
    static final int
    Definition: ImGuiWindowFlags_NoMouseInputs | ImGuiWindowFlags_NoNavInputs | ImGuiWindowFlags_NoNavFocus
    static final int
    Disable catching mouse, hovering test with pass through.
    static final int
    Disable user moving the window
    static final int
    Definition: ImGuiWindowFlags_NoNavInputs | ImGuiWindowFlags_NoNavFocus
    static final int
    No focusing toward this window with keyboard/gamepad navigation (e.g.
    static final int
    No keyboard/gamepad navigation within the window
    static final int
    Definition: 0
    static final int
    Disable user resizing with the lower-right grip
    static final int
    Never load/save settings in .ini file
    static final int
    Disable scrollbars (window can still scroll with mouse or programmatically)
    static final int
    Disable user vertically scrolling with mouse wheel.
    static final int
    Disable title-bar
    static final int
    Don't use! For internal use by BeginPopup()
    static final int
    Don't use! For internal use by BeginTooltip()
    static final int
    Display a dot next to the title.
  • Method Summary

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • None

      public static final int None
      Definition: 0
      See Also:
    • NoTitleBar

      public static final int NoTitleBar
      Disable title-bar

      Definition: 1 << 0

      See Also:
    • NoResize

      public static final int NoResize
      Disable user resizing with the lower-right grip

      Definition: 1 << 1

      See Also:
    • NoMove

      public static final int NoMove
      Disable user moving the window

      Definition: 1 << 2

      See Also:
    • NoScrollbar

      public static final int NoScrollbar
      Disable scrollbars (window can still scroll with mouse or programmatically)

      Definition: 1 << 3

      See Also:
    • NoScrollWithMouse

      public static final int NoScrollWithMouse
      Disable user vertically scrolling with mouse wheel. On child window, mouse wheel will be forwarded to the parent unless NoScrollbar is also set.

      Definition: 1 << 4

      See Also:
    • NoCollapse

      public static final int NoCollapse
      Disable user collapsing window by double-clicking on it. Also referred to as Window Menu Button (e.g. within a docking node).

      Definition: 1 << 5

      See Also:
    • AlwaysAutoResize

      public static final int AlwaysAutoResize
      Resize every window to its content every frame

      Definition: 1 << 6

      See Also:
    • NoBackground

      public static final int NoBackground
      Disable drawing background color (WindowBg, etc.) and outside border. Similar as using SetNextWindowBgAlpha(0.0f).

      Definition: 1 << 7

      See Also:
    • NoSavedSettings

      public static final int NoSavedSettings
      Never load/save settings in .ini file

      Definition: 1 << 8

      See Also:
    • NoMouseInputs

      public static final int NoMouseInputs
      Disable catching mouse, hovering test with pass through.

      Definition: 1 << 9

      See Also:
    • HorizontalScrollbar

      public static final int HorizontalScrollbar
      Allow horizontal scrollbar to appear (off by default). You may use SetNextWindowContentSize(ImVec2(width,0.0f)); prior to calling Begin() to specify width. Read code in imgui_demo in the "Horizontal Scrolling" section.

      Definition: 1 << 11

      See Also:
    • NoFocusOnAppearing

      public static final int NoFocusOnAppearing
      Disable taking focus when transitioning from hidden to visible state

      Definition: 1 << 12

      See Also:
    • NoBringToFrontOnFocus

      public static final int NoBringToFrontOnFocus
      Disable bringing window to front when taking focus (e.g. clicking on it or programmatically giving it focus)

      Definition: 1 << 13

      See Also:
    • AlwaysVerticalScrollbar

      public static final int AlwaysVerticalScrollbar
      Always show vertical scrollbar (even if ContentSize.y<Size.y)

      Definition: 1 << 14

      See Also:
    • AlwaysHorizontalScrollbar

      public static final int AlwaysHorizontalScrollbar
      Always show horizontal scrollbar (even if ContentSize.x<Size.x)

      Definition: 1<< 15

      See Also:
    • NoNavInputs

      public static final int NoNavInputs
      No keyboard/gamepad navigation within the window

      Definition: 1 << 16

      See Also:
    • NoNavFocus

      public static final int NoNavFocus
      No focusing toward this window with keyboard/gamepad navigation (e.g. skipped by Ctrl+Tab)

      Definition: 1 << 17

      See Also:
    • UnsavedDocument

      public static final int UnsavedDocument
      Display a dot next to the title. When used in a tab/docking context, tab is selected when clicking the X + closure is not assumed (will wait for user to stop submitting the tab). Otherwise closure is assumed when pressing the X, so if you keep submitting the tab may reappear at end of tab bar.

      Definition: 1 << 18

      See Also:
    • NoDocking

      public static final int NoDocking
      Disable docking of this window

      Definition: 1 << 19

      See Also:
    • NoNav

      public static final int NoNav
      Definition: ImGuiWindowFlags_NoNavInputs | ImGuiWindowFlags_NoNavFocus
      See Also:
    • NoDecoration

      public static final int NoDecoration
      Definition: ImGuiWindowFlags_NoTitleBar | ImGuiWindowFlags_NoResize | ImGuiWindowFlags_NoScrollbar | ImGuiWindowFlags_NoCollapse
      See Also:
    • NoInputs

      public static final int NoInputs
      Definition: ImGuiWindowFlags_NoMouseInputs | ImGuiWindowFlags_NoNavInputs | ImGuiWindowFlags_NoNavFocus
      See Also:
    • DockNodeHost

      public static final int DockNodeHost
      Don't use! For internal use by Begin()/NewFrame()

      Definition: 1 << 23

      See Also:
    • ChildWindow

      public static final int ChildWindow
      Don't use! For internal use by BeginChild()

      Definition: 1 << 24

      See Also:
    • Tooltip

      public static final int Tooltip
      Don't use! For internal use by BeginTooltip()

      Definition: 1 << 25

      See Also:
    • ChildMenu

      public static final int ChildMenu
      Don't use! For internal use by BeginMenu()

      Definition: 1 << 28

      See Also: