Package imgui.flag
package imgui.flag
-
ClassesClassDescriptionFlags for ImDrawList functionsFlags for ImDrawList.Flags for ImFontAtlas buildBackend capabilities flags stored in io.BackendFlags.Flags for ImGui::BeginChild() (Legacy: bit 0 must always correspond to ImGuiChildFlags_Border to be backward compatible with old API using 'bool border = false'.Enumeration for PushStyleColor() / PopStyleColor()Flags for ColorEdit3() / ColorEdit4() / ColorPicker3() / ColorPicker4() / ColorButton()Flags for ImGui::BeginCombo()Enumeration for ImGui::SetWindow***(), SetNextWindow***(), SetNextItem***() functions Represent a condition.Configuration flags stored in io.ConfigFlags.A primary data typeA cardinal directionFlags for ImGui::DockSpace(), shared/inherited by child nodes.Flags for ImGui::BeginDragDropSource(), ImGui::AcceptDragDropPayload()Flags for ImGui::IsWindowFocused()Renamed from
ImGuiFreeTypeBuilderFlagsin imgui 1.92.Flags for ImGui::IsItemHovered(), ImGui::IsWindowHovered() Note:if you are trying to check whether your mouse should be dispatched to Dear ImGui or to your app, you should use'io.WantCaptureMouse'instead!Please read the FAQ!Note: windows with the ImGuiWindowFlags_NoInputs flag are ignored by IsWindowHovered() calls.Flags for ImGui::InputText()A key identifier (ImGuiKey_XXX or ImGuiMod_XXX value): can represent Keyboard, Mouse and Gamepad values.Identify a mouse button.Enumeration for GetMouseCursor() User code may request binding to display given cursor by calling SetMouseCursor(), which is why we have some cursors that are marked unused hereEnumeration for AddMouseSourceEvent() actual source of Mouse Input data.Flags for OpenPopup*(), BeginPopupContext*(), IsPopupOpen() functions.Flags for ImGui::Selectable()A sorting directionEnumeration for PushStyleVar() / PopStyleVar() to temporarily modify the ImGuiStyle structure.Flags for ImGui::BeginTabBar()Flags for ImGui::BeginTabItem()Enum for ImGui::TableSetBgColor() Background colors are rendering in 3 layers: - Layer 0: draw with RowBg0 color if set, otherwise draw with ColumnBg0 if set.Flags forImGui.tableSetupColumn(String, int)Flags for ImGui::BeginTable() [BETA API] API may evolve slightly! If you use this, please update to the next version when it comes out! - Important! Sizing policies have complex and subtle side effects, more so than you would expect.Flags forImGui.tableNextRow(int)Flags for ImGui::TreeNodeEx(), ImGui::CollapsingHeader*()Flags stored in ImGuiViewport::Flags, giving indications to the platform backends.Flags for ImGui::Begin()