Package imgui


package imgui
  • Classes
    Class
    Description
    Helper class to get ABGR packed color used by Dear ImGui.
    All draw data to render Dear ImGui frame (NB: the style and the naming convention here is a little inconsistent, we currently preserve them for backward compatibility purpose, as this is one of the oldest structure exposed by the library! Basically, ImDrawList == CmdList)
    Draw command list This is the low-level list of polygons that ImGui:: functions are filling.
    Font runtime data.
    Load and rasterize multiple TTF/OTF fonts into a same texture.
     
    Hold rendering data for one glyph.
    Helper to build glyph ranges from text/string data.
     
    Shared state of InputText(), passed as an argument to your callback when a ImGuiInputTextFlags_Callback* flag is used.
    Communicate most settings and inputs/outputs to Dear ImGui using this structure.
    [Internal] Storage used by IsKeyDown(), IsKeyPressed() etc functions.
    Helper: Manually clip large list of items.
    Helper: Execute a block of code at maximum once a frame.
    ----------------------------------------------------------------------------- [BETA] Platform interface for multi-viewport support ----------------------------------------------------------------------------- (Optional) This is completely optional, for advanced users! If you are new to Dear ImGui and trying to integrate it into your engine, you can probably ignore this for now.
    (Optional) This is required when enabling multi-viewport.
    Helper: Key-Value storage Typically you don't have to worry about this since a storage is held within each Window.
    You may modify the ImGui::GetStyle() main instance during initialization and before NewFrame().
    Sorting specification for one column of a table.
    Sorting specifications for a table (often handling sort specs for a single column, occasionally more) Obtained by calling TableGetSortSpecs().
    Helper: Parse and apply text filters.
    The viewports created and managed by Dear ImGui.
    [ALPHA] Rarely used / very advanced uses only.
    2D vector (often used to store positions or sizes).
    4D vector (often used to store floating-point colors).