Package imgui
Class ImGuiPlatformMonitor
java.lang.Object
imgui.binding.ImGuiStruct
imgui.ImGuiPlatformMonitor
(Optional) This is required when enabling multi-viewport. Represent the bounds of each connected monitor/display and their DPI.
We use this information for multiple DPI support + clamping the position of popups and tooltips so they don't straddle multiple monitors.
-
Field Summary
Fields inherited from class imgui.binding.ImGuiStruct
ptr -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfloat1.0f = 96 DPICoordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidgetMainPos(ImVec2 dst) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)floatCoordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)floatCoordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidgetMainSize(ImVec2 dst) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)floatCoordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)floatCoordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)longBackend dependant data (e.g.Coordinates without task bars / side bars / menu bars.voidgetWorkPos(ImVec2 dst) Coordinates without task bars / side bars / menu bars.floatCoordinates without task bars / side bars / menu bars.floatCoordinates without task bars / side bars / menu bars.Coordinates without task bars / side bars / menu bars.voidgetWorkSize(ImVec2 dst) Coordinates without task bars / side bars / menu bars.floatCoordinates without task bars / side bars / menu bars.floatCoordinates without task bars / side bars / menu bars.voidsetDpiScale(float value) 1.0f = 96 DPIvoidsetMainPos(float valueX, float valueY) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidsetMainPos(ImVec2 value) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidsetMainSize(float valueX, float valueY) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidsetMainSize(ImVec2 value) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right)voidsetPlatformHandle(long platformHandle) Backend dependant data (e.g.voidsetWorkPos(float valueX, float valueY) Coordinates without task bars / side bars / menu bars.voidsetWorkPos(ImVec2 value) Coordinates without task bars / side bars / menu bars.voidsetWorkSize(float valueX, float valueY) Coordinates without task bars / side bars / menu bars.voidsetWorkSize(ImVec2 value) Coordinates without task bars / side bars / menu bars.Methods inherited from class imgui.binding.ImGuiStruct
isNotValidPtr, isValidPtr
-
Constructor Details
-
ImGuiPlatformMonitor
public ImGuiPlatformMonitor(long ptr)
-
-
Method Details
-
getMainPos
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainPosX
public float getMainPosX()Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainPosY
public float getMainPosY()Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainPos
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
setMainPos
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
setMainPos
public void setMainPos(float valueX, float valueY) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainSize
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainSizeX
public float getMainSizeX()Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainSizeY
public float getMainSizeY()Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getMainSize
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
setMainSize
Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
setMainSize
public void setMainSize(float valueX, float valueY) Coordinates of the area displayed on this monitor (Min = upper left, Max = bottom right) -
getWorkPos
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkPosX
public float getWorkPosX()Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkPosY
public float getWorkPosY()Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkPos
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
setWorkPos
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
setWorkPos
public void setWorkPos(float valueX, float valueY) Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkSize
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkSizeX
public float getWorkSizeX()Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkSizeY
public float getWorkSizeY()Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getWorkSize
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
setWorkSize
Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
setWorkSize
public void setWorkSize(float valueX, float valueY) Coordinates without task bars / side bars / menu bars. Used to avoid positioning popups/tooltips inside this region. If you don't have this info, please copy the value for MainPos/MainSize. -
getDpiScale
public float getDpiScale()1.0f = 96 DPI -
setDpiScale
public void setDpiScale(float value) 1.0f = 96 DPI -
setPlatformHandle
public void setPlatformHandle(long platformHandle) Backend dependant data (e.g. HMONITOR, GLFWmonitor*, SDL Display Index, NSScreen*) -
getPlatformHandle
public long getPlatformHandle()Backend dependant data (e.g. HMONITOR, GLFWmonitor*, SDL Display Index, NSScreen*)
-