Package imgui
Class ImGuiStyle
You may modify the ImGui::GetStyle() main instance during initialization and before NewFrame().
During the frame, use ImGui::PushStyleVar(ImGuiStyleVar_XXXX)/PopStyleVar() to alter the main style values,
and ImGui::PushStyleColor(ImGuiCol_XXX)/PopStyleColor() for colors.
-
Field Summary
Fields inherited from class imgui.binding.ImGuiStruct
ptr -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidaddTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92).protected longcreate()floatgetAlpha()Global alpha applies to everything in Dear ImGui.booleanEnable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.).booleanEnable anti-aliased lines/borders.booleanEnable anti-aliased lines/borders using textures where possible.Alignment of button text when button is larger than text.voidgetButtonTextAlign(ImVec2 dst) Alignment of button text when button is larger than text.floatAlignment of button text when button is larger than text.floatAlignment of button text when button is larger than text.Padding within a table cell.voidgetCellPadding(ImVec2 dst) Padding within a table cell.floatPadding within a table cell.floatPadding within a table cell.floatThickness of border around child windows.floatRadius of child window corners rounding.floatMaximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified.getColor(int col) voidintSide of the color button in the ColorEdit4 widget (left/right).floatSize of R/G/B/A color markers forColorEdit4()and for Drags/Sliders when usingImGuiSliderFlags_ColorMarkers(since imgui 1.92.7).ImVec4[]floatMinimum horizontal spacing between two columns.floatTessellation tolerance when using PathBezierCurveTo() without a specific number of segments.floatAdditional alpha multiplier applied by BeginDisabled().If you cannot see the edges of your screen (e.g.voidIf you cannot see the edges of your screen (e.g.floatIf you cannot see the edges of your screen (e.g.floatIf you cannot see the edges of your screen (e.g.Window position are clamped to be visible within the display area by at least this amount.voidWindow position are clamped to be visible within the display area by at least this amount.floatWindow position are clamped to be visible within the display area by at least this amount.floatWindow position are clamped to be visible within the display area by at least this amount.floatThickness of resizing border between docked windowsfloatAdditional global scale factor from viewport/monitor contents scale (since imgui 1.92).floatMain global scale factor applied on top of font size.floatThickness of border around frames.Padding within a framed rectangle (used by most widgets).voidgetFramePadding(ImVec2 dst) Padding within a framed rectangle (used by most widgets).floatPadding within a framed rectangle (used by most widgets).floatPadding within a framed rectangle (used by most widgets).floatRadius of frame corners rounding.floatMinimum width/height of a grab box for slider/scrollbar.floatRadius of grabs corners rounding.floatDelay for IsItemHovered(ImGuiHoveredFlags_DelayNormal).floatDelay for IsItemHovered(ImGuiHoveredFlags_DelayShort).intDefault flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse.intDefault flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using keyboard/gamepad.floatDelay for IsItemHovered(ImGuiHoveredFlags_Stationary).floatThickness of border around Image() calls (since imgui 1.92).floatRounding of Image() calls (since imgui 1.92).floatHorizontal indentation when e.g.Horizontal and vertical spacing between within elements of a composed widget (e.g.voidHorizontal and vertical spacing between within elements of a composed widget (e.g.floatHorizontal and vertical spacing between within elements of a composed widget (e.g.floatHorizontal and vertical spacing between within elements of a composed widget (e.g.Horizontal and vertical spacing between widgets/lines.voidgetItemSpacing(ImVec2 dst) Horizontal and vertical spacing between widgets/lines.floatHorizontal and vertical spacing between widgets/lines.floatHorizontal and vertical spacing between widgets/lines.floatThe size in pixels of the dead-zone around zero on logarithmic sliders that cross zero.floatScale software rendered mouse cursor (when io.MouseDrawCursor is enabled).floatThickness of border around popup/tooltip windows.floatRadius of popup window corners rounding.floatRadius of grab corners for scrollbar.floatWidth of the vertical scrollbar, Height of the horizontal scrollbar.Alignment of selectable text.voidAlignment of selectable text.floatAlignment of selectable text.floatAlignment of selectable text.floatThickness of the separator line rendered by Separator() (new in imgui 1.92.7).Alignment of text within the separator.voidAlignment of text within the separator.floatAlignment of text within the separator.floatAlignment of text within the separator.floatThickkness of border in SeparatorText()Horizontal offset of text from each edge of the separator + spacing on other axis.voidHorizontal offset of text from each edge of the separator + spacing on other axis.floatHorizontal offset of text from each edge of the separator + spacing on other axis.floatHorizontal offset of text from each edge of the separator + spacing on other axis.floatThickness of border around tabs.floatMinimum width for close button to appear on a selected tab when hovered.floatMinimum width for close button to appear on an unselected tab when hovered.floatRadius of upper corners of a tab.Expand reactive bounding box for touch-based system where touch position is not accurate enough.voidExpand reactive bounding box for touch-based system where touch position is not accurate enough.floatExpand reactive bounding box for touch-based system where touch position is not accurate enough.floatExpand reactive bounding box for touch-based system where touch position is not accurate enough.intDefault way to draw lines connecting TreeNode hierarchy (since imgui 1.92).floatRadius of lines connecting child nodes to the vertical line (since imgui 1.92).floatThickness of outlines when usingImGuiTreeNodeFlags_DrawLines(since imgui 1.92).floatThickness of border around windows.intSide of the collapsing/docking button in the title bar (None/Left/Right).Minimum window size.voidgetWindowMinSize(ImVec2 dst) Minimum window size.floatMinimum window size.floatMinimum window size.Padding within a window.voidgetWindowPadding(ImVec2 dst) Padding within a window.floatPadding within a window.floatPadding within a window.floatRadius of window corners rounding.Alignment for title bar text.voidAlignment for title bar text.floatAlignment for title bar text.floatAlignment for title bar text.booleanhasTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92).voidremoveTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92).voidscaleAllSizes(float scaleFactor) voidsetAlpha(float value) Global alpha applies to everything in Dear ImGui.voidsetAntiAliasedFill(boolean value) Enable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.).voidsetAntiAliasedLines(boolean value) Enable anti-aliased lines/borders.voidsetAntiAliasedLinesUseTex(boolean value) Enable anti-aliased lines/borders using textures where possible.voidsetButtonTextAlign(float valueX, float valueY) Alignment of button text when button is larger than text.voidsetButtonTextAlign(ImVec2 value) Alignment of button text when button is larger than text.voidsetCellPadding(float valueX, float valueY) Padding within a table cell.voidsetCellPadding(ImVec2 value) Padding within a table cell.voidsetChildBorderSize(float value) Thickness of border around child windows.voidsetChildRounding(float value) Radius of child window corners rounding.voidsetCircleTessellationMaxError(float value) Maximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified.voidsetColor(int col, float r, float g, float b, float a) voidsetColor(int col, int value) voidsetColor(int col, int r, int g, int b, int a) voidsetColorButtonPosition(int value) Side of the color button in the ColorEdit4 widget (left/right).voidsetColorMarkerSize(float value) Size of R/G/B/A color markers forColorEdit4()and for Drags/Sliders when usingImGuiSliderFlags_ColorMarkers(since imgui 1.92.7).voidvoidsetColumnsMinSpacing(float value) Minimum horizontal spacing between two columns.voidsetCurveTessellationTol(float value) Tessellation tolerance when using PathBezierCurveTo() without a specific number of segments.voidsetDisabledAlpha(float value) Additional alpha multiplier applied by BeginDisabled().voidsetDisplaySafeAreaPadding(float valueX, float valueY) If you cannot see the edges of your screen (e.g.voidsetDisplaySafeAreaPadding(ImVec2 value) If you cannot see the edges of your screen (e.g.voidsetDisplayWindowPadding(float valueX, float valueY) Window position are clamped to be visible within the display area by at least this amount.voidsetDisplayWindowPadding(ImVec2 value) Window position are clamped to be visible within the display area by at least this amount.voidsetDockingSeparatorSize(float value) Thickness of resizing border between docked windowsvoidsetFontScaleDpi(float value) Additional global scale factor from viewport/monitor contents scale (since imgui 1.92).voidsetFontScaleMain(float value) Main global scale factor applied on top of font size.voidsetFrameBorderSize(float value) Thickness of border around frames.voidsetFramePadding(float valueX, float valueY) Padding within a framed rectangle (used by most widgets).voidsetFramePadding(ImVec2 value) Padding within a framed rectangle (used by most widgets).voidsetFrameRounding(float value) Radius of frame corners rounding.voidsetGrabMinSize(float value) Minimum width/height of a grab box for slider/scrollbar.voidsetGrabRounding(float value) Radius of grabs corners rounding.voidsetHoverDelayNormal(float value) Delay for IsItemHovered(ImGuiHoveredFlags_DelayNormal).voidsetHoverDelayShort(float value) Delay for IsItemHovered(ImGuiHoveredFlags_DelayShort).voidsetHoverFlagsForTooltipMouse(int value) Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse.voidsetHoverFlagsForTooltipNav(int value) Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using keyboard/gamepad.voidsetHoverStationaryDelay(float value) Delay for IsItemHovered(ImGuiHoveredFlags_Stationary).voidsetImageBorderSize(float value) Thickness of border around Image() calls (since imgui 1.92).voidsetImageRounding(float value) Rounding of Image() calls (since imgui 1.92).voidsetIndentSpacing(float value) Horizontal indentation when e.g.voidsetItemInnerSpacing(float valueX, float valueY) Horizontal and vertical spacing between within elements of a composed widget (e.g.voidsetItemInnerSpacing(ImVec2 value) Horizontal and vertical spacing between within elements of a composed widget (e.g.voidsetItemSpacing(float valueX, float valueY) Horizontal and vertical spacing between widgets/lines.voidsetItemSpacing(ImVec2 value) Horizontal and vertical spacing between widgets/lines.voidsetLogSliderDeadzone(float value) The size in pixels of the dead-zone around zero on logarithmic sliders that cross zero.voidsetMouseCursorScale(float value) Scale software rendered mouse cursor (when io.MouseDrawCursor is enabled).voidsetPopupBorderSize(float value) Thickness of border around popup/tooltip windows.voidsetPopupRounding(float value) Radius of popup window corners rounding.voidsetScrollbarRounding(float value) Radius of grab corners for scrollbar.voidsetScrollbarSize(float value) Width of the vertical scrollbar, Height of the horizontal scrollbar.voidsetSelectableTextAlign(float valueX, float valueY) Alignment of selectable text.voidsetSelectableTextAlign(ImVec2 value) Alignment of selectable text.voidsetSeparatorSize(float value) Thickness of the separator line rendered by Separator() (new in imgui 1.92.7).voidsetSeparatorTextAlign(float valueX, float valueY) Alignment of text within the separator.voidsetSeparatorTextAlign(ImVec2 value) Alignment of text within the separator.voidsetSeparatorTextBorderSize(float value) Thickkness of border in SeparatorText()voidsetSeparatorTextPadding(float valueX, float valueY) Horizontal offset of text from each edge of the separator + spacing on other axis.voidsetSeparatorTextPadding(ImVec2 value) Horizontal offset of text from each edge of the separator + spacing on other axis.voidsetTabBorderSize(float value) Thickness of border around tabs.voidsetTabCloseButtonMinWidthSelected(float value) Minimum width for close button to appear on a selected tab when hovered.voidsetTabCloseButtonMinWidthUnselected(float value) Minimum width for close button to appear on an unselected tab when hovered.voidsetTabRounding(float value) Radius of upper corners of a tab.voidsetTouchExtraPadding(float valueX, float valueY) Expand reactive bounding box for touch-based system where touch position is not accurate enough.voidsetTouchExtraPadding(ImVec2 value) Expand reactive bounding box for touch-based system where touch position is not accurate enough.voidsetTreeLinesFlags(int value) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92).voidsetTreeLinesRounding(float value) Radius of lines connecting child nodes to the vertical line (since imgui 1.92).voidsetTreeLinesSize(float value) Thickness of outlines when usingImGuiTreeNodeFlags_DrawLines(since imgui 1.92).voidsetWindowBorderSize(float value) Thickness of border around windows.voidsetWindowMenuButtonPosition(int value) Side of the collapsing/docking button in the title bar (None/Left/Right).voidsetWindowMinSize(float valueX, float valueY) Minimum window size.voidsetWindowMinSize(ImVec2 value) Minimum window size.voidsetWindowPadding(float valueX, float valueY) Padding within a window.voidsetWindowPadding(ImVec2 value) Padding within a window.voidsetWindowRounding(float value) Radius of window corners rounding.voidsetWindowTitleAlign(float valueX, float valueY) Alignment for title bar text.voidsetWindowTitleAlign(ImVec2 value) Alignment for title bar text.Methods inherited from class imgui.binding.ImGuiStructDestroyable
destroyMethods inherited from class imgui.binding.ImGuiStruct
isNotValidPtr, isValidPtr
-
Constructor Details
-
ImGuiStyle
public ImGuiStyle() -
ImGuiStyle
public ImGuiStyle(long ptr)
-
-
Method Details
-
create
protected long create()- Specified by:
createin classImGuiStructDestroyable
-
getAlpha
public float getAlpha()Global alpha applies to everything in Dear ImGui. -
setAlpha
public void setAlpha(float value) Global alpha applies to everything in Dear ImGui. -
getDisabledAlpha
public float getDisabledAlpha()Additional alpha multiplier applied by BeginDisabled(). Multiply over current value of Alpha. -
setDisabledAlpha
public void setDisabledAlpha(float value) Additional alpha multiplier applied by BeginDisabled(). Multiply over current value of Alpha. -
getFontScaleMain
public float getFontScaleMain()Main global scale factor applied on top of font size. Replacesio.FontGlobalScale(moved from io to style in imgui 1.92). May be set by application once or exposed to end-users. -
setFontScaleMain
public void setFontScaleMain(float value) Main global scale factor applied on top of font size. Replacesio.FontGlobalScale(moved from io to style in imgui 1.92). May be set by application once or exposed to end-users. -
getFontScaleDpi
public float getFontScaleDpi()Additional global scale factor from viewport/monitor contents scale (since imgui 1.92). In the docking branch: whenio.ConfigDpiScaleFontsis enabled, this is automatically overwritten when changing monitor DPI. -
setFontScaleDpi
public void setFontScaleDpi(float value) Additional global scale factor from viewport/monitor contents scale (since imgui 1.92). In the docking branch: whenio.ConfigDpiScaleFontsis enabled, this is automatically overwritten when changing monitor DPI. -
getWindowPadding
Padding within a window. -
getWindowPaddingX
public float getWindowPaddingX()Padding within a window. -
getWindowPaddingY
public float getWindowPaddingY()Padding within a window. -
getWindowPadding
Padding within a window. -
setWindowPadding
Padding within a window. -
setWindowPadding
public void setWindowPadding(float valueX, float valueY) Padding within a window. -
getWindowRounding
public float getWindowRounding()Radius of window corners rounding. Set to 0.0f to have rectangular windows. Large values tend to lead to variety of artifacts and are not recommended. -
setWindowRounding
public void setWindowRounding(float value) Radius of window corners rounding. Set to 0.0f to have rectangular windows. Large values tend to lead to variety of artifacts and are not recommended. -
getWindowBorderSize
public float getWindowBorderSize()Thickness of border around windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
setWindowBorderSize
public void setWindowBorderSize(float value) Thickness of border around windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
getWindowMinSize
Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
getWindowMinSizeX
public float getWindowMinSizeX()Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
getWindowMinSizeY
public float getWindowMinSizeY()Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
getWindowMinSize
Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
setWindowMinSize
Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
setWindowMinSize
public void setWindowMinSize(float valueX, float valueY) Minimum window size. This is a global setting. If you want to constrain individual windows, use SetNextWindowSizeConstraints(). -
getWindowTitleAlign
Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
getWindowTitleAlignX
public float getWindowTitleAlignX()Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
getWindowTitleAlignY
public float getWindowTitleAlignY()Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
getWindowTitleAlign
Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
setWindowTitleAlign
Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
setWindowTitleAlign
public void setWindowTitleAlign(float valueX, float valueY) Alignment for title bar text. Defaults to (0.0f,0.5f) for left-aligned,vertically centered. -
getWindowMenuButtonPosition
public int getWindowMenuButtonPosition()Side of the collapsing/docking button in the title bar (None/Left/Right). Defaults to ImGuiDir_Left. -
setWindowMenuButtonPosition
public void setWindowMenuButtonPosition(int value) Side of the collapsing/docking button in the title bar (None/Left/Right). Defaults to ImGuiDir_Left. -
getChildRounding
public float getChildRounding()Radius of child window corners rounding. Set to 0.0f to have rectangular windows. -
setChildRounding
public void setChildRounding(float value) Radius of child window corners rounding. Set to 0.0f to have rectangular windows. -
getChildBorderSize
public float getChildBorderSize()Thickness of border around child windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
setChildBorderSize
public void setChildBorderSize(float value) Thickness of border around child windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
getPopupRounding
public float getPopupRounding()Radius of popup window corners rounding. (Note that tooltip windows use WindowRounding) -
setPopupRounding
public void setPopupRounding(float value) Radius of popup window corners rounding. (Note that tooltip windows use WindowRounding) -
getPopupBorderSize
public float getPopupBorderSize()Thickness of border around popup/tooltip windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
setPopupBorderSize
public void setPopupBorderSize(float value) Thickness of border around popup/tooltip windows. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
getFramePadding
Padding within a framed rectangle (used by most widgets). -
getFramePaddingX
public float getFramePaddingX()Padding within a framed rectangle (used by most widgets). -
getFramePaddingY
public float getFramePaddingY()Padding within a framed rectangle (used by most widgets). -
getFramePadding
Padding within a framed rectangle (used by most widgets). -
setFramePadding
Padding within a framed rectangle (used by most widgets). -
setFramePadding
public void setFramePadding(float valueX, float valueY) Padding within a framed rectangle (used by most widgets). -
getFrameRounding
public float getFrameRounding()Radius of frame corners rounding. Set to 0.0f to have rectangular frame (used by most widgets). -
setFrameRounding
public void setFrameRounding(float value) Radius of frame corners rounding. Set to 0.0f to have rectangular frame (used by most widgets). -
getFrameBorderSize
public float getFrameBorderSize()Thickness of border around frames. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
setFrameBorderSize
public void setFrameBorderSize(float value) Thickness of border around frames. Generally set to 0.0f or 1.0f. (Other values are not well tested and more CPU/GPU costly). -
getItemSpacing
Horizontal and vertical spacing between widgets/lines. -
getItemSpacingX
public float getItemSpacingX()Horizontal and vertical spacing between widgets/lines. -
getItemSpacingY
public float getItemSpacingY()Horizontal and vertical spacing between widgets/lines. -
getItemSpacing
Horizontal and vertical spacing between widgets/lines. -
setItemSpacing
Horizontal and vertical spacing between widgets/lines. -
setItemSpacing
public void setItemSpacing(float valueX, float valueY) Horizontal and vertical spacing between widgets/lines. -
getItemInnerSpacing
Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
getItemInnerSpacingX
public float getItemInnerSpacingX()Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
getItemInnerSpacingY
public float getItemInnerSpacingY()Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
getItemInnerSpacing
Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
setItemInnerSpacing
Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
setItemInnerSpacing
public void setItemInnerSpacing(float valueX, float valueY) Horizontal and vertical spacing between within elements of a composed widget (e.g. a slider and its label). -
getCellPadding
Padding within a table cell. CellPadding.y may be altered between different rows. -
getCellPaddingX
public float getCellPaddingX()Padding within a table cell. CellPadding.y may be altered between different rows. -
getCellPaddingY
public float getCellPaddingY()Padding within a table cell. CellPadding.y may be altered between different rows. -
getCellPadding
Padding within a table cell. CellPadding.y may be altered between different rows. -
setCellPadding
Padding within a table cell. CellPadding.y may be altered between different rows. -
setCellPadding
public void setCellPadding(float valueX, float valueY) Padding within a table cell. CellPadding.y may be altered between different rows. -
getTouchExtraPadding
Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
getTouchExtraPaddingX
public float getTouchExtraPaddingX()Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
getTouchExtraPaddingY
public float getTouchExtraPaddingY()Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
getTouchExtraPadding
Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
setTouchExtraPadding
Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
setTouchExtraPadding
public void setTouchExtraPadding(float valueX, float valueY) Expand reactive bounding box for touch-based system where touch position is not accurate enough. Unfortunately we don't sort widgets so priority on overlap will always be given to the first widget. So don't grow this too much! -
getIndentSpacing
public float getIndentSpacing()Horizontal indentation when e.g. entering a tree node. Generally == (FontSize + FramePadding.x*2). -
setIndentSpacing
public void setIndentSpacing(float value) Horizontal indentation when e.g. entering a tree node. Generally == (FontSize + FramePadding.x*2). -
getColumnsMinSpacing
public float getColumnsMinSpacing()Minimum horizontal spacing between two columns. Preferably>(FramePadding.x + 1). -
setColumnsMinSpacing
public void setColumnsMinSpacing(float value) Minimum horizontal spacing between two columns. Preferably>(FramePadding.x + 1). -
getScrollbarSize
public float getScrollbarSize()Width of the vertical scrollbar, Height of the horizontal scrollbar. -
setScrollbarSize
public void setScrollbarSize(float value) Width of the vertical scrollbar, Height of the horizontal scrollbar. -
getScrollbarRounding
public float getScrollbarRounding()Radius of grab corners for scrollbar. -
setScrollbarRounding
public void setScrollbarRounding(float value) Radius of grab corners for scrollbar. -
getGrabMinSize
public float getGrabMinSize()Minimum width/height of a grab box for slider/scrollbar. -
setGrabMinSize
public void setGrabMinSize(float value) Minimum width/height of a grab box for slider/scrollbar. -
getGrabRounding
public float getGrabRounding()Radius of grabs corners rounding. Set to 0.0f to have rectangular slider grabs. -
setGrabRounding
public void setGrabRounding(float value) Radius of grabs corners rounding. Set to 0.0f to have rectangular slider grabs. -
getLogSliderDeadzone
public float getLogSliderDeadzone()The size in pixels of the dead-zone around zero on logarithmic sliders that cross zero. -
setLogSliderDeadzone
public void setLogSliderDeadzone(float value) The size in pixels of the dead-zone around zero on logarithmic sliders that cross zero. -
getTabRounding
public float getTabRounding()Radius of upper corners of a tab. Set to 0.0f to have rectangular tabs. -
setTabRounding
public void setTabRounding(float value) Radius of upper corners of a tab. Set to 0.0f to have rectangular tabs. -
getTabBorderSize
public float getTabBorderSize()Thickness of border around tabs. -
setTabBorderSize
public void setTabBorderSize(float value) Thickness of border around tabs. -
getTabCloseButtonMinWidthSelected
public float getTabCloseButtonMinWidthSelected()Minimum width for close button to appear on a selected tab when hovered.-1: always visible;0: visible when hovered;>0: visible when hovered if tab width is at least this wide. (Since imgui 1.91.9 this field split intoTabCloseButtonMinWidthSelectedandTabCloseButtonMinWidthUnselected.) -
setTabCloseButtonMinWidthSelected
public void setTabCloseButtonMinWidthSelected(float value) Minimum width for close button to appear on a selected tab when hovered.-1: always visible;0: visible when hovered;>0: visible when hovered if tab width is at least this wide. (Since imgui 1.91.9 this field split intoTabCloseButtonMinWidthSelectedandTabCloseButtonMinWidthUnselected.) -
getTabCloseButtonMinWidthUnselected
public float getTabCloseButtonMinWidthUnselected()Minimum width for close button to appear on an unselected tab when hovered.-1: always visible;0: visible when hovered;>0: visible when hovered if tab width is at least this wide;FLT_MAX: never show close button when unselected. (Since imgui 1.91.9; renamed fromTabMinWidthForCloseButton.) -
setTabCloseButtonMinWidthUnselected
public void setTabCloseButtonMinWidthUnselected(float value) Minimum width for close button to appear on an unselected tab when hovered.-1: always visible;0: visible when hovered;>0: visible when hovered if tab width is at least this wide;FLT_MAX: never show close button when unselected. (Since imgui 1.91.9; renamed fromTabMinWidthForCloseButton.) -
getColorButtonPosition
public int getColorButtonPosition()Side of the color button in the ColorEdit4 widget (left/right). Defaults to ImGuiDir_Right. -
setColorButtonPosition
public void setColorButtonPosition(int value) Side of the color button in the ColorEdit4 widget (left/right). Defaults to ImGuiDir_Right. -
getButtonTextAlign
Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
getButtonTextAlignX
public float getButtonTextAlignX()Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
getButtonTextAlignY
public float getButtonTextAlignY()Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
getButtonTextAlign
Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
setButtonTextAlign
Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
setButtonTextAlign
public void setButtonTextAlign(float valueX, float valueY) Alignment of button text when button is larger than text. Defaults to (0.5f, 0.5f) (centered). -
getSelectableTextAlign
Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
getSelectableTextAlignX
public float getSelectableTextAlignX()Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
getSelectableTextAlignY
public float getSelectableTextAlignY()Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
getSelectableTextAlign
Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
setSelectableTextAlign
Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
setSelectableTextAlign
public void setSelectableTextAlign(float valueX, float valueY) Alignment of selectable text. Defaults to (0.0f, 0.0f) (top-left aligned). It's generally important to keep this left-aligned if you want to lay multiple items on a same line. -
getImageRounding
public float getImageRounding()Rounding of Image() calls (since imgui 1.92). -
setImageRounding
public void setImageRounding(float value) Rounding of Image() calls (since imgui 1.92). -
getImageBorderSize
public float getImageBorderSize()Thickness of border around Image() calls (since imgui 1.92). -
setImageBorderSize
public void setImageBorderSize(float value) Thickness of border around Image() calls (since imgui 1.92). -
getTreeLinesFlags
public int getTreeLinesFlags()Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One ofImGuiTreeNodeFlags_DrawLinesNone/DrawLinesFull/DrawLinesToNodes. -
setTreeLinesFlags
public void setTreeLinesFlags(int value) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One ofImGuiTreeNodeFlags_DrawLinesNone/DrawLinesFull/DrawLinesToNodes. -
addTreeLinesFlags
public void addTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One ofImGuiTreeNodeFlags_DrawLinesNone/DrawLinesFull/DrawLinesToNodes. -
removeTreeLinesFlags
public void removeTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One ofImGuiTreeNodeFlags_DrawLinesNone/DrawLinesFull/DrawLinesToNodes. -
hasTreeLinesFlags
public boolean hasTreeLinesFlags(int flags) Default way to draw lines connecting TreeNode hierarchy (since imgui 1.92). One ofImGuiTreeNodeFlags_DrawLinesNone/DrawLinesFull/DrawLinesToNodes. -
getTreeLinesSize
public float getTreeLinesSize()Thickness of outlines when usingImGuiTreeNodeFlags_DrawLines(since imgui 1.92). -
setTreeLinesSize
public void setTreeLinesSize(float value) Thickness of outlines when usingImGuiTreeNodeFlags_DrawLines(since imgui 1.92). -
getTreeLinesRounding
public float getTreeLinesRounding()Radius of lines connecting child nodes to the vertical line (since imgui 1.92). -
setTreeLinesRounding
public void setTreeLinesRounding(float value) Radius of lines connecting child nodes to the vertical line (since imgui 1.92). -
getColorMarkerSize
public float getColorMarkerSize()Size of R/G/B/A color markers forColorEdit4()and for Drags/Sliders when usingImGuiSliderFlags_ColorMarkers(since imgui 1.92.7). Set to 0 to disable globally. -
setColorMarkerSize
public void setColorMarkerSize(float value) Size of R/G/B/A color markers forColorEdit4()and for Drags/Sliders when usingImGuiSliderFlags_ColorMarkers(since imgui 1.92.7). Set to 0 to disable globally. -
getSeparatorSize
public float getSeparatorSize()Thickness of the separator line rendered by Separator() (new in imgui 1.92.7). -
setSeparatorSize
public void setSeparatorSize(float value) Thickness of the separator line rendered by Separator() (new in imgui 1.92.7). -
getSeparatorTextBorderSize
public float getSeparatorTextBorderSize()Thickkness of border in SeparatorText() -
setSeparatorTextBorderSize
public void setSeparatorTextBorderSize(float value) Thickkness of border in SeparatorText() -
getSeparatorTextAlign
Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
getSeparatorTextAlignX
public float getSeparatorTextAlignX()Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
getSeparatorTextAlignY
public float getSeparatorTextAlignY()Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
getSeparatorTextAlign
Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
setSeparatorTextAlign
Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
setSeparatorTextAlign
public void setSeparatorTextAlign(float valueX, float valueY) Alignment of text within the separator. Defaults to (0.0f, 0.5f) (left aligned, center). -
getSeparatorTextPadding
Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
getSeparatorTextPaddingX
public float getSeparatorTextPaddingX()Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
getSeparatorTextPaddingY
public float getSeparatorTextPaddingY()Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
getSeparatorTextPadding
Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
setSeparatorTextPadding
Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
setSeparatorTextPadding
public void setSeparatorTextPadding(float valueX, float valueY) Horizontal offset of text from each edge of the separator + spacing on other axis. Generally small values. .y is recommended to be == FramePadding.y. -
getDisplayWindowPadding
Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
getDisplayWindowPaddingX
public float getDisplayWindowPaddingX()Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
getDisplayWindowPaddingY
public float getDisplayWindowPaddingY()Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
getDisplayWindowPadding
Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
setDisplayWindowPadding
Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
setDisplayWindowPadding
public void setDisplayWindowPadding(float valueX, float valueY) Window position are clamped to be visible within the display area by at least this amount. Only applies to regular windows. -
getDisplaySafeAreaPadding
If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
getDisplaySafeAreaPaddingX
public float getDisplaySafeAreaPaddingX()If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
getDisplaySafeAreaPaddingY
public float getDisplaySafeAreaPaddingY()If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
getDisplaySafeAreaPadding
If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
setDisplaySafeAreaPadding
If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
setDisplaySafeAreaPadding
public void setDisplaySafeAreaPadding(float valueX, float valueY) If you cannot see the edges of your screen (e.g. on a TV) increase the safe area padding. Apply to popups/tooltips as well regular windows. NB: Prefer configuring your TV sets correctly! -
getDockingSeparatorSize
public float getDockingSeparatorSize()Thickness of resizing border between docked windows -
setDockingSeparatorSize
public void setDockingSeparatorSize(float value) Thickness of resizing border between docked windows -
getMouseCursorScale
public float getMouseCursorScale()Scale software rendered mouse cursor (when io.MouseDrawCursor is enabled). May be removed later. -
setMouseCursorScale
public void setMouseCursorScale(float value) Scale software rendered mouse cursor (when io.MouseDrawCursor is enabled). May be removed later. -
getAntiAliasedLines
public boolean getAntiAliasedLines()Enable anti-aliased lines/borders. Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList). -
setAntiAliasedLines
public void setAntiAliasedLines(boolean value) Enable anti-aliased lines/borders. Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList). -
getAntiAliasedLinesUseTex
public boolean getAntiAliasedLinesUseTex()Enable anti-aliased lines/borders using textures where possible. Require backend to render with bilinear filtering (NOT point/nearest filtering). Latched at the beginning of the frame (copied to ImDrawList). -
setAntiAliasedLinesUseTex
public void setAntiAliasedLinesUseTex(boolean value) Enable anti-aliased lines/borders using textures where possible. Require backend to render with bilinear filtering (NOT point/nearest filtering). Latched at the beginning of the frame (copied to ImDrawList). -
getAntiAliasedFill
public boolean getAntiAliasedFill()Enable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.). Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList). -
setAntiAliasedFill
public void setAntiAliasedFill(boolean value) Enable anti-aliased edges around filled shapes (rounded rectangles, circles, etc.). Disable if you are really tight on CPU/GPU. Latched at the beginning of the frame (copied to ImDrawList). -
getCurveTessellationTol
public float getCurveTessellationTol()Tessellation tolerance when using PathBezierCurveTo() without a specific number of segments. Decrease for highly tessellated curves (higher quality, more polygons), increase to reduce quality. -
setCurveTessellationTol
public void setCurveTessellationTol(float value) Tessellation tolerance when using PathBezierCurveTo() without a specific number of segments. Decrease for highly tessellated curves (higher quality, more polygons), increase to reduce quality. -
getCircleTessellationMaxError
public float getCircleTessellationMaxError()Maximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified. Decrease for higher quality but more geometry. -
setCircleTessellationMaxError
public void setCircleTessellationMaxError(float value) Maximum error (in pixels) allowed when using AddCircle()/AddCircleFilled() or drawing rounded corner rectangles with no explicit segment count specified. Decrease for higher quality but more geometry. -
getColors
-
setColors
-
getColor
-
getColor
-
setColor
public void setColor(int col, float r, float g, float b, float a) -
setColor
public void setColor(int col, int r, int g, int b, int a) -
setColor
public void setColor(int col, int value) -
getHoverStationaryDelay
public float getHoverStationaryDelay()Delay for IsItemHovered(ImGuiHoveredFlags_Stationary). Time required to consider mouse stationary. -
setHoverStationaryDelay
public void setHoverStationaryDelay(float value) Delay for IsItemHovered(ImGuiHoveredFlags_Stationary). Time required to consider mouse stationary. -
getHoverDelayShort
public float getHoverDelayShort()Delay for IsItemHovered(ImGuiHoveredFlags_DelayShort). Usually used along with HoverStationaryDelay. -
setHoverDelayShort
public void setHoverDelayShort(float value) Delay for IsItemHovered(ImGuiHoveredFlags_DelayShort). Usually used along with HoverStationaryDelay. -
getHoverDelayNormal
public float getHoverDelayNormal()Delay for IsItemHovered(ImGuiHoveredFlags_DelayNormal). " -
setHoverDelayNormal
public void setHoverDelayNormal(float value) Delay for IsItemHovered(ImGuiHoveredFlags_DelayNormal). " -
getHoverFlagsForTooltipMouse
public int getHoverFlagsForTooltipMouse()Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse. -
setHoverFlagsForTooltipMouse
public void setHoverFlagsForTooltipMouse(int value) Default flags when using IsItemHovered(ImGuiHoveredFlags_ForTooltip) or BeginItemTooltip()/SetItemTooltip() while using mouse. -
scaleAllSizes
public void scaleAllSizes(float scaleFactor)
-