Package imgui
Class ImGuiTableSortSpecs
java.lang.Object
imgui.binding.ImGuiStruct
imgui.ImGuiTableSortSpecs
Sorting specifications for a table (often handling sort specs for a single column, occasionally more)
Obtained by calling TableGetSortSpecs().
When 'SpecsDirty == true' you can sort your data. It will be true with sorting specs have changed since last call, or the first time.
Make sure to set 'SpecsDirty = false' after sorting, else you may wastefully sort your data every frame!
-
Field Summary
Fields inherited from class imgui.binding.ImGuiStruct
ptr -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiongetSpecs()Pointer to sort spec array.intSort spec count.booleanSet to true when specs have changed since last time! Use this to sort again, then clear the flag.voidsetSpecsDirty(boolean value) Set to true when specs have changed since last time! Use this to sort again, then clear the flag.Methods inherited from class imgui.binding.ImGuiStruct
isNotValidPtr, isValidPtr
-
Constructor Details
-
ImGuiTableSortSpecs
public ImGuiTableSortSpecs(long ptr)
-
-
Method Details
-
getSpecs
Pointer to sort spec array. -
getSpecsCount
public int getSpecsCount()Sort spec count. Most often 1. May be>1 when ImGuiTableFlags_SortMulti is enabled. May be == 0 when ImGuiTableFlags_SortTristate is enabled. -
getSpecsDirty
public boolean getSpecsDirty()Set to true when specs have changed since last time! Use this to sort again, then clear the flag. -
setSpecsDirty
public void setSpecsDirty(boolean value) Set to true when specs have changed since last time! Use this to sort again, then clear the flag.
-