Package imgui.binding
Class ImGuiStruct
java.lang.Object
imgui.binding.ImGuiStruct
- Direct Known Subclasses:
ImDrawData,ImDrawList,ImGuiContext,ImGuiDockNode,ImGuiInputTextCallbackData,ImGuiIO,ImGuiPlatformIO,ImGuiPlatformMonitor,ImGuiStructDestroyable,ImGuiTableColumnSortSpecs,ImGuiTableSortSpecs,ImGuiViewport,ImGuiWindow,ImNodesContext,ImNodesEditorContext,ImNodesIO,ImNodesStyle,ImPlotContext,NodeEditorContext,NodeEditorStyle,TextEditorLanguage
Class provides a communication layer between binding and Dear ImGui library through the "pointer" field.
-
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanShows if object pointer is valid and does it point to the existing object.final booleanShows if object pointer is valid and does it point to the existing object.
-
Field Details
-
ptr
public long ptrPointer to the natively allocated object. Could be zero if JNI returned NULL instead of the real object. For such cases methodsisValidPtr()andisNotValidPtr()could be used to verify that object points to the real object.
-
-
Constructor Details
-
ImGuiStruct
public ImGuiStruct(long ptr)
-
-
Method Details
-
isValidPtr
public final boolean isValidPtr()Shows if object pointer is valid and does it point to the existing object.- Returns:
- true, if pointer is valid
-
isNotValidPtr
public final boolean isNotValidPtr()Shows if object pointer is valid and does it point to the existing object.- Returns:
- true, if pointer is invalid
-