Package imgui.extension.implot
Class ImPlotInputMap
java.lang.Object
imgui.binding.ImGuiStruct
imgui.binding.ImGuiStructDestroyable
imgui.extension.implot.ImPlotInputMap
-
Field Summary
Fields inherited from class imgui.binding.ImGuiStruct
ptr -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected longcreate()intgetFit()LMB initiates fit when double clickedintgetMenu()RMB opens context menus (if enabled) when clickedintCtrl when held, all input is ignored; used to enable axis/plots as DND sourcesintgetPan()LMB enables panning when heldintOptional modifier that must be held for panning/fittingintRMB begins box selection when pressed and confirms selection when releasedintLMB cancels active box selection when pressed; cannot be the same as SelectintAlt expands active box selection horizontally to plot edge when heldintOptional modifier that must be held for box selectionintShift expands active box selection vertically to plot edge when heldintOptional modifier that must be held for scroll wheel zoomingfloatZoom rate for scroll (e.g.voidsetFit(int value) LMB initiates fit when double clickedvoidsetMenu(int value) RMB opens context menus (if enabled) when clickedvoidsetOverrideMod(int value) Ctrl when held, all input is ignored; used to enable axis/plots as DND sourcesvoidsetPan(int value) LMB enables panning when heldvoidsetPanMod(int value) Optional modifier that must be held for panning/fittingvoidsetSelect(int value) RMB begins box selection when pressed and confirms selection when releasedvoidsetSelectCancel(int value) LMB cancels active box selection when pressed; cannot be the same as SelectvoidsetSelectHorzMod(int value) Alt expands active box selection horizontally to plot edge when heldvoidsetSelectMod(int value) Optional modifier that must be held for box selectionvoidsetSelectVertMod(int value) Shift expands active box selection vertically to plot edge when heldvoidsetZoomMod(int value) Optional modifier that must be held for scroll wheel zoomingvoidsetZoomRate(float value) Zoom rate for scroll (e.g.Methods inherited from class imgui.binding.ImGuiStructDestroyable
destroyMethods inherited from class imgui.binding.ImGuiStruct
isNotValidPtr, isValidPtr
-
Constructor Details
-
ImPlotInputMap
public ImPlotInputMap() -
ImPlotInputMap
public ImPlotInputMap(long ptr)
-
-
Method Details
-
create
protected long create()- Specified by:
createin classImGuiStructDestroyable
-
getPan
public int getPan()LMB enables panning when held -
setPan
public void setPan(int value) LMB enables panning when held -
getPanMod
public int getPanMod()Optional modifier that must be held for panning/fitting -
setPanMod
public void setPanMod(int value) Optional modifier that must be held for panning/fitting -
getFit
public int getFit()LMB initiates fit when double clicked -
setFit
public void setFit(int value) LMB initiates fit when double clicked -
getSelect
public int getSelect()RMB begins box selection when pressed and confirms selection when released -
setSelect
public void setSelect(int value) RMB begins box selection when pressed and confirms selection when released -
getSelectCancel
public int getSelectCancel()LMB cancels active box selection when pressed; cannot be the same as Select -
setSelectCancel
public void setSelectCancel(int value) LMB cancels active box selection when pressed; cannot be the same as Select -
getSelectMod
public int getSelectMod()Optional modifier that must be held for box selection -
setSelectMod
public void setSelectMod(int value) Optional modifier that must be held for box selection -
getSelectHorzMod
public int getSelectHorzMod()Alt expands active box selection horizontally to plot edge when held -
setSelectHorzMod
public void setSelectHorzMod(int value) Alt expands active box selection horizontally to plot edge when held -
getSelectVertMod
public int getSelectVertMod()Shift expands active box selection vertically to plot edge when held -
setSelectVertMod
public void setSelectVertMod(int value) Shift expands active box selection vertically to plot edge when held -
getMenu
public int getMenu()RMB opens context menus (if enabled) when clicked -
setMenu
public void setMenu(int value) RMB opens context menus (if enabled) when clicked -
getOverrideMod
public int getOverrideMod()Ctrl when held, all input is ignored; used to enable axis/plots as DND sources -
setOverrideMod
public void setOverrideMod(int value) Ctrl when held, all input is ignored; used to enable axis/plots as DND sources -
getZoomMod
public int getZoomMod()Optional modifier that must be held for scroll wheel zooming -
setZoomMod
public void setZoomMod(int value) Optional modifier that must be held for scroll wheel zooming -
getZoomRate
public float getZoomRate()Zoom rate for scroll (e.g. 0.1f = 10% plot range every scroll click); make negative to invert -
setZoomRate
public void setZoomRate(float value) Zoom rate for scroll (e.g. 0.1f = 10% plot range every scroll click); make negative to invert
-