Package imgui.extension.implot.flag
Class ImPlotFlags
java.lang.Object
imgui.extension.implot.flag.ImPlotFlags
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intDefinition:ImPlotFlags_NoTitle | ImPlotFlags_NoLegend | ImPlotFlags_NoMenus | ImPlotFlags_NoBoxSelect | ImPlotFlags_NoMouseTextstatic final intthe default mouse cursor will be replaced with a crosshair when hoveredstatic final intx and y axes pairs will be constrained to have the same units/pixelstatic final intthe user will not be able to box-selectstatic final intthe ImGui frame will not be renderedstatic final intthe user will not be able to interact with the plotstatic final intthe legend will not be displayedstatic final intthe user will not be able to open context menusstatic final intthe mouse position, in plot coordinates, will not be displayed inside of the plotstatic final intdefaultstatic final intthe plot title will not be displayed (titles are also hidden if preceded by double hashes, e.g. -
Method Summary
-
Field Details
-
None
public static final int NonedefaultDefinition:
0- See Also:
-
NoTitle
public static final int NoTitlethe plot title will not be displayed (titles are also hidden if preceded by double hashes, e.g. "##MyPlot")Definition:
1 << 0- See Also:
-
NoLegend
public static final int NoLegendthe legend will not be displayedDefinition:
1 << 1- See Also:
-
NoMouseText
public static final int NoMouseTextthe mouse position, in plot coordinates, will not be displayed inside of the plotDefinition:
1 << 2- See Also:
-
NoInputs
public static final int NoInputsthe user will not be able to interact with the plotDefinition:
1 << 3- See Also:
-
NoMenus
public static final int NoMenusthe user will not be able to open context menusDefinition:
1 << 4- See Also:
-
NoBoxSelect
public static final int NoBoxSelectthe user will not be able to box-selectDefinition:
1 << 5- See Also:
-
NoFrame
public static final int NoFramethe ImGui frame will not be renderedDefinition:
1 << 6- See Also:
-
Equal
public static final int Equalx and y axes pairs will be constrained to have the same units/pixelDefinition:
1 << 7- See Also:
-
Crosshairs
public static final int Crosshairsthe default mouse cursor will be replaced with a crosshair when hoveredDefinition:
1 << 8- See Also:
-
CanvasOnly
public static final int CanvasOnlyDefinition:ImPlotFlags_NoTitle | ImPlotFlags_NoLegend | ImPlotFlags_NoMenus | ImPlotFlags_NoBoxSelect | ImPlotFlags_NoMouseText- See Also:
-