Package imgui.extension.implot.flag
Class ImPlotHistogramFlags
java.lang.Object
imgui.extension.implot.flag.ImPlotHistogramFlags
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intdata will be read in column major order (not supported by PlotHistogram)static final inteach bin will contain its count plus the counts of all previous bins (not supported by PlotHistogram2D)static final intcounts will be normalized, i.e.static final inthistogram bars will be rendered horizontally (not supported by PlotHistogram2D)static final intdefaultstatic final intexclude values outside the specified histogram range from the count toward normalizing and cumulative counts -
Method Summary
-
Field Details
-
None
public static final int NonedefaultDefinition:
0- See Also:
-
Horizontal
public static final int Horizontalhistogram bars will be rendered horizontally (not supported by PlotHistogram2D)Definition:
1 << 10- See Also:
-
Cumulative
public static final int Cumulativeeach bin will contain its count plus the counts of all previous bins (not supported by PlotHistogram2D)Definition:
1 << 11- See Also:
-
Density
public static final int Densitycounts will be normalized, i.e. the PDF will be visualized, or the CDF will be visualized if Cumulative is also setDefinition:
1 << 12- See Also:
-
NoOutliers
public static final int NoOutliersexclude values outside the specified histogram range from the count toward normalizing and cumulative countsDefinition:
1 << 13- See Also:
-
ColMajor
public static final int ColMajordata will be read in column major order (not supported by PlotHistogram)Definition:
1 << 14- See Also:
-