Package imgui.extension.implot.flag
Class ImPlotLineFlags
java.lang.Object
imgui.extension.implot.flag.ImPlotLineFlags
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intthe last and first point will be connected to form a closed loopstatic final intmarkers (if displayed) on the edge of a plot will not be clippedstatic final intdefaultstatic final inta line segment will be rendered from every two consecutive pointsstatic final inta filled region between the line and horizontal origin will be rendered; use PlotShaded for more advanced casesstatic final intNaNs values will be skipped instead of rendered as missing data -
Method Summary
-
Field Details
-
None
public static final int NonedefaultDefinition:
0- See Also:
-
Segments
public static final int Segmentsa line segment will be rendered from every two consecutive pointsDefinition:
1 << 10- See Also:
-
Loop
public static final int Loopthe last and first point will be connected to form a closed loopDefinition:
1 << 11- See Also:
-
SkipNaN
public static final int SkipNaNNaNs values will be skipped instead of rendered as missing dataDefinition:
1 << 12- See Also:
-
NoClip
public static final int NoClipmarkers (if displayed) on the edge of a plot will not be clippedDefinition:
1 << 13- See Also:
-
Shaded
public static final int Shadeda filled region between the line and horizontal origin will be rendered; use PlotShaded for more advanced casesDefinition:
1 << 14- See Also:
-