Package imgui.extension.implot.flag
Class ImPlotStyleVar
java.lang.Object
imgui.extension.implot.flag.ImPlotStyleVar
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intImVec2, text padding around annotation labelsstatic final intstatic final intfloat, digital plot padding from bottom in pixelsstatic final intfloat, digital plot spacing gap in pixelsstatic final intImVec2, additional fit padding as a percentage of the fit extents (e.g.static final intImVec2, padding between axes labels, tick labels, and plot edgestatic final intImVec2, legend inner padding from legend edgesstatic final intImVec2, legend padding from plot edgesstatic final intImVec2, spacing between legend entriesstatic final intImVec2, line thickness of major grid linesstatic final intImVec2, major tick lengths for X and Y axesstatic final intImVec2, line thickness of major ticksstatic final intfloat, alpha multiplier applied to minor axis grid linesstatic final intImVec2, line thickness of minor grid linesstatic final intImVec2, minor tick lengths for X and Y axesstatic final intImVec2, line thickness of minor ticksstatic final intImVec2, padding between plot edge and interior info textstatic final intfloat, thickness of border around plot areastatic final intImVec2, default size used when ImVec2(0,0) is passed to BeginPlotstatic final intImVec2, minimum size plot frame can be when shrunkstatic final intImVec2, padding between widget frame and plot area, labels, or outside legends (i.e. -
Method Summary
-
Field Details
-
PlotDefaultSize
public static final int PlotDefaultSizeImVec2, default size used when ImVec2(0,0) is passed to BeginPlot- See Also:
-
PlotMinSize
public static final int PlotMinSizeImVec2, minimum size plot frame can be when shrunk- See Also:
-
PlotBorderSize
public static final int PlotBorderSizefloat, thickness of border around plot area- See Also:
-
MinorAlpha
public static final int MinorAlphafloat, alpha multiplier applied to minor axis grid lines- See Also:
-
MajorTickLen
public static final int MajorTickLenImVec2, major tick lengths for X and Y axes- See Also:
-
MinorTickLen
public static final int MinorTickLenImVec2, minor tick lengths for X and Y axes- See Also:
-
MajorTickSize
public static final int MajorTickSizeImVec2, line thickness of major ticks- See Also:
-
MinorTickSize
public static final int MinorTickSizeImVec2, line thickness of minor ticks- See Also:
-
MajorGridSize
public static final int MajorGridSizeImVec2, line thickness of major grid lines- See Also:
-
MinorGridSize
public static final int MinorGridSizeImVec2, line thickness of minor grid lines- See Also:
-
PlotPadding
public static final int PlotPaddingImVec2, padding between widget frame and plot area, labels, or outside legends (i.e. main padding)- See Also:
-
LabelPadding
public static final int LabelPaddingImVec2, padding between axes labels, tick labels, and plot edge- See Also:
-
LegendPadding
public static final int LegendPaddingImVec2, legend padding from plot edges- See Also:
-
LegendInnerPadding
public static final int LegendInnerPaddingImVec2, legend inner padding from legend edges- See Also:
-
LegendSpacing
public static final int LegendSpacingImVec2, spacing between legend entries- See Also:
-
MousePosPadding
public static final int MousePosPaddingImVec2, padding between plot edge and interior info text- See Also:
-
AnnotationPadding
public static final int AnnotationPaddingImVec2, text padding around annotation labels- See Also:
-
FitPadding
public static final int FitPaddingImVec2, additional fit padding as a percentage of the fit extents (e.g. ImVec2(0.1f,0.1f) adds 10% to the fit extents of X and Y)- See Also:
-
DigitalPadding
public static final int DigitalPaddingfloat, digital plot padding from bottom in pixels- See Also:
-
DigitalSpacing
public static final int DigitalSpacingfloat, digital plot spacing gap in pixels- See Also:
-
COUNT
public static final int COUNT- See Also:
-