Package imgui.flag
Class ImDrawListFlags
java.lang.Object
imgui.flag.ImDrawListFlags
Flags for ImDrawList. Those are set automatically by ImGui:: functions from ImGuiIO settings, and generally not manipulated directly.
It is however possible to temporarily alter flags between calls to ImDrawList:: functions.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intCan emit 'VtxOffset>0' to allow large meshes.static final intEnable anti-aliased edge around filled shapes (rounded rectangles, circles).static final intEnable anti-aliased lines/borders (*2 the number of triangles for 1.0f wide line or lines thin enough to be drawn using textures, otherwise *3 the number of triangles)static final intEnable anti-aliased lines/borders using textures when possible.static final intDefinition:0 -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
AntiAliasedLines
public static final int AntiAliasedLinesEnable anti-aliased lines/borders (*2 the number of triangles for 1.0f wide line or lines thin enough to be drawn using textures, otherwise *3 the number of triangles)Definition:
1 << 0- See Also:
-
AntiAliasedLinesUseTex
public static final int AntiAliasedLinesUseTexEnable anti-aliased lines/borders using textures when possible. Require backend to render with bilinear filtering (NOT point/nearest filtering).Definition:
1 << 1- See Also:
-
AntiAliasedFill
public static final int AntiAliasedFillEnable anti-aliased edge around filled shapes (rounded rectangles, circles).Definition:
1 << 2- See Also:
-
AllowVtxOffset
public static final int AllowVtxOffsetCan emit 'VtxOffset>0' to allow large meshes. Set when 'ImGuiBackendFlags_RendererHasVtxOffset' is enabled.Definition:
1 << 3- See Also:
-