Package imgui.flag
Class ImFontAtlasFlags
java.lang.Object
imgui.flag.ImFontAtlasFlags
Flags for ImFontAtlas build
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intDon't build thick line textures into the atlas (save a little texture memory, allow support for point/nearest filtering).static final intDon't build software mouse cursors into the atlas (save a little texture memory)static final intDefinition:0static final intDon't round the height to next power of two -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
NoPowerOfTwoHeight
public static final int NoPowerOfTwoHeightDon't round the height to next power of twoDefinition:
1 << 0- See Also:
-
NoMouseCursors
public static final int NoMouseCursorsDon't build software mouse cursors into the atlas (save a little texture memory)Definition:
1 << 1- See Also:
-
NoBakedLines
public static final int NoBakedLinesDon't build thick line textures into the atlas (save a little texture memory, allow support for point/nearest filtering). The AntiAliasedLinesUseTex features uses them, otherwise they will be rendered using polygons (more expensive for CPU/GPU).Definition:
1 << 2- See Also:
-