Package imgui.flag
Class ImGuiBackendFlags
java.lang.Object
imgui.flag.ImGuiBackendFlags
Backend capabilities flags stored in io.BackendFlags. Set by imgui_impl_xxx or custom backend.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intBackend Platform supports gamepad and currently has one connected.static final intBackend Platform supports honoring GetMouseCursor() value to change the OS cursor shape.static final intBackend Platform supports calling io.AddMouseViewportEvent() with the viewport under the mouse.static final intBackend Platform supports honoring viewport->ParentViewport/ParentViewportId value, by applying the corresponding parent/child relation at the Platform level.static final intBackend Platform supports io.WantSetMousePos requests to reposition the OS mouse position (only used if io.ConfigNavMoveSetMousePos is set).static final intDefinition:0static final intBackend Platform supports multiple viewports.static final intBackend Renderer supports ImTextureData requests to create/update/destroy textures.static final intBackend Renderer supports multiple viewports.static final intBackend Renderer supports ImDrawCmd::VtxOffset. -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
HasGamepad
public static final int HasGamepadBackend Platform supports gamepad and currently has one connected.Definition:
1 << 0- See Also:
-
HasMouseCursors
public static final int HasMouseCursorsBackend Platform supports honoring GetMouseCursor() value to change the OS cursor shape.Definition:
1 << 1- See Also:
-
HasSetMousePos
public static final int HasSetMousePosBackend Platform supports io.WantSetMousePos requests to reposition the OS mouse position (only used if io.ConfigNavMoveSetMousePos is set).Definition:
1 << 2- See Also:
-
RendererHasVtxOffset
public static final int RendererHasVtxOffsetBackend Renderer supports ImDrawCmd::VtxOffset. This enables output of large meshes (64K+ vertices) while still using 16-bit indices.Definition:
1 << 3- See Also:
-
RendererHasTextures
public static final int RendererHasTexturesBackend Renderer supports ImTextureData requests to create/update/destroy textures. This enables incremental texture updates and texture reloads. See https://github.com/ocornut/imgui/blob/master/docs/BACKENDS.md for instructions on how to upgrade your custom backend.Definition:
1 << 4- See Also:
-
RendererHasViewports
public static final int RendererHasViewportsBackend Renderer supports multiple viewports.Definition:
1 << 10- See Also:
-
PlatformHasViewports
public static final int PlatformHasViewportsBackend Platform supports multiple viewports.Definition:
1 << 11- See Also:
-
HasMouseHoveredViewport
public static final int HasMouseHoveredViewportBackend Platform supports calling io.AddMouseViewportEvent() with the viewport under the mouse. IF POSSIBLE, ignore viewports with the ImGuiViewportFlags_NoInputs flag (Win32 backend, GLFW 3.30+ backend can do this, SDL backend cannot). If this cannot be done, Dear ImGui needs to use a flawed heuristic to find the viewport under.Definition:
1 << 12- See Also:
-
HasParentViewport
public static final int HasParentViewportBackend Platform supports honoring viewport->ParentViewport/ParentViewportId value, by applying the corresponding parent/child relation at the Platform level.Definition:
1 << 13- See Also:
-