Package imgui.flag
Class ImGuiDockNodeFlags
java.lang.Object
imgui.flag.ImGuiDockNodeFlags
Flags for ImGui::DockSpace(), shared/inherited by child nodes.
(Some flags can be applied to individual nodes directly)
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intTab bar will automatically hide when there is a single window in the dock node.static final intDon't display the dockspace node but keep it alive.static final intRenamed in 1.90static final intDisable docking over the Central Node, which will be always kept empty.static final intDisable other windows/nodes from splitting this node.static final intDefinition:0static final intSaved // Disable resizing node using the splitter/separators.static final intRenamed in 1.90static final intDisable undocking this node.static final intEnable passthru dockspace: 1) DockSpace() will render a ImGuiCol_WindowBg background covering everything excepted the Central Node when empty. -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
KeepAliveOnly
public static final int KeepAliveOnlyDon't display the dockspace node but keep it alive. Windows docked into this dockspace node won't be undocked.Definition:
1 << 0- See Also:
-
NoDockingOverCentralNode
public static final int NoDockingOverCentralNodeDisable docking over the Central Node, which will be always kept empty.Definition:
1 << 2- See Also:
-
PassthruCentralNode
public static final int PassthruCentralNodeEnable passthru dockspace: 1) DockSpace() will render a ImGuiCol_WindowBg background covering everything excepted the Central Node when empty. Meaning the host window should probably use SetNextWindowBgAlpha(0.0f) prior to Begin() when using this. 2) When Central Node is empty: let inputs pass-through + won't display a DockingEmptyBg background. See demo for details.Definition:
1 << 3- See Also:
-
NoDockingSplit
public static final int NoDockingSplitDisable other windows/nodes from splitting this node.Definition:
1 << 4- See Also:
-
NoResize
public static final int NoResizeSaved // Disable resizing node using the splitter/separators. Useful with programmatically setup dockspaces.Definition:
1 << 5- See Also:
-
AutoHideTabBar
public static final int AutoHideTabBarTab bar will automatically hide when there is a single window in the dock node.Definition:
1 << 6- See Also:
-
NoUndocking
public static final int NoUndockingDisable undocking this node.Definition:
1 << 7- See Also:
-
NoSplit
public static final int NoSplitRenamed in 1.90Definition:
ImGuiDockNodeFlags_NoDockingSplit- See Also:
-
NoDockingInCentralNode
public static final int NoDockingInCentralNodeRenamed in 1.90Definition:
ImGuiDockNodeFlags_NoDockingOverCentralNode- See Also:
-