Package imgui.flag
Class ImGuiDragDropFlags
java.lang.Object
imgui.flag.ImGuiDragDropFlags
Flags for ImGui::BeginDragDropSource(), ImGui::AcceptDragDropPayload()
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intAcceptDragDropPayload() will returns true even before the mouse button is released.static final intAccepting item will render as if hovered.static final intDo not draw the default highlight rectangle when hovering over target.static final intRequest hiding the BeginDragDropSource tooltip from the BeginDragDropTarget site.static final intFor peeking ahead and inspecting the payload before delivery.static final intDefinition:0static final intAutomatically expire the payload if the source cease to be submitted (otherwise payloads are persisting while being dragged)static final intHint to specify that the payload may not be copied outside current dear imgui context.static final intHint to specify that the payload may not be copied outside current process.static final intAllow items such as Text(), Image() that have no unique identifier to be used as drag source, by manufacturing a temporary identifier based on their window-relative position.static final intRenamed in 1.90.9static final intExternal source (from outside of dear imgui), won't attempt to read current item/window info.static final intBy default, when dragging we clear data so that IsItemHovered() will return false, to avoid subsequent user code submitting tooltips.static final intDisable the behavior that allows to open tree nodes and collapsing header by holding over them while dragging a source item.static final intDisable preview tooltip. -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
SourceNoPreviewTooltip
public static final int SourceNoPreviewTooltipDisable preview tooltip. By default, a successful call to BeginDragDropSource opens a tooltip so you can display a preview or description of the source contents. This flag disables this behavior.Definition:
1 << 0- See Also:
-
SourceNoDisableHover
public static final int SourceNoDisableHoverBy default, when dragging we clear data so that IsItemHovered() will return false, to avoid subsequent user code submitting tooltips. This flag disables this behavior so you can still call IsItemHovered() on the source item.Definition:
1 << 1- See Also:
-
SourceNoHoldToOpenOthers
public static final int SourceNoHoldToOpenOthersDisable the behavior that allows to open tree nodes and collapsing header by holding over them while dragging a source item.Definition:
1 << 2- See Also:
-
SourceAllowNullID
public static final int SourceAllowNullIDAllow items such as Text(), Image() that have no unique identifier to be used as drag source, by manufacturing a temporary identifier based on their window-relative position. This is extremely unusual within the dear imgui ecosystem and so we made it explicit.Definition:
1 << 3- See Also:
-
SourceExtern
public static final int SourceExternExternal source (from outside of dear imgui), won't attempt to read current item/window info. Will always return true. Only one Extern source can be active simultaneously.Definition:
1 << 4- See Also:
-
PayloadAutoExpire
public static final int PayloadAutoExpireAutomatically expire the payload if the source cease to be submitted (otherwise payloads are persisting while being dragged)Definition:
1 << 5- See Also:
-
PayloadNoCrossContext
public static final int PayloadNoCrossContextHint to specify that the payload may not be copied outside current dear imgui context.Definition:
1 << 6- See Also:
-
PayloadNoCrossProcess
public static final int PayloadNoCrossProcessHint to specify that the payload may not be copied outside current process.Definition:
1 << 7- See Also:
-
AcceptBeforeDelivery
public static final int AcceptBeforeDeliveryAcceptDragDropPayload() will returns true even before the mouse button is released. You can then call IsDelivery() to test if the payload needs to be delivered.Definition:
1 << 10- See Also:
-
AcceptNoDrawDefaultRect
public static final int AcceptNoDrawDefaultRectDo not draw the default highlight rectangle when hovering over target.Definition:
1 << 11- See Also:
-
AcceptNoPreviewTooltip
public static final int AcceptNoPreviewTooltipRequest hiding the BeginDragDropSource tooltip from the BeginDragDropTarget site.Definition:
1 << 12- See Also:
-
AcceptDrawAsHovered
public static final int AcceptDrawAsHoveredAccepting item will render as if hovered. Useful for e.g. a Button() used as a drop target.Definition:
1 << 13- See Also:
-
AcceptPeekOnly
public static final int AcceptPeekOnlyFor peeking ahead and inspecting the payload before delivery.Definition:
ImGuiDragDropFlags_AcceptBeforeDelivery | ImGuiDragDropFlags_AcceptNoDrawDefaultRect- See Also:
-
SourceAutoExpirePayload
public static final int SourceAutoExpirePayloadRenamed in 1.90.9Definition:
ImGuiDragDropFlags_PayloadAutoExpire- See Also:
-