Package imgui.flag
Class ImGuiInputTextFlags
java.lang.Object
imgui.flag.ImGuiInputTextFlags
Flags for ImGui::InputText()
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intPressing TAB input a ' ' character into the text fieldstatic final intOverwrite modestatic final intSelect entire text when first taking mouse focusstatic final intCallback on each iteration.static final intCallback on character inputs to replace or discard them.static final intCallback on pressing TAB (for completion handling)static final intCallback on any edit.static final intCallback on pressing Up/Down arrows (for history handling)static final intCallback on buffer capacity changes request (beyond 'buf_size' parameter value), allowing the string to grow.static final intAllow 0123456789.+-* /static final intAllow 0123456789ABCDEFabcdefstatic final intFilter out spaces, tabsstatic final intAllow 0123456789.+-* /eE (Scientific notation input)static final intTurn a..z into A..Zstatic final intIn multi-line mode: validate with Enter, add new line with Ctrl+Enter (default is opposite: validate with Ctrl+Enter, add line with Enter).static final intInputFloat(), InputInt(), InputScalar() etc.static final intWhen text doesn't fit, elide left side to ensure right side stays visible.static final intReturn 'true' when Enter is pressed (as opposed to every time the value was modified).static final intEscape key clears content if not empty, and deactivate otherwise (contrast to default behavior of Escape to revert)static final intDisable following the cursor horizontallystatic final intBasic filters (also see ImGuiInputTextFlags_CallbackCharFilter)static final intDisable undo/redo.static final intInputFloat(), InputInt(), InputScalar() etc.static final intPassword mode, display all characters as '*', disable copystatic final intRead-only modestatic final intInputTextMultiline(): word-wrap lines that are too long. -
Method Summary
-
Field Details
-
None
public static final int NoneBasic filters (also see ImGuiInputTextFlags_CallbackCharFilter)Definition:
0- See Also:
-
CharsDecimal
public static final int CharsDecimalAllow 0123456789.+-* /Definition:
1 << 0- See Also:
-
CharsHexadecimal
public static final int CharsHexadecimalAllow 0123456789ABCDEFabcdefDefinition:
1 << 1- See Also:
-
CharsScientific
public static final int CharsScientificAllow 0123456789.+-* /eE (Scientific notation input)Definition:
1 << 2- See Also:
-
CharsUppercase
public static final int CharsUppercaseTurn a..z into A..ZDefinition:
1 << 3- See Also:
-
CharsNoBlank
public static final int CharsNoBlankFilter out spaces, tabsDefinition:
1 << 4- See Also:
-
AllowTabInput
public static final int AllowTabInputPressing TAB input a ' ' character into the text fieldDefinition:
1 << 5- See Also:
-
EnterReturnsTrue
public static final int EnterReturnsTrueReturn 'true' when Enter is pressed (as opposed to every time the value was modified). Consider using IsItemDeactivatedAfterEdit() instead!Definition:
1 << 6- See Also:
-
EscapeClearsAll
public static final int EscapeClearsAllEscape key clears content if not empty, and deactivate otherwise (contrast to default behavior of Escape to revert)Definition:
1 << 7- See Also:
-
CtrlEnterForNewLine
public static final int CtrlEnterForNewLineIn multi-line mode: validate with Enter, add new line with Ctrl+Enter (default is opposite: validate with Ctrl+Enter, add line with Enter). Note that Shift+Enter always enter a new line either way.Definition:
1 << 8- See Also:
-
ReadOnly
public static final int ReadOnlyRead-only modeDefinition:
1 << 9- See Also:
-
Password
public static final int PasswordPassword mode, display all characters as '*', disable copyDefinition:
1 << 10- See Also:
-
AlwaysOverwrite
public static final int AlwaysOverwriteOverwrite modeDefinition:
1 << 11- See Also:
-
AutoSelectAll
public static final int AutoSelectAllSelect entire text when first taking mouse focusDefinition:
1 << 12- See Also:
-
ParseEmptyRefVal
public static final int ParseEmptyRefValInputFloat(), InputInt(), InputScalar() etc. only: parse empty string as zero value.Definition:
1 << 13- See Also:
-
DisplayEmptyRefVal
public static final int DisplayEmptyRefValInputFloat(), InputInt(), InputScalar() etc. only: when value is zero, do not display it. Generally used with ImGuiInputTextFlags_ParseEmptyRefVal.Definition:
1 << 14- See Also:
-
NoHorizontalScroll
public static final int NoHorizontalScrollDisable following the cursor horizontallyDefinition:
1 << 15- See Also:
-
NoUndoRedo
public static final int NoUndoRedoDisable undo/redo. Note that input text owns the text data while active, if you want to provide your own undo/redo stack you need e.g. to call ClearActiveID().Definition:
1 << 16- See Also:
-
ElideLeft
public static final int ElideLeftWhen text doesn't fit, elide left side to ensure right side stays visible. Useful for path/filenames. Single-line only!Definition:
1 << 17- See Also:
-
CallbackCompletion
public static final int CallbackCompletionCallback on pressing TAB (for completion handling)Definition:
1 << 18- See Also:
-
CallbackHistory
public static final int CallbackHistoryCallback on pressing Up/Down arrows (for history handling)Definition:
1 << 19- See Also:
-
CallbackAlways
public static final int CallbackAlwaysCallback on each iteration. User code may query cursor position, modify text buffer.Definition:
1 << 20- See Also:
-
CallbackCharFilter
public static final int CallbackCharFilterCallback on character inputs to replace or discard them. Modify 'EventChar' to replace or discard, or return 1 in callback to discard.Definition:
1 << 21- See Also:
-
CallbackResize
public static final int CallbackResizeCallback on buffer capacity changes request (beyond 'buf_size' parameter value), allowing the string to grow. Notify when the string wants to be resized (for string types which hold a cache of their Size). You will be provided a new BufSize in the callback and NEED to honor it. (see misc/cpp/imgui_stdlib.h for an example of using this)Definition:
1 << 22- See Also:
-
CallbackEdit
public static final int CallbackEditCallback on any edit. Note that InputText() already returns true on edit + you can always use IsItemEdited(). The callback is useful to manipulate the underlying buffer while focus is active.Definition:
1 << 23- See Also:
-
WordWrap
public static final int WordWrapInputTextMultiline(): word-wrap lines that are too long.Definition:
1 << 24- See Also:
-