Package imgui.flag
Class ImGuiSelectableFlags
java.lang.Object
imgui.flag.ImGuiSelectableFlags
Flags for ImGui::Selectable()
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intGenerate press events on double clicks toostatic final intHit testing will allow subsequent widgets to overlap this one.static final intCannot be selected, display grayed out textstatic final intRenamed in 1.91.0static final intMake the item be displayed as if it is hoveredstatic final intClicking this doesn't close parent popup window (overrides ImGuiItemFlags_AutoClosePopups)static final intDefinition:0static final intAuto-select when moved into, unless Ctrl is held.static final intFrame will span all columns of its container table (text will still fit in current column) -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
NoAutoClosePopups
public static final int NoAutoClosePopupsClicking this doesn't close parent popup window (overrides ImGuiItemFlags_AutoClosePopups)Definition:
1 << 0- See Also:
-
SpanAllColumns
public static final int SpanAllColumnsFrame will span all columns of its container table (text will still fit in current column)Definition:
1 << 1- See Also:
-
AllowDoubleClick
public static final int AllowDoubleClickGenerate press events on double clicks tooDefinition:
1 << 2- See Also:
-
Disabled
public static final int DisabledCannot be selected, display grayed out textDefinition:
1 << 3- See Also:
-
AllowOverlap
public static final int AllowOverlapHit testing will allow subsequent widgets to overlap this one. Require previous frame HoveredId to match before being usable. Shortcut to calling SetNextItemAllowOverlap().Definition:
1 << 4- See Also:
-
Highlight
public static final int HighlightMake the item be displayed as if it is hoveredDefinition:
1 << 5- See Also:
-
DontClosePopups
public static final int DontClosePopupsRenamed in 1.91.0Definition:
ImGuiSelectableFlags_NoAutoClosePopups- See Also:
-