Class ImGuiTableColumnFlags
ImGui.tableSetupColumn(String, int)-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intTableHeadersRow() will submit an angled header row for this column.static final intDefault as a hidden/disabled column.static final intDefault as a sorting column.static final intOverriding/master disable flag: hide column, won't show in context menu (unlike calling TableSetColumnEnabled() which manipulates the user accessible state)static final intIgnore current Indent value when entering cell (default for columns>0).static final intUse current Indent value when entering cell (default for column 0).static final int[Internal] Combinations and masksstatic final intStatus: is enabled == not hidden by user/api (referred to as "Hide" in _DefaultHide and _NoHide) flags.static final intStatus: is hovered by mousestatic final intStatus: is currently part of the sort specsstatic final intStatus: is visible == is enabled AND not clipped by scrolling.static final intDisable clipping for this column (all NoClip columns will render in a same draw command).static final int[Internal] Disable user resizing this column directly (it may however we resized indirectly from its left edge)static final intTableHeadersRow() will submit an empty label for this column.static final intDisable header text width contribution to automatic column width.static final intDisable ability to hide/disable this column.static final intInput configuration flagsstatic final intDisable manual reordering this column, this will also prevent other columns from crossing over this column.static final intDisable manual resizing.static final intDisable ability to sort on this field (even if ImGuiTableFlags_Sortable is set on the table).static final intDisable ability to sort in the ascending direction.static final intDisable ability to sort in the descending direction.static final intMake the initial sort direction Ascending when first sorting on this column (default).static final intMake the initial sort direction Descending when first sorting on this column.static final int[Internal] Combinations and masksstatic final intColumn will not stretch.static final int[Internal] Combinations and masksstatic final intColumn will stretch. -
Method Summary
-
Field Details
-
None
public static final int NoneInput configuration flagsDefinition:
0- See Also:
-
Disabled
public static final int DisabledOverriding/master disable flag: hide column, won't show in context menu (unlike calling TableSetColumnEnabled() which manipulates the user accessible state)Definition:
1 << 0- See Also:
-
DefaultHide
public static final int DefaultHideDefault as a hidden/disabled column.Definition:
1 << 1- See Also:
-
DefaultSort
public static final int DefaultSortDefault as a sorting column.Definition:
1 << 2- See Also:
-
WidthStretch
public static final int WidthStretchColumn will stretch. Preferable with horizontal scrolling disabled (default if table sizing policy is _SizingStretchSame or _SizingStretchProp).Definition:
1 << 3- See Also:
-
WidthFixed
public static final int WidthFixedColumn will not stretch. Preferable with horizontal scrolling enabled (default if table sizing policy is _SizingFixedFit and table is resizable).Definition:
1 << 4- See Also:
-
NoResize
public static final int NoResizeDisable manual resizing.Definition:
1 << 5- See Also:
-
NoReorder
public static final int NoReorderDisable manual reordering this column, this will also prevent other columns from crossing over this column.Definition:
1 << 6- See Also:
-
NoHide
public static final int NoHideDisable ability to hide/disable this column.Definition:
1 << 7- See Also:
-
NoClip
public static final int NoClipDisable clipping for this column (all NoClip columns will render in a same draw command).Definition:
1 << 8- See Also:
-
NoSort
public static final int NoSortDisable ability to sort on this field (even if ImGuiTableFlags_Sortable is set on the table).Definition:
1 << 9- See Also:
-
NoSortAscending
public static final int NoSortAscendingDisable ability to sort in the ascending direction.Definition:
1 << 10- See Also:
-
NoSortDescending
public static final int NoSortDescendingDisable ability to sort in the descending direction.Definition:
1 << 11- See Also:
-
NoHeaderLabel
public static final int NoHeaderLabelTableHeadersRow() will submit an empty label for this column. Convenient for some small columns. Name will still appear in context menu or in angled headers. You may append into this cell by calling TableSetColumnIndex() right after the TableHeadersRow() call.Definition:
1 << 12- See Also:
-
NoHeaderWidth
public static final int NoHeaderWidthDisable header text width contribution to automatic column width.Definition:
1 << 13- See Also:
-
PreferSortAscending
public static final int PreferSortAscendingMake the initial sort direction Ascending when first sorting on this column (default).Definition:
1 << 14- See Also:
-
PreferSortDescending
public static final int PreferSortDescendingMake the initial sort direction Descending when first sorting on this column.Definition:
1 << 15- See Also:
-
IndentEnable
public static final int IndentEnableUse current Indent value when entering cell (default for column 0).Definition:
1 << 16- See Also:
-
IndentDisable
public static final int IndentDisableIgnore current Indent value when entering cell (default for columns>0). Indentation changes _within_ the cell will still be honored.Definition:
1 << 17- See Also:
-
AngledHeader
public static final int AngledHeaderTableHeadersRow() will submit an angled header row for this column. Note this will add an extra row.Definition:
1 << 18- See Also:
-
IsEnabled
public static final int IsEnabledStatus: is enabled == not hidden by user/api (referred to as "Hide" in _DefaultHide and _NoHide) flags.Definition:
1 << 24- See Also:
-
IsVisible
public static final int IsVisibleStatus: is visible == is enabled AND not clipped by scrolling.Definition:
1 << 25- See Also:
-
IsSorted
public static final int IsSortedStatus: is currently part of the sort specsDefinition:
1 << 26- See Also:
-
IsHovered
public static final int IsHoveredStatus: is hovered by mouseDefinition:
1 << 27- See Also:
-
WidthMask_
public static final int WidthMask_[Internal] Combinations and masksDefinition:
ImGuiTableColumnFlags_WidthStretch | ImGuiTableColumnFlags_WidthFixed- See Also:
-
IndentMask_
public static final int IndentMask_[Internal] Combinations and masksDefinition:
ImGuiTableColumnFlags_IndentEnable | ImGuiTableColumnFlags_IndentDisable- See Also:
-
StatusMask_
public static final int StatusMask_[Internal] Combinations and masksDefinition:
ImGuiTableColumnFlags_IsEnabled | ImGuiTableColumnFlags_IsVisible | ImGuiTableColumnFlags_IsSorted | ImGuiTableColumnFlags_IsHovered- See Also:
-
NoDirectResize_
public static final int NoDirectResize_[Internal] Disable user resizing this column directly (it may however we resized indirectly from its left edge)Definition:
1 << 30- See Also:
-