Package imgui.flag
Class ImGuiTreeNodeFlags
java.lang.Object
imgui.flag.ImGuiTreeNodeFlags
Flags for ImGui::TreeNodeEx(), ImGui::CollapsingHeader*()
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intHit testing will allow subsequent widgets to overlap this one.static final intDisplay a bullet instead of arrow.static final intDefinition:ImGuiTreeNodeFlags_Framed | ImGuiTreeNodeFlags_NoTreePushOnOpen | ImGuiTreeNodeFlags_NoAutoOpenOnLogstatic final intDefault node to be openstatic final intHorizontal lines to child nodes.static final intNo lines drawnstatic final intHorizontal lines to child nodes.static final intDraw frame with background (e.g.static final intUse FramePadding (even for an unframed text node) to vertically align text baseline to regular widget height.static final intLabel will span all columns of its container tablestatic final intNo collapsing, no arrow (use as a convenience for leaf nodes).static final intRenamed in 1.92.0static final intNav: left arrow moves back to parent.static final intDon't automatically and temporarily open node when Logging is active (by default logging will automatically open tree nodes)static final intDefinition:0static final intDon't do a TreePush() when open (e.g.static final intOpen when clicking on the arrow part (default for multi-select unless any _OpenOnXXX behavior is set explicitly).static final intOpen on double-click instead of simple click (default for multi-select unless any _OpenOnXXX behavior is set explicitly).static final intDraw as selectedstatic final intFrame will span all columns of its container table (label will still fit in current column)static final intExtend hit box to the right-most edge, even if not framed.static final intExtend hit box to the left-most and right-most edges (cover the indent area).static final intNarrow hit box + narrow hovering highlight, will only cover the label text.static final intRenamed in 1.90.7 -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
Selected
public static final int SelectedDraw as selectedDefinition:
1 << 0- See Also:
-
Framed
public static final int FramedDraw frame with background (e.g. for CollapsingHeader)Definition:
1 << 1- See Also:
-
AllowOverlap
public static final int AllowOverlapHit testing will allow subsequent widgets to overlap this one. Require previous frame HoveredId to match before being usable. Shortcut to calling SetNextItemAllowOverlap().Definition:
1 << 2- See Also:
-
NoTreePushOnOpen
public static final int NoTreePushOnOpenDon't do a TreePush() when open (e.g. for CollapsingHeader) = no extra indent nor pushing on ID stackDefinition:
1 << 3- See Also:
-
NoAutoOpenOnLog
public static final int NoAutoOpenOnLogDon't automatically and temporarily open node when Logging is active (by default logging will automatically open tree nodes)Definition:
1 << 4- See Also:
-
DefaultOpen
public static final int DefaultOpenDefault node to be openDefinition:
1 << 5- See Also:
-
OpenOnDoubleClick
public static final int OpenOnDoubleClickOpen on double-click instead of simple click (default for multi-select unless any _OpenOnXXX behavior is set explicitly). Both behaviors may be combined.Definition:
1 << 6- See Also:
-
OpenOnArrow
public static final int OpenOnArrowOpen when clicking on the arrow part (default for multi-select unless any _OpenOnXXX behavior is set explicitly). Both behaviors may be combined.Definition:
1 << 7- See Also:
-
Leaf
public static final int LeafNo collapsing, no arrow (use as a convenience for leaf nodes). Note: will always open a tree/id scope and return true. If you never use that scope, add ImGuiTreeNodeFlags_NoTreePushOnOpen.Definition:
1 << 8- See Also:
-
Bullet
public static final int BulletDisplay a bullet instead of arrow. IMPORTANT: node can still be marked open/close if you don't set the _Leaf flag!Definition:
1 << 9- See Also:
-
FramePadding
public static final int FramePaddingUse FramePadding (even for an unframed text node) to vertically align text baseline to regular widget height. Equivalent to calling AlignTextToFramePadding() before the node.Definition:
1 << 10- See Also:
-
SpanAvailWidth
public static final int SpanAvailWidthExtend hit box to the right-most edge, even if not framed. This is not the default in order to allow adding other items on the same line without using AllowOverlap mode.Definition:
1 << 11- See Also:
-
SpanFullWidth
public static final int SpanFullWidthExtend hit box to the left-most and right-most edges (cover the indent area).Definition:
1 << 12- See Also:
-
SpanLabelWidth
public static final int SpanLabelWidthNarrow hit box + narrow hovering highlight, will only cover the label text.Definition:
1 << 13- See Also:
-
SpanAllColumns
public static final int SpanAllColumnsFrame will span all columns of its container table (label will still fit in current column)Definition:
1 << 14- See Also:
-
LabelSpanAllColumns
public static final int LabelSpanAllColumnsLabel will span all columns of its container tableDefinition:
1 << 15- See Also:
-
CollapsingHeader
public static final int CollapsingHeaderDefinition:ImGuiTreeNodeFlags_Framed | ImGuiTreeNodeFlags_NoTreePushOnOpen | ImGuiTreeNodeFlags_NoAutoOpenOnLog- See Also:
-
DrawLinesNone
public static final int DrawLinesNoneNo lines drawnDefinition:
1 << 18- See Also:
-
DrawLinesFull
public static final int DrawLinesFullHorizontal lines to child nodes. Vertical line drawn down to TreePop() position: cover full contents. Faster (for large trees).Definition:
1 << 19- See Also:
-
DrawLinesToNodes
public static final int DrawLinesToNodesHorizontal lines to child nodes. Vertical line drawn down to bottom-most child node. Slower (for large trees).Definition:
1 << 20- See Also:
-
SpanTextWidth
public static final int SpanTextWidthRenamed in 1.90.7Definition:
ImGuiTreeNodeFlags_SpanLabelWidth- See Also:
-