Package imgui.internal.flag
Class ImGuiButtonFlags
java.lang.Object
imgui.internal.flag.ImGuiButtonFlags
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intvertically align button to match text baseline - ButtonEx() only // FIXME: Should be removed and handled by SmallButton(), not possible currently because of DC.CursorPosPrevLinestatic final intHit testing will allow subsequent widgets to overlap this one.static final intInvisibleButton(): do not disable navigation/tabbing.static final intallow interactions even if a child window is overlappingstatic final intReact on left mouse button (default)static final int[Internal]static final intReact on center mouse buttonstatic final intReact on right mouse buttonstatic final int[EXPERIMENTAL: Not very well specced].static final intdon't set ActiveId while holding the mouse (ImGuiButtonFlags_PressedOnClick only)static final intdon't report as hovered when nav focus is on this itemstatic final intdisable mouse interaction if a key modifier is heldstatic final intdon't override navigation focus when activated (FIXME: this is essentially used every time an item uses ImGuiItemFlags_NoNav, but because legacy specs don't requires LastItemData to be set ButtonBehavior(), we can't poll g.LastItemData.ItemFlags)static final intDefinition:0static final intdon't set key/input owner on the initial click (note: mouse buttons are keys! often, the key in question will be ImGuiKey_MouseLeft!)static final intdon't test key/input owner when polling the key (note: mouse buttons are keys! often, the key in question will be ImGuiKey_MouseLeft!)static final intreturn true on click (mouse down event)static final int[Default] return true on click + release on same item<-- this is what the majority of Button are usingstatic final intreturn true on click + release even if the release event is not done while hovering the itemstatic final intDefinition:ImGuiButtonFlags_PressedOnClickReleasestatic final intreturn true on double-click (default requires click+release)static final intreturn true when held into while we are drag and dropping another item (used by e.g.static final intDefinition:ImGuiButtonFlags_PressedOnClick | ImGuiButtonFlags_PressedOnClickRelease | ImGuiButtonFlags_PressedOnClickReleaseAnywhere | ImGuiButtonFlags_PressedOnRelease | ImGuiButtonFlags_PressedOnDoubleClick | ImGuiButtonFlags_PressedOnDragDropHoldstatic final intreturn true on release (default requires click+release). -
Method Summary
-
Field Details
-
None
public static final int NoneDefinition:0- See Also:
-
MouseButtonLeft
public static final int MouseButtonLeftReact on left mouse button (default)Definition:
1 << 0- See Also:
-
MouseButtonRight
public static final int MouseButtonRightReact on right mouse buttonDefinition:
1 << 1- See Also:
-
MouseButtonMiddle
public static final int MouseButtonMiddleReact on center mouse buttonDefinition:
1 << 2- See Also:
-
MouseButtonMask_
public static final int MouseButtonMask_[Internal]Definition:
ImGuiButtonFlags_MouseButtonLeft | ImGuiButtonFlags_MouseButtonRight | ImGuiButtonFlags_MouseButtonMiddle- See Also:
-
AllowOverlap
public static final int AllowOverlapHit testing will allow subsequent widgets to overlap this one. Require previous frame HoveredId to match before being usable. Shortcut to calling SetNextItemAllowOverlap().Definition:
1 << 12- See Also:
-
PressedOnClick
public static final int PressedOnClickreturn true on click (mouse down event)Definition:
1 << 4- See Also:
-
PressedOnClickRelease
public static final int PressedOnClickRelease[Default] return true on click + release on same item<-- this is what the majority of Button are usingDefinition:
1 << 5- See Also:
-
PressedOnClickReleaseAnywhere
public static final int PressedOnClickReleaseAnywherereturn true on click + release even if the release event is not done while hovering the itemDefinition:
1 << 6- See Also:
-
PressedOnRelease
public static final int PressedOnReleasereturn true on release (default requires click+release). Prior to 2026/03/20 this implied ImGuiButtonFlags_NoHoldingActiveId but they are separate now.Definition:
1 << 7- See Also:
-
PressedOnDoubleClick
public static final int PressedOnDoubleClickreturn true on double-click (default requires click+release)Definition:
1 << 8- See Also:
-
PressedOnDragDropHold
public static final int PressedOnDragDropHoldreturn true when held into while we are drag and dropping another item (used by e.g. tree nodes, collapsing headers)Definition:
1 << 9- See Also:
-
FlattenChildren
public static final int FlattenChildrenallow interactions even if a child window is overlappingDefinition:
1 << 11- See Also:
-
AlignTextBaseLine
public static final int AlignTextBaseLinevertically align button to match text baseline - ButtonEx() only // FIXME: Should be removed and handled by SmallButton(), not possible currently because of DC.CursorPosPrevLineDefinition:
1 << 15- See Also:
-
NoKeyModsAllowed
public static final int NoKeyModsAlloweddisable mouse interaction if a key modifier is heldDefinition:
1 << 16- See Also:
-
NoHoldingActiveId
public static final int NoHoldingActiveIddon't set ActiveId while holding the mouse (ImGuiButtonFlags_PressedOnClick only)Definition:
1 << 17- See Also:
-
NoHoveredOnFocus
public static final int NoHoveredOnFocusdon't report as hovered when nav focus is on this itemDefinition:
1 << 19- See Also:
-
NoSetKeyOwner
public static final int NoSetKeyOwnerdon't set key/input owner on the initial click (note: mouse buttons are keys! often, the key in question will be ImGuiKey_MouseLeft!)Definition:
1 << 20- See Also:
-
NoTestKeyOwner
public static final int NoTestKeyOwnerdon't test key/input owner when polling the key (note: mouse buttons are keys! often, the key in question will be ImGuiKey_MouseLeft!)Definition:
1 << 21- See Also:
-
NoFocus
public static final int NoFocus[EXPERIMENTAL: Not very well specced]. Don't focus parent window when clicking.Definition:
1 << 22- See Also:
-
PressedOnMask_
public static final int PressedOnMask_Definition:ImGuiButtonFlags_PressedOnClick | ImGuiButtonFlags_PressedOnClickRelease | ImGuiButtonFlags_PressedOnClickReleaseAnywhere | ImGuiButtonFlags_PressedOnRelease | ImGuiButtonFlags_PressedOnDoubleClick | ImGuiButtonFlags_PressedOnDragDropHold- See Also:
-
PressedOnDefault_
public static final int PressedOnDefault_Definition:ImGuiButtonFlags_PressedOnClickRelease- See Also:
-